@@ -113,17 +113,16 @@ static __always_inline void auxmap__finalize_event_header(struct auxiliary_map *
 
 /**
  * @brief Copy the entire event from the auxiliary map to bpf ringbuf.
- * If the event is correctly copied in the ringbuf we increments the number
+ * If the event is correctly copied in the ringbuf we increment the number
  * of events sent to userspace, otherwise we increment the dropped events.
  *
  * @param auxmap pointer to the auxmap in which we have already written the entire event.
- * @param ctx BPF prog context
  */
-static __always_inline void auxmap__submit_event(struct auxiliary_map *auxmap, void *ctx) {
+static __always_inline void auxmap__submit_event(struct auxiliary_map *auxmap) {
 	struct ringbuf_map *rb = maps__get_ringbuf_map();
 	if(!rb) {
-		bpf_tail_call(ctx, &extra_event_prog_tail_table, T1_HOTPLUG_E);
-		bpf_printk("failed to tail call into the 'hotplug' prog");
+		// this should never happen because we check it in sys_enter/sys_exit
+		bpf_printk("FAILURE: unable to obtain the ring buffer");
 		return;
 	}
 
@@ -777,7 +776,8 @@ static __always_inline void auxmap__store_socktuple_param(struct auxiliary_map *
 
 	case AF_UNIX: {
 		struct unix_sock *socket_local = (struct unix_sock *)sk;
-		struct unix_sock *socket_remote = (struct unix_sock *)BPF_CORE_READ(socket_local, peer);
+		struct unix_sock *socket_peer = (struct unix_sock *)BPF_CORE_READ(socket_local, peer);
+		struct sockaddr_un usrsockaddr_un = {};
 		char *path = NULL;
 
 		/* Pack the tuple info:
@@ -788,18 +788,23 @@ static __always_inline void auxmap__store_socktuple_param(struct auxiliary_map *
 		 */
 		push__u8(auxmap->data, &auxmap->payload_pos, socket_family_to_scap(socket_family));
 		if(direction == OUTBOUND) {
-			push__u64(auxmap->data, &auxmap->payload_pos, (uint64_t)socket_remote);
+			push__u64(auxmap->data, &auxmap->payload_pos, (uint64_t)socket_peer);
 			push__u64(auxmap->data, &auxmap->payload_pos, (uint64_t)socket_local);
-			path = BPF_CORE_READ(socket_remote, addr, name[0].sun_path);
+			if(socket_peer == NULL && usrsockaddr != NULL) {
+				bpf_probe_read_user(&usrsockaddr_un,
+				                    bpf_core_type_size(struct sockaddr_un),
+				                    (void *)usrsockaddr);
+				path = usrsockaddr_un.sun_path;
+			} else {
+				path = BPF_CORE_READ(socket_peer, addr, name[0].sun_path);
+			}
 		} else {
 			push__u64(auxmap->data, &auxmap->payload_pos, (uint64_t)socket_local);
-			push__u64(auxmap->data, &auxmap->payload_pos, (uint64_t)socket_remote);
+			push__u64(auxmap->data, &auxmap->payload_pos, (uint64_t)socket_peer);
 			path = BPF_CORE_READ(socket_local, addr, name[0].sun_path);
 		}
 
-		unsigned long start_reading_point;
-		char first_path_byte = *(char *)path;
-		if(first_path_byte == '\0') {
+		if(path[0] == '\0') {
 			/* Please note exceptions in the `sun_path`:
 			 * Taken from: https://man7.org/linux/man-pages/man7/unix.7.html
 			 *
@@ -809,14 +814,12 @@ static __always_inline void auxmap__store_socktuple_param(struct auxiliary_map *
 			 *
 			 * So in this case, we need to skip the initial `\0`.
 			 */
-			start_reading_point = (unsigned long)path + 1;
-		} else {
-			start_reading_point = (unsigned long)path;
+			path++;
 		}
 
 		uint16_t written_bytes = push__charbuf(auxmap->data,
 		                                       &auxmap->payload_pos,
-		                                       start_reading_point,
+		                                       (unsigned long)path,
 		                                       MAX_UNIX_SOCKET_PATH,
 		                                       KERNEL);
 		final_param_len = FAMILY_SIZE + KERNEL_POINTER + KERNEL_POINTER + written_bytes;
@@ -1303,7 +1306,7 @@ static __always_inline uint16_t store_cgroup_subsys(struct auxiliary_map *auxmap
 	 * at the end of the string, reading with `bpf_probe_read_str()`).
 	 *
 	 * The rationale here is to replace the string terminator '\0'
-	 * with the '/' for every path compotent, excluding the last.
+	 * with the '/' for every path component, excluding the last.
 	 *
 	 * Starting from what we have already inserted ("cpuset="),
 	 * we want to obtain as a final result:
@@ -1323,6 +1326,39 @@ static __always_inline uint16_t store_cgroup_subsys(struct auxiliary_map *auxmap
 	 *
 	 *  cpuset=/path_part1/path_part2\0
 	 */
+
+	/*
+	 *  If kernfs node is still not NULL, it means last path component retrieved
+	 *  (ie: the first one to be printed) was still not '\0' (ie: '/').
+	 *  To avoid sending a cgroup that does not start with '/', manually add it.
+	 *
+	 *  Example:
+	 *  /user.slice/user-1000.slice/user@1000.service/app.slice/app-org.gnome.Terminal.slice/vte-spawn-2f17b2eb-994e-415d-bce0-44c1447d7cd2.scope
+	 *  gets split as:
+	 *  * vte-spawn-2f17b2eb-994e-415d-bce0-44c1447d7cd2.scope\0
+	 *  * app-org.gnome.Terminal.slice\0
+	 *  * app.slice\0
+	 *  * user@1000.service\0
+	 *  * user-1000.slice\0
+	 *  * user.slice\0
+	 * Without the below fix, we would send to userspace "user.slice/user-1000.slice/..." without
+	 * leading '/'.
+	 *
+	 * Counter example with "5" components + the root:
+	 * /user.slice/user-1000.slice/user@1000.service/app.slice/app-org.gnome.Terminal.slice
+	 * gets split as:
+	 * * app-org.gnome.Terminal.slice\0
+	 * * app.slice\0
+	 * * user@1000.service\0
+	 * * user-1000.slice\0
+	 * * user.slice\0
+	 * * \0
+	 * In this case, we won't push the new character, instead we will push the correct string.
+	 */
+	if(kn) {
+		push__new_character(auxmap->data, &auxmap->payload_pos, '/');
+		total_size++;
+	}
 	for(int k = MAX_CGROUP_PATH_POINTERS - 1; k >= 0; --k) {
 		if(cgroup_path_pointers[k]) {
 			total_size += push__charbuf(auxmap->data,
@@ -1467,10 +1503,15 @@ static __always_inline void auxmap__store_fdlist_param(struct auxiliary_map *aux
 	                sizeof(uint16_t) + (num_pairs * (sizeof(int64_t) + sizeof(int16_t))));
 }
 
+typedef struct {
+	bool only_port_range;
+	ppm_event_code evt_type;
+	long mmsg_index;
+} dynamic_snaplen_args;
+
 static __always_inline void apply_dynamic_snaplen(struct pt_regs *regs,
                                                   uint16_t *snaplen,
-                                                  bool only_port_range,
-                                                  ppm_event_code evt_type) {
+                                                  const dynamic_snaplen_args *input_args) {
 	if(!maps__get_do_dynamic_snaplen()) {
 		return;
 	}
@@ -1487,7 +1528,9 @@ static __always_inline void apply_dynamic_snaplen(struct pt_regs *regs,
 	 *  - writev
 	 *  - pwritev
 	 *  - recvmsg
+	 *  - recvmmsg
 	 *  - sendmsg
+	 *  - sendmmsg
 	 *  - send
 	 *  - recv
 	 *  - recvfrom
@@ -1507,12 +1550,14 @@ static __always_inline void apply_dynamic_snaplen(struct pt_regs *regs,
 	 *  - writev
 	 *  - pwritev
 	 *  - recvmsg
+	 *  - recvmmsg
 	 *  - sendmsg
+	 *  - sendmmsg
 	 */
 	unsigned long args[5] = {0};
 	struct sockaddr *sockaddr = NULL;
 
-	switch(evt_type) {
+	switch(input_args->evt_type) {
 	case PPME_SOCKET_SENDTO_X:
 	case PPME_SOCKET_RECVFROM_X:
 		extract__network_args(args, 5, regs);
@@ -1539,6 +1584,30 @@ static __always_inline void apply_dynamic_snaplen(struct pt_regs *regs,
 		}
 	} break;
 
+	case PPME_SOCKET_RECVMMSG_X:
+	case PPME_SOCKET_SENDMMSG_X: {
+		extract__network_args(args, 3, regs);
+		if(bpf_in_ia32_syscall()) {
+			struct compat_mmsghdr compat_mmh = {};
+			struct compat_mmsghdr *mmh_ptr = (struct compat_mmsghdr *)args[1];
+			if(likely(bpf_probe_read_user(&compat_mmh,
+			                              bpf_core_type_size(struct compat_mmsghdr),
+			                              (void *)(mmh_ptr + input_args->mmsg_index)) == 0)) {
+				sockaddr = (struct sockaddr *)(unsigned long)(compat_mmh.msg_hdr.msg_name);
+			}
+			// in any case we break the switch.
+			break;
+		}
+
+		struct mmsghdr mmh = {};
+		struct mmsghdr *mmh_ptr = (struct mmsghdr *)args[1];
+		if(bpf_probe_read_user(&mmh,
+		                       bpf_core_type_size(struct mmsghdr),
+		                       (void *)(mmh_ptr + input_args->mmsg_index)) == 0) {
+			sockaddr = (struct sockaddr *)mmh.msg_hdr.msg_name;
+		}
+	} break;
+
 	default:
 		extract__network_args(args, 3, regs);
 		break;
@@ -1607,7 +1676,7 @@ static __always_inline void apply_dynamic_snaplen(struct pt_regs *regs,
 	}
 
 	/* If we check only port range without reading syscall data we can stop here */
-	if(only_port_range) {
+	if(input_args->only_port_range) {
 		return;
 	}
 
@@ -1815,3 +1884,12 @@ static __always_inline void auxmap__store_d_path_approx(struct auxiliary_map *au
 	                            MAX_COMPONENT_LEN,
 	                            KERNEL);
 }
+
+static __always_inline void auxmap__store_pgid(struct auxiliary_map *auxmap,
+                                               struct task_struct *task) {
+	pid_t pgid = 0;
+	struct pid *pid_struct = NULL;
+	READ_TASK_FIELD_INTO(&pid_struct, task, signal, pids[PIDTYPE_PGID]);
+	BPF_CORE_READ_INTO(&pgid, pid_struct, numbers[0].nr);
+	auxmap__store_s64_param(auxmap, (int64_t)pgid);
+}
