@@ -28,7 +28,7 @@ int BPF_PROG(execve_e, struct pt_regs *regs, long id) {
 
 	auxmap__finalize_event_header(auxmap);
 
-	auxmap__submit_event(auxmap, ctx);
+	auxmap__submit_event(auxmap);
 	return 0;
 }
 
@@ -155,7 +155,7 @@ int BPF_PROG(execve_x, struct pt_regs *regs, long ret) {
 	/* We have to split here the bpf program, otherwise, it is too large
 	 * for the verifier (limit 1000000 instructions).
 	 */
-	bpf_tail_call(ctx, &extra_event_prog_tail_table, T1_EXECVE_X);
+	bpf_tail_call(ctx, &syscall_exit_extra_tail_table, T1_EXECVE_X);
 	return 0;
 }
 
@@ -284,7 +284,7 @@ int BPF_PROG(t1_execve_x, struct pt_regs *regs, long ret) {
 
 	/*=============================== COLLECT PARAMETERS  ===========================*/
 
-	bpf_tail_call(ctx, &extra_event_prog_tail_table, T2_EXECVE_X);
+	bpf_tail_call(ctx, &syscall_exit_extra_tail_table, T2_EXECVE_X);
 	return 0;
 }
 
@@ -307,11 +307,19 @@ int BPF_PROG(t2_execve_x, struct pt_regs *regs, long ret) {
 		auxmap__store_empty_param(auxmap);
 	}
 
+	/* Parameter 29: pgid (type: PT_PID) */
+	auxmap__store_pgid(auxmap, task);
+
+	/* Parameter 30: egid (type: PT_GID) */
+	uint32_t egid;
+	extract__egid(task, &egid);
+	auxmap__store_u32_param(auxmap, egid);
+
 	/*=============================== COLLECT PARAMETERS  ===========================*/
 
 	auxmap__finalize_event_header(auxmap);
 
-	auxmap__submit_event(auxmap, ctx);
+	auxmap__submit_event(auxmap);
 	return 0;
 }
 
