@@ -13,10 +13,7 @@
 SEC("tp_btf/sys_enter")
 int BPF_PROG(io_uring_enter_e, struct pt_regs *regs, long id) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf,
-	                           ctx,
-	                           IO_URING_ENTER_E_SIZE,
-	                           PPME_SYSCALL_IO_URING_ENTER_E)) {
+	if(!ringbuf__reserve_space(&ringbuf, IO_URING_ENTER_E_SIZE, PPME_SYSCALL_IO_URING_ENTER_E)) {
 		return 0;
 	}
 
@@ -40,10 +37,7 @@ int BPF_PROG(io_uring_enter_e, struct pt_regs *regs, long id) {
 SEC("tp_btf/sys_exit")
 int BPF_PROG(io_uring_enter_x, struct pt_regs *regs, long ret) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf,
-	                           ctx,
-	                           IO_URING_ENTER_X_SIZE,
-	                           PPME_SYSCALL_IO_URING_ENTER_X)) {
+	if(!ringbuf__reserve_space(&ringbuf, IO_URING_ENTER_X_SIZE, PPME_SYSCALL_IO_URING_ENTER_X)) {
 		return 0;
 	}
 
