@@ -13,7 +13,7 @@
 SEC("tp_btf/sys_enter")
 int BPF_PROG(llseek_e, struct pt_regs *regs, long id) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, LLSEEK_E_SIZE, PPME_SYSCALL_LLSEEK_E)) {
+	if(!ringbuf__reserve_space(&ringbuf, LLSEEK_E_SIZE, PPME_SYSCALL_LLSEEK_E)) {
 		return 0;
 	}
 
@@ -47,7 +47,7 @@ int BPF_PROG(llseek_e, struct pt_regs *regs, long id) {
 SEC("tp_btf/sys_exit")
 int BPF_PROG(llseek_x, struct pt_regs *regs, long ret) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, LLSEEK_X_SIZE, PPME_SYSCALL_LLSEEK_X)) {
+	if(!ringbuf__reserve_space(&ringbuf, LLSEEK_X_SIZE, PPME_SYSCALL_LLSEEK_X)) {
 		return 0;
 	}
 
