@@ -13,7 +13,7 @@
 SEC("tp_btf/sys_enter")
 int BPF_PROG(lseek_e, struct pt_regs *regs, long id) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, LSEEK_E_SIZE, PPME_SYSCALL_LSEEK_E)) {
+	if(!ringbuf__reserve_space(&ringbuf, LSEEK_E_SIZE, PPME_SYSCALL_LSEEK_E)) {
 		return 0;
 	}
 
@@ -45,7 +45,7 @@ int BPF_PROG(lseek_e, struct pt_regs *regs, long id) {
 SEC("tp_btf/sys_exit")
 int BPF_PROG(lseek_x, struct pt_regs *regs, long ret) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, LSEEK_X_SIZE, PPME_SYSCALL_LSEEK_X)) {
+	if(!ringbuf__reserve_space(&ringbuf, LSEEK_X_SIZE, PPME_SYSCALL_LSEEK_X)) {
 		return 0;
 	}
 
