@@ -14,7 +14,7 @@
 SEC("tp_btf/sys_enter")
 int BPF_PROG(mkdir_e, struct pt_regs *regs, long id) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, MKDIR_E_SIZE, PPME_SYSCALL_MKDIR_2_E)) {
+	if(!ringbuf__reserve_space(&ringbuf, MKDIR_E_SIZE, PPME_SYSCALL_MKDIR_2_E)) {
 		return 0;
 	}
 
@@ -59,7 +59,7 @@ int BPF_PROG(mkdir_x, struct pt_regs *regs, long ret) {
 
 	auxmap__finalize_event_header(auxmap);
 
-	auxmap__submit_event(auxmap, ctx);
+	auxmap__submit_event(auxmap);
 
 	return 0;
 }
