@@ -14,7 +14,7 @@
 SEC("tp_btf/sys_enter")
 int BPF_PROG(mknodat_e, struct pt_regs *regs, long id) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, MKNODAT_E_SIZE, PPME_SYSCALL_MKNODAT_E)) {
+	if(!ringbuf__reserve_space(&ringbuf, MKNODAT_E_SIZE, PPME_SYSCALL_MKNODAT_E)) {
 		return 0;
 	}
 
@@ -72,7 +72,7 @@ int BPF_PROG(mknodat_x, struct pt_regs *regs, long ret) {
 
 	auxmap__finalize_event_header(auxmap);
 
-	auxmap__submit_event(auxmap, ctx);
+	auxmap__submit_event(auxmap);
 
 	return 0;
 }
