@@ -13,7 +13,7 @@
 SEC("tp_btf/sys_enter")
 int BPF_PROG(mlock_e, struct pt_regs *regs, long id) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, MLOCK_E_SIZE, PPME_SYSCALL_MLOCK_E)) {
+	if(!ringbuf__reserve_space(&ringbuf, MLOCK_E_SIZE, PPME_SYSCALL_MLOCK_E)) {
 		return 0;
 	}
 
@@ -35,7 +35,7 @@ int BPF_PROG(mlock_e, struct pt_regs *regs, long id) {
 SEC("tp_btf/sys_exit")
 int BPF_PROG(mlock_x, struct pt_regs *regs, long ret) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, MLOCK_X_SIZE, PPME_SYSCALL_MLOCK_X)) {
+	if(!ringbuf__reserve_space(&ringbuf, MLOCK_X_SIZE, PPME_SYSCALL_MLOCK_X)) {
 		return 0;
 	}
 
