@@ -13,7 +13,7 @@
 SEC("tp_btf/sys_enter")
 int BPF_PROG(mlock2_e, struct pt_regs *regs, long id) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, MLOCK2_E_SIZE, PPME_SYSCALL_MLOCK2_E)) {
+	if(!ringbuf__reserve_space(&ringbuf, MLOCK2_E_SIZE, PPME_SYSCALL_MLOCK2_E)) {
 		return 0;
 	}
 
@@ -35,7 +35,7 @@ int BPF_PROG(mlock2_e, struct pt_regs *regs, long id) {
 SEC("tp_btf/sys_exit")
 int BPF_PROG(mlock2_x, struct pt_regs *regs, long ret) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, MLOCK2_X_SIZE, PPME_SYSCALL_MLOCK2_X)) {
+	if(!ringbuf__reserve_space(&ringbuf, MLOCK2_X_SIZE, PPME_SYSCALL_MLOCK2_X)) {
 		return 0;
 	}
 
