@@ -13,7 +13,7 @@
 SEC("tp_btf/sys_enter")
 int BPF_PROG(mlockall_e, struct pt_regs *regs, long id) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, MLOCKALL_E_SIZE, PPME_SYSCALL_MLOCKALL_E)) {
+	if(!ringbuf__reserve_space(&ringbuf, MLOCKALL_E_SIZE, PPME_SYSCALL_MLOCKALL_E)) {
 		return 0;
 	}
 
@@ -35,7 +35,7 @@ int BPF_PROG(mlockall_e, struct pt_regs *regs, long id) {
 SEC("tp_btf/sys_exit")
 int BPF_PROG(mlockall_x, struct pt_regs *regs, long ret) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, MLOCKALL_X_SIZE, PPME_SYSCALL_MLOCKALL_X)) {
+	if(!ringbuf__reserve_space(&ringbuf, MLOCKALL_X_SIZE, PPME_SYSCALL_MLOCKALL_X)) {
 		return 0;
 	}
 
