@@ -13,7 +13,7 @@
 SEC("tp_btf/sys_enter")
 int BPF_PROG(mmap2_e, struct pt_regs *regs, long id) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, MMAP2_E_SIZE, PPME_SYSCALL_MMAP2_E)) {
+	if(!ringbuf__reserve_space(&ringbuf, MMAP2_E_SIZE, PPME_SYSCALL_MMAP2_E)) {
 		return 0;
 	}
 
@@ -59,7 +59,7 @@ int BPF_PROG(mmap2_e, struct pt_regs *regs, long id) {
 SEC("tp_btf/sys_exit")
 int BPF_PROG(mmap2_x, struct pt_regs *regs, long ret) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, MMAP2_X_SIZE, PPME_SYSCALL_MMAP2_X)) {
+	if(!ringbuf__reserve_space(&ringbuf, MMAP2_X_SIZE, PPME_SYSCALL_MMAP2_X)) {
 		return 0;
 	}
 
