@@ -14,7 +14,7 @@
 SEC("tp_btf/sys_enter")
 int BPF_PROG(mount_e, struct pt_regs *regs, long id) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, MOUNT_E_SIZE, PPME_SYSCALL_MOUNT_E)) {
+	if(!ringbuf__reserve_space(&ringbuf, MOUNT_E_SIZE, PPME_SYSCALL_MOUNT_E)) {
 		return 0;
 	}
 
@@ -79,7 +79,7 @@ int BPF_PROG(mount_x, struct pt_regs *regs, long ret) {
 
 	auxmap__finalize_event_header(auxmap);
 
-	auxmap__submit_event(auxmap, ctx);
+	auxmap__submit_event(auxmap);
 
 	return 0;
 }
