@@ -13,7 +13,7 @@
 SEC("tp_btf/sys_enter")
 int BPF_PROG(munlockall_e, struct pt_regs *regs, long id) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, MUNLOCKALL_E_SIZE, PPME_SYSCALL_MUNLOCKALL_E)) {
+	if(!ringbuf__reserve_space(&ringbuf, MUNLOCKALL_E_SIZE, PPME_SYSCALL_MUNLOCKALL_E)) {
 		return 0;
 	}
 
@@ -35,7 +35,7 @@ int BPF_PROG(munlockall_e, struct pt_regs *regs, long id) {
 SEC("tp_btf/sys_exit")
 int BPF_PROG(munlockall_x, struct pt_regs *regs, long ret) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, MUNLOCKALL_X_SIZE, PPME_SYSCALL_MUNLOCKALL_X)) {
+	if(!ringbuf__reserve_space(&ringbuf, MUNLOCKALL_X_SIZE, PPME_SYSCALL_MUNLOCKALL_X)) {
 		return 0;
 	}
 
