@@ -13,7 +13,7 @@
 SEC("tp_btf/sys_enter")
 int BPF_PROG(munmap_e, struct pt_regs *regs, long id) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, MUNMAP_E_SIZE, PPME_SYSCALL_MUNMAP_E)) {
+	if(!ringbuf__reserve_space(&ringbuf, MUNMAP_E_SIZE, PPME_SYSCALL_MUNMAP_E)) {
 		return 0;
 	}
 
@@ -43,7 +43,7 @@ int BPF_PROG(munmap_e, struct pt_regs *regs, long id) {
 SEC("tp_btf/sys_exit")
 int BPF_PROG(munmap_x, struct pt_regs *regs, long ret) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, MUNMAP_X_SIZE, PPME_SYSCALL_MUNMAP_X)) {
+	if(!ringbuf__reserve_space(&ringbuf, MUNMAP_X_SIZE, PPME_SYSCALL_MUNMAP_X)) {
 		return 0;
 	}
 
