@@ -15,7 +15,6 @@ SEC("tp_btf/sys_enter")
 int BPF_PROG(open_by_handle_at_e, struct pt_regs *regs, long id) {
 	struct ringbuf_struct ringbuf;
 	if(!ringbuf__reserve_space(&ringbuf,
-	                           ctx,
 	                           OPEN_BY_HANDLE_AT_E_SIZE,
 	                           PPME_SYSCALL_OPEN_BY_HANDLE_AT_E)) {
 		return 0;
@@ -61,7 +60,7 @@ int BPF_PROG(open_by_handle_at_x, struct pt_regs *regs, long ret) {
 
 	/*=============================== COLLECT PARAMETERS  ===========================*/
 
-	bpf_tail_call(ctx, &extra_event_prog_tail_table, T1_OPEN_BY_HANDLE_AT_X);
+	bpf_tail_call(ctx, &syscall_exit_extra_tail_table, T1_OPEN_BY_HANDLE_AT_X);
 	return 0;
 }
 
@@ -118,7 +117,7 @@ int BPF_PROG(t1_open_by_handle_at_x, struct pt_regs *regs, long ret) {
 
 	auxmap__finalize_event_header(auxmap);
 
-	auxmap__submit_event(auxmap, ctx);
+	auxmap__submit_event(auxmap);
 
 	return 0;
 }
