@@ -13,7 +13,7 @@
 SEC("tp_btf/sys_enter")
 int BPF_PROG(pidfd_getfd_e, struct pt_regs *regs, long id) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, PIDFD_GETFD_E_SIZE, PPME_SYSCALL_PIDFD_GETFD_E)) {
+	if(!ringbuf__reserve_space(&ringbuf, PIDFD_GETFD_E_SIZE, PPME_SYSCALL_PIDFD_GETFD_E)) {
 		return 0;
 	}
 
@@ -39,7 +39,7 @@ int BPF_PROG(pidfd_getfd_x, struct pt_regs *regs, long ret)
 
 {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, PIDFD_GETFD_X_SIZE, PPME_SYSCALL_PIDFD_GETFD_X)) {
+	if(!ringbuf__reserve_space(&ringbuf, PIDFD_GETFD_X_SIZE, PPME_SYSCALL_PIDFD_GETFD_X)) {
 		return 0;
 	}
 
