@@ -14,7 +14,7 @@
 SEC("tp_btf/sys_enter")
 int BPF_PROG(ptrace_e, struct pt_regs *regs, long id) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, PTRACE_E_SIZE, PPME_SYSCALL_PTRACE_E)) {
+	if(!ringbuf__reserve_space(&ringbuf, PTRACE_E_SIZE, PPME_SYSCALL_PTRACE_E)) {
 		return 0;
 	}
 
@@ -71,7 +71,7 @@ int BPF_PROG(ptrace_x, struct pt_regs *regs, long ret) {
 
 	auxmap__finalize_event_header(auxmap);
 
-	auxmap__submit_event(auxmap, ctx);
+	auxmap__submit_event(auxmap);
 
 	return 0;
 }
