@@ -14,7 +14,7 @@
 SEC("tp_btf/sys_enter")
 int BPF_PROG(pwritev_e, struct pt_regs *regs, long id) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, PWRITEV_E_SIZE, PPME_SYSCALL_PWRITEV_E)) {
+	if(!ringbuf__reserve_space(&ringbuf, PWRITEV_E_SIZE, PPME_SYSCALL_PWRITEV_E)) {
 		return 0;
 	}
 
@@ -66,8 +66,12 @@ int BPF_PROG(pwritev_x, struct pt_regs *regs, long ret) {
 	 * otherwise we need to extract it now and it has a cost. Here we check just
 	 * the return value if the syscall is successful.
 	 */
+	dynamic_snaplen_args snaplen_args = {
+	        .only_port_range = true,
+	        .evt_type = PPME_SYSCALL_PWRITEV_X,
+	};
 	uint16_t snaplen = maps__get_snaplen();
-	apply_dynamic_snaplen(regs, &snaplen, true, PPME_SYSCALL_PWRITEV_X);
+	apply_dynamic_snaplen(regs, &snaplen, &snaplen_args);
 	if(ret > 0 && snaplen > ret) {
 		snaplen = ret;
 	}
@@ -82,7 +86,7 @@ int BPF_PROG(pwritev_x, struct pt_regs *regs, long ret) {
 
 	auxmap__finalize_event_header(auxmap);
 
-	auxmap__submit_event(auxmap, ctx);
+	auxmap__submit_event(auxmap);
 
 	return 0;
 }
