@@ -14,7 +14,7 @@
 SEC("tp_btf/sys_enter")
 int BPF_PROG(quotactl_e, struct pt_regs *regs, long syscall_id) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, QUOTACTL_E_SIZE, PPME_SYSCALL_QUOTACTL_E)) {
+	if(!ringbuf__reserve_space(&ringbuf, QUOTACTL_E_SIZE, PPME_SYSCALL_QUOTACTL_E)) {
 		return 0;
 	}
 
@@ -209,7 +209,7 @@ int BPF_PROG(quotactl_x, struct pt_regs *regs, long ret) {
 
 	auxmap__finalize_event_header(auxmap);
 
-	auxmap__submit_event(auxmap, ctx);
+	auxmap__submit_event(auxmap);
 
 	return 0;
 }
