@@ -14,7 +14,7 @@
 SEC("tp_btf/sys_enter")
 int BPF_PROG(readv_e, struct pt_regs *regs, long id) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, READV_E_SIZE, PPME_SYSCALL_READV_E)) {
+	if(!ringbuf__reserve_space(&ringbuf, READV_E_SIZE, PPME_SYSCALL_READV_E)) {
 		return 0;
 	}
 
@@ -58,8 +58,12 @@ int BPF_PROG(readv_x, struct pt_regs *regs, long ret) {
 		/* We read the minimum between `snaplen` and what we really
 		 * have in the buffer.
 		 */
+		dynamic_snaplen_args snaplen_args = {
+		        .only_port_range = true,
+		        .evt_type = PPME_SYSCALL_READV_X,
+		};
 		uint16_t snaplen = maps__get_snaplen();
-		apply_dynamic_snaplen(regs, &snaplen, true, PPME_SYSCALL_READV_X);
+		apply_dynamic_snaplen(regs, &snaplen, &snaplen_args);
 		if(snaplen > ret) {
 			snaplen = ret;
 		}
@@ -81,7 +85,7 @@ int BPF_PROG(readv_x, struct pt_regs *regs, long ret) {
 
 	auxmap__finalize_event_header(auxmap);
 
-	auxmap__submit_event(auxmap, ctx);
+	auxmap__submit_event(auxmap);
 
 	return 0;
 }
