@@ -14,7 +14,7 @@
 SEC("tp_btf/sys_enter")
 int BPF_PROG(renameat_e, struct pt_regs *regs, long id) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, RENAMEAT_E_SIZE, PPME_SYSCALL_RENAMEAT_E)) {
+	if(!ringbuf__reserve_space(&ringbuf, RENAMEAT_E_SIZE, PPME_SYSCALL_RENAMEAT_E)) {
 		return 0;
 	}
 
@@ -75,7 +75,7 @@ int BPF_PROG(renameat_x, struct pt_regs *regs, long ret) {
 
 	auxmap__finalize_event_header(auxmap);
 
-	auxmap__submit_event(auxmap, ctx);
+	auxmap__submit_event(auxmap);
 
 	return 0;
 }
