@@ -14,7 +14,7 @@
 SEC("tp_btf/sys_enter")
 int BPF_PROG(rmdir_e, struct pt_regs *regs, long id) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, RMDIR_E_SIZE, PPME_SYSCALL_RMDIR_2_E)) {
+	if(!ringbuf__reserve_space(&ringbuf, RMDIR_E_SIZE, PPME_SYSCALL_RMDIR_2_E)) {
 		return 0;
 	}
 
@@ -57,7 +57,7 @@ int BPF_PROG(rmdir_x, struct pt_regs *regs, long ret) {
 
 	auxmap__finalize_event_header(auxmap);
 
-	auxmap__submit_event(auxmap, ctx);
+	auxmap__submit_event(auxmap);
 
 	return 0;
 }
