@@ -13,7 +13,7 @@
 SEC("tp_btf/sys_enter")
 int BPF_PROG(seccomp_e, struct pt_regs *regs, long id) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, SECCOMP_E_SIZE, PPME_SYSCALL_SECCOMP_E)) {
+	if(!ringbuf__reserve_space(&ringbuf, SECCOMP_E_SIZE, PPME_SYSCALL_SECCOMP_E)) {
 		return 0;
 	}
 
@@ -42,7 +42,7 @@ int BPF_PROG(seccomp_e, struct pt_regs *regs, long id) {
 SEC("tp_btf/sys_exit")
 int BPF_PROG(seccomp_x, struct pt_regs *regs, long ret) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, SECCOMP_X_SIZE, PPME_SYSCALL_SECCOMP_X)) {
+	if(!ringbuf__reserve_space(&ringbuf, SECCOMP_X_SIZE, PPME_SYSCALL_SECCOMP_X)) {
 		return 0;
 	}
 
