@@ -13,12 +13,14 @@
 
 SEC("tp_btf/sys_enter")
 int BPF_PROG(send_e, struct pt_regs *regs, long id) {
-	/* Collect parameters at the beginning to manage socketcalls */
+	/* We need to keep this at the beginning of the program because otherwise we alter the state of
+	 * the ebpf registers causing a verifier issue.
+	 */
 	unsigned long args[3] = {0};
 	extract__network_args(args, 3, regs);
 
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, SEND_E_SIZE, PPME_SOCKET_SEND_E)) {
+	if(!ringbuf__reserve_space(&ringbuf, SEND_E_SIZE, PPME_SOCKET_SEND_E)) {
 		return 0;
 	}
 
@@ -63,9 +65,13 @@ int BPF_PROG(send_x, struct pt_regs *regs, long ret) {
 	unsigned long args[3] = {0};
 	extract__network_args(args, 3, regs);
 
+	dynamic_snaplen_args snaplen_args = {
+	        .only_port_range = false,
+	        .evt_type = PPME_SOCKET_SEND_X,
+	};
 	int64_t bytes_to_read = ret > 0 ? ret : args[2];
 	uint16_t snaplen = maps__get_snaplen();
-	apply_dynamic_snaplen(regs, &snaplen, false, PPME_SOCKET_SEND_X);
+	apply_dynamic_snaplen(regs, &snaplen, &snaplen_args);
 	if((int64_t)snaplen > bytes_to_read) {
 		snaplen = bytes_to_read;
 	}
@@ -78,7 +84,7 @@ int BPF_PROG(send_x, struct pt_regs *regs, long ret) {
 
 	auxmap__finalize_event_header(auxmap);
 
-	auxmap__submit_event(auxmap, ctx);
+	auxmap__submit_event(auxmap);
 
 	return 0;
 }
