@@ -13,7 +13,7 @@
 SEC("tp_btf/sys_enter")
 int BPF_PROG(sendfile_e, struct pt_regs *regs, long id) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, SENDFILE_E_SIZE, PPME_SYSCALL_SENDFILE_E)) {
+	if(!ringbuf__reserve_space(&ringbuf, SENDFILE_E_SIZE, PPME_SYSCALL_SENDFILE_E)) {
 		return 0;
 	}
 
@@ -53,7 +53,7 @@ int BPF_PROG(sendfile_e, struct pt_regs *regs, long id) {
 SEC("tp_btf/sys_exit")
 int BPF_PROG(sendfile_x, struct pt_regs *regs, long ret) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, SENDFILE_X_SIZE, PPME_SYSCALL_SENDFILE_X)) {
+	if(!ringbuf__reserve_space(&ringbuf, SENDFILE_X_SIZE, PPME_SYSCALL_SENDFILE_X)) {
 		return 0;
 	}
 
