@@ -13,7 +13,7 @@
 SEC("tp_btf/sys_enter")
 int BPF_PROG(setgid_e, struct pt_regs *regs, long id) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, SETGID_E_SIZE, PPME_SYSCALL_SETGID_E)) {
+	if(!ringbuf__reserve_space(&ringbuf, SETGID_E_SIZE, PPME_SYSCALL_SETGID_E)) {
 		return 0;
 	}
 
@@ -39,7 +39,7 @@ int BPF_PROG(setgid_e, struct pt_regs *regs, long id) {
 SEC("tp_btf/sys_exit")
 int BPF_PROG(setgid_x, struct pt_regs *regs, long ret) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, SETGID_X_SIZE, PPME_SYSCALL_SETGID_X)) {
+	if(!ringbuf__reserve_space(&ringbuf, SETGID_X_SIZE, PPME_SYSCALL_SETGID_X)) {
 		return 0;
 	}
 
