@@ -13,7 +13,7 @@
 SEC("tp_btf/sys_enter")
 int BPF_PROG(setns_e, struct pt_regs *regs, long id) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, SETNS_E_SIZE, PPME_SYSCALL_SETNS_E)) {
+	if(!ringbuf__reserve_space(&ringbuf, SETNS_E_SIZE, PPME_SYSCALL_SETNS_E)) {
 		return 0;
 	}
 
@@ -43,7 +43,7 @@ int BPF_PROG(setns_e, struct pt_regs *regs, long id) {
 SEC("tp_btf/sys_exit")
 int BPF_PROG(setns_x, struct pt_regs *regs, long ret) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, SETNS_X_SIZE, PPME_SYSCALL_SETNS_X)) {
+	if(!ringbuf__reserve_space(&ringbuf, SETNS_X_SIZE, PPME_SYSCALL_SETNS_X)) {
 		return 0;
 	}
 
