@@ -13,7 +13,7 @@
 SEC("tp_btf/sys_enter")
 int BPF_PROG(setpgid_e, struct pt_regs *regs, long id) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, SETPGID_E_SIZE, PPME_SYSCALL_SETPGID_E)) {
+	if(!ringbuf__reserve_space(&ringbuf, SETPGID_E_SIZE, PPME_SYSCALL_SETPGID_E)) {
 		return 0;
 	}
 
@@ -43,7 +43,7 @@ int BPF_PROG(setpgid_e, struct pt_regs *regs, long id) {
 SEC("tp_btf/sys_exit")
 int BPF_PROG(setpgid_x, struct pt_regs *regs, long ret) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, SETPGID_X_SIZE, PPME_SYSCALL_SETPGID_X)) {
+	if(!ringbuf__reserve_space(&ringbuf, SETPGID_X_SIZE, PPME_SYSCALL_SETPGID_X)) {
 		return 0;
 	}
 
