@@ -13,7 +13,7 @@
 SEC("tp_btf/sys_enter")
 int BPF_PROG(setsid_e, struct pt_regs *regs, long id) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, SETSID_E_SIZE, PPME_SYSCALL_SETSID_E)) {
+	if(!ringbuf__reserve_space(&ringbuf, SETSID_E_SIZE, PPME_SYSCALL_SETSID_E)) {
 		return 0;
 	}
 
@@ -37,7 +37,7 @@ int BPF_PROG(setsid_e, struct pt_regs *regs, long id) {
 SEC("tp_btf/sys_exit")
 int BPF_PROG(setsid_x, struct pt_regs *regs, long ret) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, SETSID_X_SIZE, PPME_SYSCALL_SETSID_X)) {
+	if(!ringbuf__reserve_space(&ringbuf, SETSID_X_SIZE, PPME_SYSCALL_SETSID_X)) {
 		return 0;
 	}
 
