@@ -14,7 +14,7 @@
 SEC("tp_btf/sys_enter")
 int BPF_PROG(setsockopt_e, struct pt_regs *regs, long id) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, SETSOCKOPT_E_SIZE, PPME_SOCKET_SETSOCKOPT_E)) {
+	if(!ringbuf__reserve_space(&ringbuf, SETSOCKOPT_E_SIZE, PPME_SOCKET_SETSOCKOPT_E)) {
 		return 0;
 	}
 
@@ -77,7 +77,7 @@ int BPF_PROG(setsockopt_x, struct pt_regs *regs, long ret) {
 
 	auxmap__finalize_event_header(auxmap);
 
-	auxmap__submit_event(auxmap, ctx);
+	auxmap__submit_event(auxmap);
 
 	return 0;
 }
