@@ -13,7 +13,7 @@
 SEC("tp_btf/sys_enter")
 int BPF_PROG(setuid_e, struct pt_regs *regs, long id) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, SETUID_E_SIZE, PPME_SYSCALL_SETUID_E)) {
+	if(!ringbuf__reserve_space(&ringbuf, SETUID_E_SIZE, PPME_SYSCALL_SETUID_E)) {
 		return 0;
 	}
 
@@ -39,7 +39,7 @@ int BPF_PROG(setuid_e, struct pt_regs *regs, long id) {
 SEC("tp_btf/sys_exit")
 int BPF_PROG(setuid_x, struct pt_regs *regs, long ret) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, SETUID_X_SIZE, PPME_SYSCALL_SETUID_X)) {
+	if(!ringbuf__reserve_space(&ringbuf, SETUID_X_SIZE, PPME_SYSCALL_SETUID_X)) {
 		return 0;
 	}
 
