@@ -13,7 +13,7 @@
 SEC("tp_btf/sys_enter")
 int BPF_PROG(signalfd_e, struct pt_regs *regs, long id) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, SIGNALFD_E_SIZE, PPME_SYSCALL_SIGNALFD_E)) {
+	if(!ringbuf__reserve_space(&ringbuf, SIGNALFD_E_SIZE, PPME_SYSCALL_SIGNALFD_E)) {
 		return 0;
 	}
 
@@ -49,7 +49,7 @@ int BPF_PROG(signalfd_e, struct pt_regs *regs, long id) {
 SEC("tp_btf/sys_exit")
 int BPF_PROG(signalfd_x, struct pt_regs *regs, long ret) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, SIGNALFD_X_SIZE, PPME_SYSCALL_SIGNALFD_X)) {
+	if(!ringbuf__reserve_space(&ringbuf, SIGNALFD_X_SIZE, PPME_SYSCALL_SIGNALFD_X)) {
 		return 0;
 	}
 
