@@ -13,7 +13,7 @@
 SEC("tp_btf/sys_enter")
 int BPF_PROG(signalfd4_e, struct pt_regs *regs, long id) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, SIGNALFD4_E_SIZE, PPME_SYSCALL_SIGNALFD4_E)) {
+	if(!ringbuf__reserve_space(&ringbuf, SIGNALFD4_E_SIZE, PPME_SYSCALL_SIGNALFD4_E)) {
 		return 0;
 	}
 
@@ -43,7 +43,7 @@ int BPF_PROG(signalfd4_e, struct pt_regs *regs, long id) {
 SEC("tp_btf/sys_exit")
 int BPF_PROG(signalfd4_x, struct pt_regs *regs, long ret) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, SIGNALFD4_X_SIZE, PPME_SYSCALL_SIGNALFD4_X)) {
+	if(!ringbuf__reserve_space(&ringbuf, SIGNALFD4_X_SIZE, PPME_SYSCALL_SIGNALFD4_X)) {
 		return 0;
 	}
 
