@@ -12,12 +12,14 @@
 
 SEC("tp_btf/sys_enter")
 int BPF_PROG(socket_e, struct pt_regs *regs, long id) {
-	/* Collect parameters at the beginning so we can easily manage socketcalls */
+	/* We need to keep this at the beginning of the program because otherwise we alter the state of
+	 * the ebpf registers causing a verifier issue.
+	 */
 	unsigned long args[3] = {0};
 	extract__network_args(args, 3, regs);
 
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, SOCKET_E_SIZE, PPME_SOCKET_SOCKET_E)) {
+	if(!ringbuf__reserve_space(&ringbuf, SOCKET_E_SIZE, PPME_SOCKET_SOCKET_E)) {
 		return 0;
 	}
 
@@ -53,8 +55,14 @@ int BPF_PROG(socket_e, struct pt_regs *regs, long id) {
 
 SEC("tp_btf/sys_exit")
 int BPF_PROG(socket_x, struct pt_regs *regs, long ret) {
+	/* We need to keep this at the beginning of the program because otherwise we alter the state of
+	 * the ebpf registers causing a verifier issue.
+	 */
+	unsigned long args[3] = {0};
+	extract__network_args(args, 3, regs);
+
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, SOCKET_X_SIZE, PPME_SOCKET_SOCKET_X)) {
+	if(!ringbuf__reserve_space(&ringbuf, SOCKET_X_SIZE, PPME_SOCKET_SOCKET_X)) {
 		return 0;
 	}
 
@@ -62,7 +70,7 @@ int BPF_PROG(socket_x, struct pt_regs *regs, long ret) {
 
 	/*=============================== COLLECT PARAMETERS  ===========================*/
 
-	/* Parameter 1: res (type: PT_ERRNO)*/
+	/* Parameter 1: fd (type: PT_FD)*/
 	ringbuf__store_s64(&ringbuf, ret);
 
 	/* Just called once by our scap process */
@@ -85,6 +93,18 @@ int BPF_PROG(socket_x, struct pt_regs *regs, long ret) {
 		}
 	}
 
+	/* Parameter 2: domain (type: PT_ENUMFLAGS32) */
+	uint8_t domain = (uint8_t)args[0];
+	ringbuf__store_u32(&ringbuf, (uint32_t)socket_family_to_scap(domain));
+
+	/* Parameter 3: type (type: PT_UINT32) */
+	uint32_t type = (uint32_t)args[1];
+	ringbuf__store_u32(&ringbuf, type);
+
+	/* Parameter 4: proto (type: PT_UINT32) */
+	uint32_t proto = (uint32_t)args[2];
+	ringbuf__store_u32(&ringbuf, proto);
+
 	/*=============================== COLLECT PARAMETERS  ===========================*/
 
 	ringbuf__submit_event(&ringbuf);
