@@ -14,7 +14,7 @@
 SEC("tp_btf/sys_enter")
 int BPF_PROG(vfork_e, struct pt_regs *regs, long id) {
 	struct ringbuf_struct ringbuf;
-	if(!ringbuf__reserve_space(&ringbuf, ctx, VFORK_E_SIZE, PPME_SYSCALL_VFORK_20_E)) {
+	if(!ringbuf__reserve_space(&ringbuf, VFORK_E_SIZE, PPME_SYSCALL_VFORK_20_E)) {
 		return 0;
 	}
 
@@ -150,7 +150,7 @@ int BPF_PROG(vfork_x, struct pt_regs *regs, long ret) {
 	/* We have to split here the bpf program, otherwise, it is too large
 	 * for the verifier (limit 1000000 instructions).
 	 */
-	bpf_tail_call(ctx, &extra_event_prog_tail_table, T1_VFORK_X);
+	bpf_tail_call(ctx, &syscall_exit_extra_tail_table, T1_VFORK_X);
 	return 0;
 }
 
@@ -196,7 +196,7 @@ int BPF_PROG(t1_vfork_x, struct pt_regs *regs, long ret) {
 	/* We have to split here the bpf program, otherwise, it is too large
 	 * for the verifier (limit 1000000 instructions).
 	 */
-	bpf_tail_call(ctx, &extra_event_prog_tail_table, T2_VFORK_X);
+	bpf_tail_call(ctx, &syscall_exit_extra_tail_table, T2_VFORK_X);
 	return 0;
 }
 
@@ -218,7 +218,7 @@ int BPF_PROG(t2_vfork_x, struct pt_regs *regs, long ret) {
 
 	auxmap__finalize_event_header(auxmap);
 
-	auxmap__submit_event(auxmap, ctx);
+	auxmap__submit_event(auxmap);
 	return 0;
 }
 
