@@ -6,8 +6,7 @@
 #include <linux/sched.h>
 
 #ifdef __NR_clone3
-TEST(GenericTracepoints, sched_proc_fork_case_clone3)
-{
+TEST(GenericTracepoints, sched_proc_fork_case_clone3) {
 	auto evt_test = get_syscall_event_test(__NR_clone, EXIT_EVENT);
 
 	evt_test->enable_capture();
@@ -15,24 +14,22 @@ TEST(GenericTracepoints, sched_proc_fork_case_clone3)
 	/*=============================== TRIGGER SYSCALL  ===========================*/
 
 	/* Here we scan the parent just to obtain some info for the child */
-	struct proc_info info = {0};
+	struct proc_info info = {};
 	pid_t pid = ::getpid();
-	if(!get_proc_info(pid, &info))
-	{
+	if(!get_proc_info(pid, &info)) {
 		FAIL() << "Unable to get all the info from proc" << std::endl;
 	}
 
 	/* We need to use `SIGCHLD` otherwise the parent won't receive any signal
 	 * when the child terminates. We use `CLONE_FILES` just to test the flags.
 	 */
-	clone_args cl_args = {0};
+	clone_args cl_args = {};
 	cl_args.flags = CLONE_FILES;
 	cl_args.exit_signal = SIGCHLD;
 	pid_t ret_pid = syscall(__NR_clone3, &cl_args, sizeof(cl_args));
 
 	/* Child performs assertions on itself. */
-	if(ret_pid == 0)
-	{
+	if(ret_pid == 0) {
 		/* Child terminates immediately. */
 		exit(EXIT_SUCCESS);
 	}
@@ -41,10 +38,12 @@ TEST(GenericTracepoints, sched_proc_fork_case_clone3)
 
 	int status = 0;
 	int options = 0;
-	assert_syscall_state(SYSCALL_SUCCESS, "wait4", syscall(__NR_wait4, ret_pid, &status, options, NULL), NOT_EQUAL,
-			     -1);
-	if(__WEXITSTATUS(status) == EXIT_FAILURE || __WIFSIGNALED(status) != 0)
-	{
+	assert_syscall_state(SYSCALL_SUCCESS,
+	                     "wait4",
+	                     syscall(__NR_wait4, ret_pid, &status, options, NULL),
+	                     NOT_EQUAL,
+	                     -1);
+	if(__WEXITSTATUS(status) == EXIT_FAILURE || __WIFSIGNALED(status) != 0) {
 		FAIL() << "Something in the child failed." << std::endl;
 	}
 
@@ -54,8 +53,7 @@ TEST(GenericTracepoints, sched_proc_fork_case_clone3)
 
 	evt_test->assert_event_presence(ret_pid);
 
-	if(HasFatalFailure())
-	{
+	if(HasFatalFailure()) {
 		return;
 	}
 
@@ -110,8 +108,7 @@ TEST(GenericTracepoints, sched_proc_fork_case_clone3)
  * we should also have the `set_tid` field in struct `clone_args`
  */
 #ifdef CLONE_CLEAR_SIGHAND
-TEST(GenericTracepoints, sched_proc_fork_case_clone3_create_child_with_2_threads)
-{
+TEST(GenericTracepoints, sched_proc_fork_case_clone3_create_child_with_2_threads) {
 	auto evt_test = get_syscall_event_test(__NR_clone, EXIT_EVENT);
 
 	evt_test->enable_capture();
@@ -125,17 +122,16 @@ TEST(GenericTracepoints, sched_proc_fork_case_clone3_create_child_with_2_threads
 	pid_t p1_t1 = 61001;
 	pid_t p1_t2 = 61004;
 
-	clone_args cl_args_parent = {0};
+	clone_args cl_args_parent = {};
 	cl_args_parent.set_tid = (uint64_t)&p1_t1;
 	cl_args_parent.set_tid_size = 1;
 	cl_args_parent.exit_signal = SIGCHLD;
 	pid_t ret_pid = syscall(__NR_clone3, &cl_args_parent, sizeof(cl_args_parent));
 
 	/* Create a child process that will spawn a new thread */
-	if(ret_pid == 0)
-	{
+	if(ret_pid == 0) {
 		/* Spawn a new thread */
-		clone_args cl_args_child = {0};
+		clone_args cl_args_child = {};
 		cl_args_child.set_tid = (uint64_t)&p1_t2;
 		cl_args_child.set_tid_size = 1;
 		/* CLONE_PARENT has no additional effects if we are spawning a thread
@@ -144,8 +140,7 @@ TEST(GenericTracepoints, sched_proc_fork_case_clone3_create_child_with_2_threads
 		 */
 		cl_args_child.flags = CLONE_THREAD | CLONE_SIGHAND | CLONE_VM | CLONE_VFORK | CLONE_PARENT;
 		pid_t child_thread = syscall(__NR_clone3, &cl_args_child, sizeof(cl_args_child));
-		if(child_thread == 0)
-		{
+		if(child_thread == 0) {
 			exit(EXIT_SUCCESS);
 		}
 		exit(EXIT_SUCCESS);
@@ -155,11 +150,13 @@ TEST(GenericTracepoints, sched_proc_fork_case_clone3_create_child_with_2_threads
 
 	int status = 0;
 	int options = 0;
-	assert_syscall_state(SYSCALL_SUCCESS, "wait4", syscall(__NR_wait4, ret_pid, &status, options, NULL), NOT_EQUAL,
-			     -1);
+	assert_syscall_state(SYSCALL_SUCCESS,
+	                     "wait4",
+	                     syscall(__NR_wait4, ret_pid, &status, options, NULL),
+	                     NOT_EQUAL,
+	                     -1);
 
-	if(__WEXITSTATUS(status) == EXIT_FAILURE || __WIFSIGNALED(status) != 0)
-	{
+	if(__WEXITSTATUS(status) == EXIT_FAILURE || __WIFSIGNALED(status) != 0) {
 		FAIL() << "Something in the child failed." << std::endl;
 	}
 	/*=============================== TRIGGER SYSCALL  ===========================*/
@@ -168,8 +165,7 @@ TEST(GenericTracepoints, sched_proc_fork_case_clone3_create_child_with_2_threads
 
 	evt_test->assert_event_presence(p1_t2);
 
-	if(HasFatalFailure())
-	{
+	if(HasFatalFailure()) {
 		FAIL() << "There is a fatal failure in the child";
 	}
 
@@ -198,7 +194,9 @@ TEST(GenericTracepoints, sched_proc_fork_case_clone3_create_child_with_2_threads
 
 	/* Parameter 16: flags (type: PT_FLAGS32) */
 	/* Right now we cannot send `PPM_CL_CLONE_PARENT` in our `sched_proc_fork` hook */
-	evt_test->assert_numeric_param(16, (uint32_t)PPM_CL_CLONE_THREAD | PPM_CL_CLONE_SIGHAND | PPM_CL_CLONE_VM);
+	evt_test->assert_numeric_param(
+	        16,
+	        (uint32_t)PPM_CL_CLONE_THREAD | PPM_CL_CLONE_SIGHAND | PPM_CL_CLONE_VM);
 
 	/* Parameter 19: vtid (type: PT_PID) */
 	evt_test->assert_numeric_param(19, (int64_t)p1_t2);
@@ -211,8 +209,7 @@ TEST(GenericTracepoints, sched_proc_fork_case_clone3_create_child_with_2_threads
 	evt_test->assert_num_params_pushed(21);
 }
 
-TEST(GenericTracepoints, sched_proc_fork_case_clone3_child_clone_parent_flag)
-{
+TEST(GenericTracepoints, sched_proc_fork_case_clone3_child_clone_parent_flag) {
 	auto evt_test = get_syscall_event_test(__NR_clone, EXIT_EVENT);
 
 	evt_test->enable_capture();
@@ -226,26 +223,23 @@ TEST(GenericTracepoints, sched_proc_fork_case_clone3_child_clone_parent_flag)
 	pid_t p1_t1 = 61024;
 	pid_t p2_t1 = 60128;
 
-	clone_args cl_args_parent = {0};
+	clone_args cl_args_parent = {};
 	cl_args_parent.set_tid = (uint64_t)&p1_t1;
 	cl_args_parent.set_tid_size = 1;
 	cl_args_parent.exit_signal = SIGCHLD;
 	pid_t ret_pid = syscall(__NR_clone3, &cl_args_parent, sizeof(cl_args_parent));
 
-	if(ret_pid == 0)
-	{
-		clone_args cl_args_child = {0};
+	if(ret_pid == 0) {
+		clone_args cl_args_child = {};
 		cl_args_child.set_tid = (uint64_t)&p2_t1;
 		cl_args_child.set_tid_size = 1;
 		cl_args_child.flags = CLONE_PARENT;
 		cl_args_parent.exit_signal = SIGCHLD;
 		pid_t second_child = syscall(__NR_clone3, &cl_args_child, sizeof(cl_args_child));
-		if(second_child == 0)
-		{
+		if(second_child == 0) {
 			exit(EXIT_SUCCESS);
 		}
-		if(second_child == -1)
-		{
+		if(second_child == -1) {
 			exit(EXIT_FAILURE);
 		}
 		exit(EXIT_SUCCESS);
@@ -257,20 +251,25 @@ TEST(GenericTracepoints, sched_proc_fork_case_clone3_child_clone_parent_flag)
 	int options = 0;
 
 	/* Wait for the first child */
-	assert_syscall_state(SYSCALL_SUCCESS, "wait4", syscall(__NR_wait4, ret_pid, &status, options, NULL), NOT_EQUAL,
-			     -1);
+	assert_syscall_state(SYSCALL_SUCCESS,
+	                     "wait4",
+	                     syscall(__NR_wait4, ret_pid, &status, options, NULL),
+	                     NOT_EQUAL,
+	                     -1);
 
-	if(__WEXITSTATUS(status) == EXIT_FAILURE || __WIFSIGNALED(status) != 0)
-	{
+	if(__WEXITSTATUS(status) == EXIT_FAILURE || __WIFSIGNALED(status) != 0) {
 		FAIL() << "Something in the first child failed." << std::endl;
 	}
 
-	/* Since we are using the `CLONE_PARENT` flag the currect process is signaled also for the second child  */
-	assert_syscall_state(SYSCALL_SUCCESS, "wait4", syscall(__NR_wait4, p2_t1, &status, options, NULL), NOT_EQUAL,
-			     -1);
+	/* Since we are using the `CLONE_PARENT` flag the currect process is signaled also for the
+	 * second child  */
+	assert_syscall_state(SYSCALL_SUCCESS,
+	                     "wait4",
+	                     syscall(__NR_wait4, p2_t1, &status, options, NULL),
+	                     NOT_EQUAL,
+	                     -1);
 
-	if(__WEXITSTATUS(status) == EXIT_FAILURE || __WIFSIGNALED(status) != 0)
-	{
+	if(__WEXITSTATUS(status) == EXIT_FAILURE || __WIFSIGNALED(status) != 0) {
 		FAIL() << "Something in the second child failed." << std::endl;
 	}
 
@@ -280,8 +279,7 @@ TEST(GenericTracepoints, sched_proc_fork_case_clone3_child_clone_parent_flag)
 
 	evt_test->assert_event_presence(p2_t1);
 
-	if(HasFatalFailure())
-	{
+	if(HasFatalFailure()) {
 		return;
 	}
 
@@ -320,8 +318,7 @@ TEST(GenericTracepoints, sched_proc_fork_case_clone3_child_clone_parent_flag)
 }
 
 /* here we test only the child case because the caller won't use this tracepoint */
-TEST(GenericTracepoints, sched_proc_fork_case_clone3_child_new_namespace_from_child)
-{
+TEST(GenericTracepoints, sched_proc_fork_case_clone3_child_new_namespace_from_child) {
 	auto evt_test = get_syscall_event_test(__NR_clone, EXIT_EVENT);
 
 	evt_test->enable_capture();
@@ -330,15 +327,14 @@ TEST(GenericTracepoints, sched_proc_fork_case_clone3_child_new_namespace_from_ch
 
 	/* Here we create a child process in a new namespace. */
 	pid_t p1_t1[2] = {1, 61032};
-	clone_args cl_args = {0};
+	clone_args cl_args = {};
 	cl_args.set_tid = (uint64_t)&p1_t1;
 	cl_args.set_tid_size = 2;
 	cl_args.flags = CLONE_NEWPID;
 	cl_args.exit_signal = SIGCHLD;
 	pid_t ret_pid = syscall(__NR_clone3, &cl_args, sizeof(cl_args));
 
-	if(ret_pid == 0)
-	{
+	if(ret_pid == 0) {
 		/* Child terminates immediately. */
 		exit(EXIT_SUCCESS);
 	}
@@ -347,11 +343,13 @@ TEST(GenericTracepoints, sched_proc_fork_case_clone3_child_new_namespace_from_ch
 
 	int status = 0;
 	int options = 0;
-	assert_syscall_state(SYSCALL_SUCCESS, "wait4", syscall(__NR_wait4, ret_pid, &status, options, NULL), NOT_EQUAL,
-			     -1);
+	assert_syscall_state(SYSCALL_SUCCESS,
+	                     "wait4",
+	                     syscall(__NR_wait4, ret_pid, &status, options, NULL),
+	                     NOT_EQUAL,
+	                     -1);
 
-	if(__WEXITSTATUS(status) == EXIT_FAILURE || __WIFSIGNALED(status) != 0)
-	{
+	if(__WEXITSTATUS(status) == EXIT_FAILURE || __WIFSIGNALED(status) != 0) {
 		FAIL() << "Something in the child failed." << std::endl;
 	}
 
@@ -361,8 +359,7 @@ TEST(GenericTracepoints, sched_proc_fork_case_clone3_child_new_namespace_from_ch
 
 	evt_test->assert_event_presence(ret_pid);
 
-	if(HasFatalFailure())
-	{
+	if(HasFatalFailure()) {
 		return;
 	}
 
@@ -399,8 +396,7 @@ TEST(GenericTracepoints, sched_proc_fork_case_clone3_child_new_namespace_from_ch
 	evt_test->assert_num_params_pushed(21);
 }
 
-TEST(GenericTracepoints, sched_proc_fork_case_clone3_child_new_namespace_create_thread)
-{
+TEST(GenericTracepoints, sched_proc_fork_case_clone3_child_new_namespace_create_thread) {
 	auto evt_test = get_syscall_event_test(__NR_clone, EXIT_EVENT);
 
 	evt_test->enable_capture();
@@ -415,23 +411,21 @@ TEST(GenericTracepoints, sched_proc_fork_case_clone3_child_new_namespace_create_
 	/* Please note that a process can have the same pid number in different namespaces */
 	pid_t p1_t2[2] = {61036, 61036};
 
-	clone_args cl_args = {0};
+	clone_args cl_args = {};
 	cl_args.set_tid = (uint64_t)&p1_t1;
 	cl_args.set_tid_size = 2;
 	cl_args.flags = CLONE_NEWPID;
 	cl_args.exit_signal = SIGCHLD;
 	pid_t ret_pid = syscall(__NR_clone3, &cl_args, sizeof(cl_args));
 
-	if(ret_pid == 0)
-	{
+	if(ret_pid == 0) {
 		/* Spawn a new thread */
-		clone_args cl_args_child = {0};
+		clone_args cl_args_child = {};
 		cl_args_child.set_tid = (uint64_t)&p1_t2;
 		cl_args_child.set_tid_size = 2;
 		cl_args_child.flags = CLONE_THREAD | CLONE_SIGHAND | CLONE_VM | CLONE_VFORK;
 		pid_t child_thread = syscall(__NR_clone3, &cl_args_child, sizeof(cl_args_child));
-		if(child_thread == 0)
-		{
+		if(child_thread == 0) {
 			exit(EXIT_SUCCESS);
 		}
 		exit(EXIT_SUCCESS);
@@ -441,11 +435,13 @@ TEST(GenericTracepoints, sched_proc_fork_case_clone3_child_new_namespace_create_
 
 	int status = 0;
 	int options = 0;
-	assert_syscall_state(SYSCALL_SUCCESS, "wait4", syscall(__NR_wait4, ret_pid, &status, options, NULL), NOT_EQUAL,
-			     -1);
+	assert_syscall_state(SYSCALL_SUCCESS,
+	                     "wait4",
+	                     syscall(__NR_wait4, ret_pid, &status, options, NULL),
+	                     NOT_EQUAL,
+	                     -1);
 
-	if(__WEXITSTATUS(status) == EXIT_FAILURE || __WIFSIGNALED(status) != 0)
-	{
+	if(__WEXITSTATUS(status) == EXIT_FAILURE || __WIFSIGNALED(status) != 0) {
 		FAIL() << "Something in the child failed." << std::endl;
 	}
 
@@ -455,8 +451,7 @@ TEST(GenericTracepoints, sched_proc_fork_case_clone3_child_new_namespace_create_
 
 	evt_test->assert_event_presence(p1_t2[1]);
 
-	if(HasFatalFailure())
-	{
+	if(HasFatalFailure()) {
 		return;
 	}
 
@@ -480,8 +475,9 @@ TEST(GenericTracepoints, sched_proc_fork_case_clone3_child_new_namespace_create_
 
 	/* Parameter 16: flags (type: PT_FLAGS32) */
 	/* we cannot get the `PPM_CL_CLONE_VFORK` flag here */
-	evt_test->assert_numeric_param(16, (uint32_t)PPM_CL_CLONE_THREAD | PPM_CL_CLONE_SIGHAND | PPM_CL_CLONE_VM |
-						   PPM_CL_CHILD_IN_PIDNS);
+	evt_test->assert_numeric_param(16,
+	                               (uint32_t)PPM_CL_CLONE_THREAD | PPM_CL_CLONE_SIGHAND |
+	                                       PPM_CL_CLONE_VM | PPM_CL_CHILD_IN_PIDNS);
 
 	/* Parameter 19: vtid (type: PT_PID) */
 	evt_test->assert_numeric_param(19, (int64_t)p1_t2[0]);
@@ -498,8 +494,7 @@ TEST(GenericTracepoints, sched_proc_fork_case_clone3_child_new_namespace_create_
 #endif /* __NR_clone3 */
 
 #ifdef __NR_clone
-TEST(GenericTracepoints, sched_proc_fork_case_clone)
-{
+TEST(GenericTracepoints, sched_proc_fork_case_clone) {
 	auto evt_test = get_syscall_event_test(__NR_clone, EXIT_EVENT);
 
 	evt_test->enable_capture();
@@ -507,10 +502,9 @@ TEST(GenericTracepoints, sched_proc_fork_case_clone)
 	/*=============================== TRIGGER SYSCALL  ===========================*/
 
 	/* Here we scan the parent just to obtain some info for the child */
-	struct proc_info info = {0};
+	struct proc_info info = {};
 	pid_t pid = ::getpid();
-	if(!get_proc_info(pid, &info))
-	{
+	if(!get_proc_info(pid, &info)) {
 		FAIL() << "Unable to get all the info from proc" << std::endl;
 	}
 
@@ -526,14 +520,13 @@ TEST(GenericTracepoints, sched_proc_fork_case_clone)
 
 #ifdef __s390x__
 	ret_pid = syscall(__NR_clone, newsp, clone_flags, &parent_tid, &child_tid, tls);
-#elif defined(__aarch64__) || defined(__riscv)
+#elif defined(__aarch64__) || defined(__riscv) || defined(__loongarch64) /*kernel clone.S*/
 	ret_pid = syscall(__NR_clone, clone_flags, newsp, &parent_tid, tls, &child_tid);
 #else
 	ret_pid = syscall(__NR_clone, clone_flags, newsp, &parent_tid, &child_tid, tls);
 #endif
 
-	if(ret_pid == 0)
-	{
+	if(ret_pid == 0) {
 		/* Child terminates immediately. */
 		exit(EXIT_SUCCESS);
 	}
@@ -542,10 +535,12 @@ TEST(GenericTracepoints, sched_proc_fork_case_clone)
 
 	int status = 0;
 	int options = 0;
-	assert_syscall_state(SYSCALL_SUCCESS, "wait4", syscall(__NR_wait4, ret_pid, &status, options, NULL), NOT_EQUAL,
-			     -1);
-	if(__WEXITSTATUS(status) == EXIT_FAILURE || __WIFSIGNALED(status) != 0)
-	{
+	assert_syscall_state(SYSCALL_SUCCESS,
+	                     "wait4",
+	                     syscall(__NR_wait4, ret_pid, &status, options, NULL),
+	                     NOT_EQUAL,
+	                     -1);
+	if(__WEXITSTATUS(status) == EXIT_FAILURE || __WIFSIGNALED(status) != 0) {
 		FAIL() << "Something in the child failed." << std::endl;
 	}
 
@@ -555,8 +550,7 @@ TEST(GenericTracepoints, sched_proc_fork_case_clone)
 
 	evt_test->assert_event_presence(ret_pid);
 
-	if(HasFatalFailure())
-	{
+	if(HasFatalFailure()) {
 		return;
 	}
 
@@ -609,8 +603,7 @@ TEST(GenericTracepoints, sched_proc_fork_case_clone)
 #endif /* __NR_clone */
 
 #ifdef __NR_fork
-TEST(GenericTracepoints, sched_proc_fork_case_fork)
-{
+TEST(GenericTracepoints, sched_proc_fork_case_fork) {
 	auto evt_test = get_syscall_event_test(__NR_clone, EXIT_EVENT);
 
 	evt_test->enable_capture();
@@ -618,17 +611,15 @@ TEST(GenericTracepoints, sched_proc_fork_case_fork)
 	/*=============================== TRIGGER SYSCALL  ===========================*/
 
 	/* Here we scan the parent just to obtain some info for the child */
-	struct proc_info info = {0};
+	struct proc_info info = {};
 	pid_t pid = ::getpid();
-	if(!get_proc_info(pid, &info))
-	{
+	if(!get_proc_info(pid, &info)) {
 		FAIL() << "Unable to get all the info from proc" << std::endl;
 	}
 
 	pid_t ret_pid = syscall(__NR_fork);
 
-	if(ret_pid == 0)
-	{
+	if(ret_pid == 0) {
 		/* Child terminates immediately. */
 		exit(EXIT_SUCCESS);
 	}
@@ -637,11 +628,13 @@ TEST(GenericTracepoints, sched_proc_fork_case_fork)
 
 	int status = 0;
 	int options = 0;
-	assert_syscall_state(SYSCALL_SUCCESS, "wait4", syscall(__NR_wait4, ret_pid, &status, options, NULL), NOT_EQUAL,
-			     -1);
+	assert_syscall_state(SYSCALL_SUCCESS,
+	                     "wait4",
+	                     syscall(__NR_wait4, ret_pid, &status, options, NULL),
+	                     NOT_EQUAL,
+	                     -1);
 
-	if(__WEXITSTATUS(status) == EXIT_FAILURE || __WIFSIGNALED(status) != 0)
-	{
+	if(__WEXITSTATUS(status) == EXIT_FAILURE || __WIFSIGNALED(status) != 0) {
 		FAIL() << "Something in the child failed." << std::endl;
 	}
 
@@ -651,8 +644,7 @@ TEST(GenericTracepoints, sched_proc_fork_case_fork)
 
 	evt_test->assert_event_presence(ret_pid);
 
-	if(HasFatalFailure())
-	{
+	if(HasFatalFailure()) {
 		return;
 	}
 
