@@ -4,8 +4,7 @@
 
 #include <linux/sched.h>
 
-TEST(SyscallEnter, clone3E)
-{
+TEST(SyscallEnter, clone3E) {
 	auto evt_test = get_syscall_event_test(__NR_clone3, ENTER_EVENT);
 
 	evt_test->enable_capture();
@@ -15,7 +14,9 @@ TEST(SyscallEnter, clone3E)
 	/* flags are invalid so the syscall will fail. */
 	clone_args cl_args = {};
 	cl_args.flags = (unsigned long)-1;
-	assert_syscall_state(SYSCALL_FAILURE, "clone3", syscall(__NR_clone3, &cl_args, sizeof(cl_args)));
+	assert_syscall_state(SYSCALL_FAILURE,
+	                     "clone3",
+	                     syscall(__NR_clone3, &cl_args, sizeof(cl_args)));
 
 	/*=============================== TRIGGER SYSCALL  ===========================*/
 
@@ -23,8 +24,7 @@ TEST(SyscallEnter, clone3E)
 
 	evt_test->assert_event_presence();
 
-	if(HasFatalFailure())
-	{
+	if(HasFatalFailure()) {
 		return;
 	}
 
