@@ -2,8 +2,7 @@
 #include "../../helpers/file_opener.h"
 
 #if defined(__NR_dup3) && defined(__NR_openat) && defined(__NR_close)
-TEST(SyscallEnter, dup3E)
-{
+TEST(SyscallEnter, dup3E) {
 	auto evt_test = get_syscall_event_test(__NR_dup3, ENTER_EVENT);
 
 	evt_test->enable_capture();
@@ -28,8 +27,7 @@ TEST(SyscallEnter, dup3E)
 
 	evt_test->assert_event_presence();
 
-	if(HasFatalFailure())
-	{
+	if(HasFatalFailure()) {
 		return;
 	}
 
