@@ -4,8 +4,7 @@
 
 #include <fcntl.h>
 
-TEST(SyscallEnter, fcntlE)
-{
+TEST(SyscallEnter, fcntlE) {
 	auto evt_test = get_syscall_event_test(__NR_fcntl, ENTER_EVENT);
 
 	evt_test->enable_capture();
@@ -23,8 +22,7 @@ TEST(SyscallEnter, fcntlE)
 
 	evt_test->assert_event_presence();
 
-	if(HasFatalFailure())
-	{
+	if(HasFatalFailure()) {
 		return;
 	}
 
