@@ -1,8 +1,7 @@
 #include "../../event_class/event_class.h"
 
 #if defined(__NR_fork) && defined(__NR_wait4)
-TEST(SyscallEnter, forkE)
-{
+TEST(SyscallEnter, forkE) {
 	auto evt_test = get_syscall_event_test(__NR_fork, ENTER_EVENT);
 
 	evt_test->enable_capture();
@@ -10,8 +9,7 @@ TEST(SyscallEnter, forkE)
 	/*=============================== TRIGGER SYSCALL ===========================*/
 
 	pid_t ret_pid = syscall(__NR_fork);
-	if(ret_pid == 0)
-	{
+	if(ret_pid == 0) {
 		/* Child terminates immediately. */
 		exit(EXIT_SUCCESS);
 	}
@@ -20,7 +18,11 @@ TEST(SyscallEnter, forkE)
 
 	int status = 0;
 	int options = 0;
-	assert_syscall_state(SYSCALL_SUCCESS, "wait4", syscall(__NR_wait4, ret_pid, &status, options, NULL), NOT_EQUAL, -1);
+	assert_syscall_state(SYSCALL_SUCCESS,
+	                     "wait4",
+	                     syscall(__NR_wait4, ret_pid, &status, options, NULL),
+	                     NOT_EQUAL,
+	                     -1);
 
 	/*=============================== TRIGGER SYSCALL ===========================*/
 
@@ -28,8 +30,7 @@ TEST(SyscallEnter, forkE)
 
 	evt_test->assert_event_presence();
 
-	if(HasFatalFailure())
-	{
+	if(HasFatalFailure()) {
 		return;
 	}
 
