@@ -5,8 +5,7 @@
 #include <sys/time.h>
 
 #ifdef __NR_futex
-TEST(SyscallEnter, futexE)
-{
+TEST(SyscallEnter, futexE) {
 	auto evt_test = get_syscall_event_test(__NR_futex, ENTER_EVENT);
 
 	evt_test->enable_capture();
@@ -16,7 +15,9 @@ TEST(SyscallEnter, futexE)
 	uint32_t futex_word;
 	int futex_op = FUTEX_PRIVATE_FLAG;
 	uint32_t val = 7;
-	assert_syscall_state(SYSCALL_FAILURE, "futex", syscall(__NR_futex, &futex_word, futex_op, val, NULL, NULL, 0));
+	assert_syscall_state(SYSCALL_FAILURE,
+	                     "futex",
+	                     syscall(__NR_futex, &futex_word, futex_op, val, NULL, NULL, 0));
 
 	/*=============================== TRIGGER SYSCALL ===========================*/
 
@@ -24,8 +25,7 @@ TEST(SyscallEnter, futexE)
 
 	evt_test->assert_event_presence();
 
-	if(HasFatalFailure())
-	{
+	if(HasFatalFailure()) {
 		return;
 	}
 
