@@ -1,8 +1,7 @@
 #include "../../event_class/event_class.h"
 
 #ifdef __NR_geteuid
-TEST(SyscallEnter, geteuidE)
-{
+TEST(SyscallEnter, geteuidE) {
 	auto evt_test = get_syscall_event_test(__NR_geteuid, ENTER_EVENT);
 
 	evt_test->enable_capture();
@@ -17,8 +16,7 @@ TEST(SyscallEnter, geteuidE)
 
 	evt_test->assert_event_presence();
 
-	if(HasFatalFailure())
-	{
+	if(HasFatalFailure()) {
 		return;
 	}
 
