@@ -4,8 +4,7 @@
 
 #include <netdb.h>
 
-TEST(SyscallEnter, getsockoptE)
-{
+TEST(SyscallEnter, getsockoptE) {
 	auto evt_test = get_syscall_event_test(__NR_getsockopt, ENTER_EVENT);
 
 	evt_test->enable_capture();
@@ -17,7 +16,10 @@ TEST(SyscallEnter, getsockoptE)
 	int option_name = 0;
 	int option_value = 0;
 	socklen_t option_len = 0;
-	assert_syscall_state(SYSCALL_FAILURE, "getsockopt", syscall(__NR_getsockopt, socket_fd, level, option_name, &option_value, &option_len));
+	assert_syscall_state(
+	        SYSCALL_FAILURE,
+	        "getsockopt",
+	        syscall(__NR_getsockopt, socket_fd, level, option_name, &option_value, &option_len));
 
 	/*=============================== TRIGGER SYSCALL ===========================*/
 
@@ -25,8 +27,7 @@ TEST(SyscallEnter, getsockoptE)
 
 	evt_test->assert_event_presence();
 
-	if(HasFatalFailure())
-	{
+	if(HasFatalFailure()) {
 		return;
 	}
 
