@@ -1,8 +1,7 @@
 #include "../../event_class/event_class.h"
 
 #ifdef __NR_mkdir
-TEST(SyscallEnter, mkdirE)
-{
+TEST(SyscallEnter, mkdirE) {
 	auto evt_test = get_syscall_event_test(__NR_mkdir, ENTER_EVENT);
 
 	evt_test->enable_capture();
@@ -22,8 +21,7 @@ TEST(SyscallEnter, mkdirE)
 
 	evt_test->assert_event_presence();
 
-	if(HasFatalFailure())
-	{
+	if(HasFatalFailure()) {
 		return;
 	}
 
