@@ -1,21 +1,21 @@
 #include "../../event_class/event_class.h"
 
 #ifdef __NR_newfstatat
-TEST(SyscallEnter, newfstatatE)
-{
+TEST(SyscallEnter, newfstatatE) {
 	auto evt_test = get_syscall_event_test(__NR_newfstatat, ENTER_EVENT);
 	evt_test->enable_capture();
 
 	/*=============================== TRIGGER SYSCALL  ===========================*/
 
-	//int dirfd = AT_FDCWD;
+	// int dirfd = AT_FDCWD;
 	int dirfd = -1;
 	const char* pathname = "mock_path";
 	struct stat buffer;
 	int flags = AT_EMPTY_PATH | AT_NO_AUTOMOUNT | AT_SYMLINK_NOFOLLOW;
 
-	assert_syscall_state(SYSCALL_FAILURE, "newfstatat", syscall(__NR_newfstatat, dirfd, pathname, &buffer, flags));
-
+	assert_syscall_state(SYSCALL_FAILURE,
+	                     "newfstatat",
+	                     syscall(__NR_newfstatat, dirfd, pathname, &buffer, flags));
 
 	/*=============================== TRIGGER SYSCALL  ===========================*/
 
@@ -23,8 +23,7 @@ TEST(SyscallEnter, newfstatatE)
 
 	evt_test->assert_event_presence();
 
-	if(HasFatalFailure())
-	{
+	if(HasFatalFailure()) {
 		return;
 	}
 
@@ -39,6 +38,5 @@ TEST(SyscallEnter, newfstatatE)
 	/*=============================== ASSERT PARAMETERS  ===========================*/
 
 	evt_test->assert_num_params_pushed(0);
-
 }
-#endif
\ No newline at end of file
+#endif
