@@ -2,8 +2,7 @@
 
 #ifdef __NR_preadv
 
-TEST(SyscallEnter, preadvE)
-{
+TEST(SyscallEnter, preadvE) {
 	auto evt_test = get_syscall_event_test(__NR_preadv, ENTER_EVENT);
 
 	evt_test->enable_capture();
@@ -21,8 +20,7 @@ TEST(SyscallEnter, preadvE)
 
 	evt_test->assert_event_presence();
 
-	if(HasFatalFailure())
-	{
+	if(HasFatalFailure()) {
 		return;
 	}
 
