@@ -4,8 +4,7 @@
 
 #include <sys/resource.h>
 
-TEST(SyscallEnter, prlimit64E)
-{
+TEST(SyscallEnter, prlimit64E) {
 	auto evt_test = get_syscall_event_test(__NR_prlimit64, ENTER_EVENT);
 
 	evt_test->enable_capture();
@@ -17,7 +16,9 @@ TEST(SyscallEnter, prlimit64E)
 	/* We need to put the pid to `-1` otherwise the syscall won't fail on some machines. */
 	pid_t pid = -1;
 	int resource = RLIMIT_NOFILE;
-	assert_syscall_state(SYSCALL_FAILURE, "prlimit64", syscall(__NR_prlimit64, pid, resource, &new_rlimit, &old_rlimit));
+	assert_syscall_state(SYSCALL_FAILURE,
+	                     "prlimit64",
+	                     syscall(__NR_prlimit64, pid, resource, &new_rlimit, &old_rlimit));
 
 	/*=============================== TRIGGER SYSCALL ===========================*/
 
@@ -25,8 +26,7 @@ TEST(SyscallEnter, prlimit64E)
 
 	evt_test->assert_event_presence();
 
-	if(HasFatalFailure())
-	{
+	if(HasFatalFailure()) {
 		return;
 	}
 
