@@ -1,8 +1,7 @@
 #include "../../event_class/event_class.h"
 
 #ifdef __NR_renameat
-TEST(SyscallEnter, renameatE)
-{
+TEST(SyscallEnter, renameatE) {
 	auto evt_test = get_syscall_event_test(__NR_renameat, ENTER_EVENT);
 
 	evt_test->enable_capture();
@@ -13,7 +12,9 @@ TEST(SyscallEnter, renameatE)
 	int32_t new_fd = 0;
 	const char* old_path = NULL;
 	const char* new_path = NULL;
-	assert_syscall_state(SYSCALL_FAILURE, "renameat", syscall(__NR_renameat, old_fd, old_path, new_fd, new_path));
+	assert_syscall_state(SYSCALL_FAILURE,
+	                     "renameat",
+	                     syscall(__NR_renameat, old_fd, old_path, new_fd, new_path));
 
 	/*=============================== TRIGGER SYSCALL ===========================*/
 
@@ -21,8 +22,7 @@ TEST(SyscallEnter, renameatE)
 
 	evt_test->assert_event_presence();
 
-	if(HasFatalFailure())
-	{
+	if(HasFatalFailure()) {
 		return;
 	}
 
