@@ -6,8 +6,7 @@
 #include <sys/ipc.h>
 #include <sys/sem.h>
 
-TEST(SyscallEnter, semgetE)
-{
+TEST(SyscallEnter, semgetE) {
 	auto evt_test = get_syscall_event_test(__NR_semget, ENTER_EVENT);
 
 	evt_test->enable_capture();
@@ -25,8 +24,7 @@ TEST(SyscallEnter, semgetE)
 
 	evt_test->assert_event_presence();
 
-	if(HasFatalFailure())
-	{
+	if(HasFatalFailure()) {
 		return;
 	}
 
@@ -49,4 +47,4 @@ TEST(SyscallEnter, semgetE)
 
 	evt_test->assert_num_params_pushed(3);
 }
-#endif
\ No newline at end of file
+#endif
