@@ -1,8 +1,7 @@
 #include "../../event_class/event_class.h"
 
 #ifdef __NR_tgkill
-TEST(SyscallEnter, tgkillE)
-{
+TEST(SyscallEnter, tgkillE) {
 	auto evt_test = get_syscall_event_test(__NR_tgkill, ENTER_EVENT);
 
 	evt_test->enable_capture();
@@ -15,7 +14,9 @@ TEST(SyscallEnter, tgkillE)
 	int32_t mock_tgid = 0;
 	int32_t mock_tid = 0;
 	int32_t signal = 0;
-	assert_syscall_state(SYSCALL_FAILURE, "tgkill", syscall(__NR_tgkill, mock_tgid, mock_tid, signal));
+	assert_syscall_state(SYSCALL_FAILURE,
+	                     "tgkill",
+	                     syscall(__NR_tgkill, mock_tgid, mock_tid, signal));
 
 	/*=============================== TRIGGER SYSCALL ===========================*/
 
@@ -23,8 +24,7 @@ TEST(SyscallEnter, tgkillE)
 
 	evt_test->assert_event_presence();
 
-	if(HasFatalFailure())
-	{
+	if(HasFatalFailure()) {
 		return;
 	}
 
