@@ -4,8 +4,7 @@
 
 #include <sched.h>
 
-TEST(SyscallEnter, unshareE)
-{
+TEST(SyscallEnter, unshareE) {
 	auto evt_test = get_syscall_event_test(__NR_unshare, ENTER_EVENT);
 
 	evt_test->enable_capture();
@@ -26,8 +25,7 @@ TEST(SyscallEnter, unshareE)
 
 	evt_test->assert_event_presence();
 
-	if(HasFatalFailure())
-	{
+	if(HasFatalFailure()) {
 		return;
 	}
 
