@@ -1,8 +1,7 @@
 #include "../../event_class/event_class.h"
 
 #ifdef __NR_chdir
-TEST(SyscallExit, chdirX)
-{
+TEST(SyscallExit, chdirX) {
 	auto evt_test = get_syscall_event_test(__NR_chdir, EXIT_EVENT);
 
 	evt_test->enable_capture();
@@ -25,8 +24,7 @@ TEST(SyscallExit, chdirX)
 
 	evt_test->assert_event_presence();
 
-	if(HasFatalFailure())
-	{
+	if(HasFatalFailure()) {
 		return;
 	}
 
