@@ -1,9 +1,7 @@
 #include "../../event_class/event_class.h"
 
 #ifdef __NR_chroot
-TEST(SyscallExit, chrootX)
-{
-
+TEST(SyscallExit, chrootX) {
 	auto evt_test = get_syscall_event_test(__NR_chroot, EXIT_EVENT);
 
 	evt_test->enable_capture();
@@ -20,8 +18,7 @@ TEST(SyscallExit, chrootX)
 
 	evt_test->assert_event_presence();
 
-	if(HasFatalFailure())
-	{
+	if(HasFatalFailure()) {
 		return;
 	}
 
