@@ -1,8 +1,7 @@
 #include "../../event_class/event_class.h"
 
 #ifdef __NR_epoll_wait
-TEST(SyscallExit, epoll_waitX)
-{
+TEST(SyscallExit, epoll_waitX) {
 	auto evt_test = get_syscall_event_test(__NR_epoll_wait, EXIT_EVENT);
 
 	evt_test->enable_capture();
@@ -13,7 +12,9 @@ TEST(SyscallExit, epoll_waitX)
 	void* events = NULL;
 	int maxevents = -1;
 	int timeout = 0;
-	assert_syscall_state(SYSCALL_FAILURE, "epoll_wait", syscall(__NR_epoll_wait, epfd, events, maxevents, timeout));
+	assert_syscall_state(SYSCALL_FAILURE,
+	                     "epoll_wait",
+	                     syscall(__NR_epoll_wait, epfd, events, maxevents, timeout));
 	int64_t errno_value = -errno;
 
 	/*=============================== TRIGGER SYSCALL  ===========================*/
@@ -22,8 +23,7 @@ TEST(SyscallExit, epoll_waitX)
 
 	evt_test->assert_event_presence();
 
-	if(HasFatalFailure())
-	{
+	if(HasFatalFailure()) {
 		return;
 	}
 
