@@ -1,8 +1,7 @@
 #include "../../event_class/event_class.h"
 
 #if defined(__NR_eventfd) && defined(__NR_close)
-TEST(SyscallExit, eventfdX)
-{
+TEST(SyscallExit, eventfdX) {
 	auto evt_test = get_syscall_event_test(__NR_eventfd, EXIT_EVENT);
 
 	evt_test->enable_capture();
@@ -20,8 +19,7 @@ TEST(SyscallExit, eventfdX)
 
 	evt_test->assert_event_presence();
 
-	if(HasFatalFailure())
-	{
+	if(HasFatalFailure()) {
 		return;
 	}
 
