@@ -206,9 +206,15 @@ TEST(SyscallExit, execveatX_failure) {
 	 * executable */
 	evt_test->assert_charbuf_param(28, info.exepath);
 
+	/* Parameter 29: pgid (type: PT_PID) */
+	evt_test->assert_numeric_param(29, (int64_t)info.pgid);
+
+	/* Parameter 30: egid (type: PT_GID) */
+	evt_test->assert_numeric_param(30, (uint32_t)getegid(), EQUAL);
+
 	/*=============================== ASSERT PARAMETERS  ===========================*/
 
-	evt_test->assert_num_params_pushed(28);
+	evt_test->assert_num_params_pushed(30);
 }
 
 /* All architectures return an `EXECVEAT_X` event when the syscall fails, but only
@@ -372,9 +378,12 @@ TEST(SyscallExit, execveatX_correct_exit) {
 	/* Parameter 28: trusted_exepath (type: PT_FSPATH) */
 	evt_test->assert_charbuf_param(28, pathname);
 
+	/* Parameter 30: egid (type: PT_GID) */
+	evt_test->assert_numeric_param(30, (uint32_t)getegid(), EQUAL);
+
 	/*=============================== ASSERT PARAMETERS  ===========================*/
 
-	evt_test->assert_num_params_pushed(28);
+	evt_test->assert_num_params_pushed(30);
 #else
 	/* We search for a child event. */
 	evt_test->assert_event_absence(ret_pid);
@@ -502,9 +511,12 @@ TEST(SyscallExit, execveatX_execve_exit) {
 	/* Parameter 28: trusted_exepath (type: PT_FSPATH) */
 	evt_test->assert_charbuf_param(28, pathname);
 
+	/* Parameter 30: egid (type: PT_GID) */
+	evt_test->assert_numeric_param(30, (uint32_t)getegid(), EQUAL);
+
 	/*=============================== ASSERT PARAMETERS  ===========================*/
 
-	evt_test->assert_num_params_pushed(28);
+	evt_test->assert_num_params_pushed(30);
 #endif
 }
 
@@ -600,7 +612,7 @@ TEST(SyscallExit, execveatX_execve_exit_comm_equal_to_fd) {
 
 	/*=============================== ASSERT PARAMETERS  ===========================*/
 
-	evt_test->assert_num_params_pushed(28);
+	evt_test->assert_num_params_pushed(30);
 #endif
 }
 
@@ -704,11 +716,9 @@ TEST(SyscallExit, execveatX_success_memfd) {
 	/* Parameter 28: trusted_exepath (type: PT_FSPATH) */
 	/* In the kmod, we use the "d_path" helper while in BPF we reconstruct the path
 	 * by hand so the result is a little bit different.
-	 * Please note that in the kernel module, we remove the " (deleted)" suffix while
-	 * in BPF we don't add it at all.
 	 */
 	if(evt_test->is_kmod_engine()) {
-		evt_test->assert_charbuf_param(28, "/memfd:malware");
+		evt_test->assert_charbuf_param(28, "/memfd:malware (deleted)");
 	} else {
 		/* In BPF drivers we don't have the correct result but we can reconstruct part of it */
 		evt_test->assert_charbuf_param(28, "memfd:malware");
@@ -716,7 +726,7 @@ TEST(SyscallExit, execveatX_success_memfd) {
 
 	/*=============================== ASSERT PARAMETERS  ===========================*/
 
-	evt_test->assert_num_params_pushed(28);
+	evt_test->assert_num_params_pushed(30);
 #else
 	/* We search for a child event. */
 	evt_test->assert_event_absence(ret_pid);
