@@ -2,8 +2,7 @@
 
 #ifdef __NR_kill
 
-TEST(SyscallExit, killX)
-{
+TEST(SyscallExit, killX) {
 	auto evt_test = get_syscall_event_test(__NR_kill, EXIT_EVENT);
 
 	evt_test->enable_capture();
@@ -17,7 +16,11 @@ TEST(SyscallExit, killX)
 	 */
 	int32_t mock_pid = 0;
 	int32_t signal = 0;
-	assert_syscall_state(SYSCALL_SUCCESS, "kill", syscall(__NR_kill, mock_pid, signal), NOT_EQUAL, -1);
+	assert_syscall_state(SYSCALL_SUCCESS,
+	                     "kill",
+	                     syscall(__NR_kill, mock_pid, signal),
+	                     NOT_EQUAL,
+	                     -1);
 
 	/*=============================== TRIGGER SYSCALL ===========================*/
 
@@ -25,8 +28,7 @@ TEST(SyscallExit, killX)
 
 	evt_test->assert_event_presence();
 
-	if(HasFatalFailure())
-	{
+	if(HasFatalFailure()) {
 		return;
 	}
 
