@@ -1,8 +1,7 @@
 #include "../../event_class/event_class.h"
 #if defined(__NR_mknod)
 #include <sys/sysmacros.h>
-TEST(SyscallEnter, mknodE_failure)
-{
+TEST(SyscallEnter, mknodE_failure) {
 	auto evt_test = get_syscall_event_test(__NR_mknod, ENTER_EVENT);
 	evt_test->enable_capture();
 
@@ -12,8 +11,9 @@ TEST(SyscallEnter, mknodE_failure)
 
 	uint32_t mode = 0060000 | 0666;
 	uint32_t dev = 61440;
-	assert_syscall_state(SYSCALL_FAILURE, "mknod", syscall(__NR_mknod, (void *)(path), (mode_t)mode, (dev_t)dev));
-
+	assert_syscall_state(SYSCALL_FAILURE,
+	                     "mknod",
+	                     syscall(__NR_mknod, (void *)(path), (mode_t)mode, (dev_t)dev));
 
 	/*=============================== TRIGGER SYSCALL  ===========================*/
 
@@ -21,8 +21,7 @@ TEST(SyscallEnter, mknodE_failure)
 
 	evt_test->assert_event_presence();
 
-	if(HasFatalFailure())
-	{
+	if(HasFatalFailure()) {
 		return;
 	}
 
@@ -37,6 +36,5 @@ TEST(SyscallEnter, mknodE_failure)
 	/*=============================== ASSERT PARAMETERS  ===========================*/
 
 	evt_test->assert_num_params_pushed(0);
-
 }
 #endif
