@@ -1,7 +1,6 @@
 #include "../../event_class/event_class.h"
 #if defined(__NR_mknodat)
-TEST(SyscallEnter, mknodatE_failure)
-{
+TEST(SyscallEnter, mknodatE_failure) {
 	auto evt_test = get_syscall_event_test(__NR_mknodat, ENTER_EVENT);
 	evt_test->enable_capture();
 
@@ -10,8 +9,9 @@ TEST(SyscallEnter, mknodatE_failure)
 	int mock_fd = -1;
 	char mock_buf[100];
 
-	assert_syscall_state(SYSCALL_FAILURE, "mknodat", syscall(__NR_mknodat, mock_fd, (void *)(mock_buf), NULL, 0));
-
+	assert_syscall_state(SYSCALL_FAILURE,
+	                     "mknodat",
+	                     syscall(__NR_mknodat, mock_fd, (void *)(mock_buf), NULL, 0));
 
 	/*=============================== TRIGGER SYSCALL  ===========================*/
 
@@ -19,8 +19,7 @@ TEST(SyscallEnter, mknodatE_failure)
 
 	evt_test->assert_event_presence();
 
-	if(HasFatalFailure())
-	{
+	if(HasFatalFailure()) {
 		return;
 	}
 
@@ -35,6 +34,5 @@ TEST(SyscallEnter, mknodatE_failure)
 	/*=============================== ASSERT PARAMETERS  ===========================*/
 
 	evt_test->assert_num_params_pushed(0);
-
 }
 #endif
