@@ -4,8 +4,7 @@
 
 #include <sys/mman.h>
 
-TEST(SyscallExit, mlockallX)
-{
+TEST(SyscallExit, mlockallX) {
 	auto evt_test = get_syscall_event_test(__NR_mlockall, EXIT_EVENT);
 
 	evt_test->enable_capture();
@@ -26,8 +25,7 @@ TEST(SyscallExit, mlockallX)
 
 	evt_test->assert_event_presence();
 
-	if(HasFatalFailure())
-	{
+	if(HasFatalFailure()) {
 		return;
 	}
 
