@@ -5,8 +5,7 @@
 
 #ifdef __NR_preadv
 
-TEST(SyscallExit, preadvX_fail)
-{
+TEST(SyscallExit, preadvX_fail) {
 	auto evt_test = get_syscall_event_test(__NR_preadv, EXIT_EVENT);
 
 	evt_test->enable_capture();
@@ -26,8 +25,7 @@ TEST(SyscallExit, preadvX_fail)
 
 	evt_test->assert_event_presence();
 
-	if(HasFatalFailure())
-	{
+	if(HasFatalFailure()) {
 		return;
 	}
 
@@ -51,4 +49,4 @@ TEST(SyscallExit, preadvX_fail)
 	evt_test->assert_num_params_pushed(3);
 }
 
-#endif
\ No newline at end of file
+#endif
