@@ -6,8 +6,7 @@
 #include <sys/ipc.h>
 #include <sys/sem.h>
 
-TEST(SyscallExit, semctlX)
-{
+TEST(SyscallExit, semctlX) {
 	auto evt_test = get_syscall_event_test(__NR_semctl, EXIT_EVENT);
 
 	evt_test->enable_capture();
@@ -27,8 +26,7 @@ TEST(SyscallExit, semctlX)
 
 	evt_test->assert_event_presence();
 
-	if(HasFatalFailure())
-	{
+	if(HasFatalFailure()) {
 		return;
 	}
 
@@ -45,4 +43,4 @@ TEST(SyscallExit, semctlX)
 
 	evt_test->assert_num_params_pushed(1);
 }
-#endif
\ No newline at end of file
+#endif
