@@ -1,8 +1,7 @@
 #include "../../event_class/event_class.h"
 
 #ifdef __NR_setgid
-TEST(SyscallExit, setgidX)
-{
+TEST(SyscallExit, setgidX) {
 	auto evt_test = get_syscall_event_test(__NR_setgid, EXIT_EVENT);
 
 	evt_test->enable_capture();
@@ -19,8 +18,7 @@ TEST(SyscallExit, setgidX)
 
 	evt_test->assert_event_presence();
 
-	if(HasFatalFailure())
-	{
+	if(HasFatalFailure()) {
 		return;
 	}
 
