@@ -1,8 +1,7 @@
 #include "../../event_class/event_class.h"
 
 #ifdef __NR_userfaultfd
-TEST(SyscallExit, userfaultfdX)
-{
+TEST(SyscallExit, userfaultfdX) {
 	auto evt_test = get_syscall_event_test(__NR_userfaultfd, EXIT_EVENT);
 
 	evt_test->enable_capture();
@@ -12,7 +11,7 @@ TEST(SyscallExit, userfaultfdX)
 	/* `flags = 3` is an invalid flag value so the syscall will return `EINVAL` as errno. */
 	int flags = 3;
 	assert_syscall_state(SYSCALL_FAILURE, "userfaultfd", syscall(__NR_userfaultfd, flags));
-    int64_t errno_value = -errno;
+	int64_t errno_value = -errno;
 
 	/*=============================== TRIGGER SYSCALL ===========================*/
 
@@ -20,8 +19,7 @@ TEST(SyscallExit, userfaultfdX)
 
 	evt_test->assert_event_presence();
 
-	if(HasFatalFailure())
-	{
+	if(HasFatalFailure()) {
 		return;
 	}
 
