@@ -22,21 +22,20 @@ limitations under the License.
 static const char* s_10_chars = "0123456789";
 static const char* s_20_chars = "abcdefghijklmnopqrst";
 
-TEST(common_strl, strlcat_input)
-{
-    char buf[256];
-    size_t res;
+TEST(common_strl, strlcat_input) {
+	char buf[256];
+	size_t res;
 
-    strlcpy(buf, s_10_chars, sizeof(buf));
+	strlcpy(buf, s_10_chars, sizeof(buf));
 
-    res = strlcat(buf, s_20_chars, sizeof(buf));
-    ASSERT_EQ(res, 30);
-    ASSERT_STREQ(buf, "0123456789abcdefghijklmnopqrst");
+	res = strlcat(buf, s_20_chars, sizeof(buf));
+	ASSERT_EQ(res, 30);
+	ASSERT_STREQ(buf, "0123456789abcdefghijklmnopqrst");
 
-    strlcpy(buf, s_10_chars, sizeof(buf));
+	strlcpy(buf, s_10_chars, sizeof(buf));
 
-    res = strlcat(buf, s_20_chars, 30);
-    ASSERT_EQ(res, 30);
-    ASSERT_STREQ(buf, "0123456789abcdefghijklmnopqrs");
-    ASSERT_EQ(strlen(buf), 29);
+	res = strlcat(buf, s_20_chars, 30);
+	ASSERT_EQ(res, 30);
+	ASSERT_STREQ(buf, "0123456789abcdefghijklmnopqrs");
+	ASSERT_EQ(strlen(buf), 29);
 }
