@@ -33,14 +33,15 @@ TEST_F(sys_call_test, container_cgroups) {
 	//
 	// FILTER
 	//
-	event_filter_t filter = [&](sinsp_evt* evt) { return evt->get_tid() == ctid; };
+	event_filter_t filter = [&](sinsp_evt* evt) {
+		return evt->get_type() == PPME_SYSCALL_CLONE_20_X && evt->get_tid() == ctid;
+	};
 
 	//
 	// TEST CODE
 	//
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector) {
+	run_callback_async_t test = [&]() {
 		ctid = fork();
-
 		if(ctid >= 0) {
 			if(ctid == 0) {
 				sleep(1);
@@ -55,70 +56,70 @@ TEST_F(sys_call_test, container_cgroups) {
 	};
 
 	//
-	// OUTPUT VALDATION
+	// OUTPUT VALIDATION
 	//
 	captured_event_callback_t callback = [&](const callback_param& param) {
-		if(param.m_evt->get_type() == PPME_SYSCALL_CLONE_20_X) {
-			sinsp_threadinfo sinsp_tinfo(nullptr);
-			char buf[100];
+		sinsp_threadinfo sinsp_tinfo(nullptr);
+		char buf[100];
 
-			sinsp_threadinfo* tinfo = param.m_evt->get_thread_info();
-			ASSERT_TRUE(tinfo != NULL);
-			const auto& cgroups = tinfo->cgroups();
-			ASSERT_TRUE(cgroups.size() > 0);
+		sinsp_threadinfo* tinfo = param.m_evt->get_thread_info();
+		ASSERT_TRUE(tinfo != nullptr);
+		const auto& cgroups = tinfo->cgroups();
+		ASSERT_TRUE(!cgroups.empty());
 
-			snprintf(buf, sizeof(buf), "/proc/%d/", ctid);
+		snprintf(buf, sizeof(buf), "/proc/%d/", ctid);
 
-			sinsp_tinfo.m_tid = ctid;
-			sinsp_cgroup::instance().lookup_cgroups(sinsp_tinfo);
+		sinsp_tinfo.m_tid = ctid;
+		sinsp_cgroup::instance().lookup_cgroups(sinsp_tinfo);
 
-			const auto& sinsp_cgroups = sinsp_tinfo.cgroups();
-			ASSERT_TRUE(sinsp_cgroups.size() > 0);
+		const auto& sinsp_cgroups = sinsp_tinfo.cgroups();
+		ASSERT_TRUE(!sinsp_cgroups.empty());
 
-			map<string, string> cgroups_kernel;
-			for(uint32_t j = 0; j < cgroups.size(); ++j) {
-				cgroups_kernel.insert(pair<string, string>(cgroups[j].first, cgroups[j].second));
-			}
-
-			map<string, string> cgroups_proc;
-			for(uint32_t j = 0; j < sinsp_cgroups.size(); ++j) {
-				cgroups_proc.insert(
-				        pair<string, string>(sinsp_cgroups[j].first, sinsp_cgroups[j].second));
-			}
-
-			ASSERT_TRUE(cgroups_kernel.size() > 0);
-			ASSERT_TRUE(cgroups_proc.size() > 0);
-
-			for(const auto& [subsys, path] : cgroups_proc) {
-				printf(" proc cgroup[%s] == <%s>\n", subsys.c_str(), path.c_str());
-			}
-
-			for(const auto& [subsys, path] : cgroups_kernel) {
-				printf(" kernel cgroup[%s] == <%s>\n", subsys.c_str(), path.c_str());
-			}
-
-			for(auto& [proc_subsys, proc_path] : cgroups_proc) {
-				auto it_kernel = cgroups_kernel.find(proc_subsys);
-				if(it_kernel != cgroups_kernel.end()) {
-					EXPECT_EQ(it_kernel->first, proc_subsys);
-					EXPECT_EQ(it_kernel->second, proc_path);
-				}
-			}
-
-			done = true;
+		map<string, string> cgroups_kernel;
+		for(const auto& cgroup : cgroups) {
+			cgroups_kernel.insert(pair<string, string>(cgroup.first, cgroup.second));
 		}
+
+		map<string, string> cgroups_proc;
+		for(const auto& sinsp_cgroup : sinsp_cgroups) {
+			cgroups_proc.insert(pair<string, string>(sinsp_cgroup.first, sinsp_cgroup.second));
+		}
+
+		ASSERT_TRUE(!cgroups_kernel.empty());
+		ASSERT_TRUE(!cgroups_proc.empty());
+
+		for(const auto& [subsys, path] : cgroups_proc) {
+			printf(" proc cgroup[%s] == <%s>\n", subsys.c_str(), path.c_str());
+		}
+
+		for(const auto& [subsys, path] : cgroups_kernel) {
+			printf(" kernel cgroup[%s] == <%s>\n", subsys.c_str(), path.c_str());
+		}
+
+		for(auto& [proc_subsys, proc_path] : cgroups_proc) {
+			auto it_kernel = cgroups_kernel.find(proc_subsys);
+			if(it_kernel != cgroups_kernel.end()) {
+				ASSERT_EQ(it_kernel->first, proc_subsys);
+				ASSERT_EQ(it_kernel->second, proc_path);
+			}
+		}
+
+		done = true;
 	};
 
-	ASSERT_NO_FATAL_FAILURE({ event_capture::run(test, callback, filter); });
+	ASSERT_NO_FATAL_FAILURE({
+		event_capture::run(test,
+		                   callback,
+		                   filter,
+		                   event_capture::do_nothing,
+		                   event_capture::do_nothing,
+		                   event_capture::do_nothing,
+		                   libsinsp::events::sinsp_state_sc_set());
+	});
 	ASSERT_TRUE(done);
 }
 
 static int clone_callback(void* arg) {
-	// Here we need 2 sleeps instead of once because, for some reason,
-	// we miss the first one. This problem is *probably* related to the
-	// fact that before we created a brand new inspector for each test but
-	// not we keep the same and start/stop the capture.
-	sleep(1);
 	sleep(1);
 	return 0;
 }
@@ -136,7 +137,7 @@ TEST_F(sys_call_test, container_clone_nspid) {
 	//
 	// TEST CODE
 	//
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector) {
+	run_callback_t test = [&](sinsp* inspector) {
 		const int STACK_SIZE = 65536; /* Stack size for cloned child */
 		char* stack;                  /* Start of stack buffer area */
 		char* stack_top;              /* End of stack buffer area */
@@ -174,7 +175,15 @@ TEST_F(sys_call_test, container_clone_nspid) {
 		}
 	};
 
-	ASSERT_NO_FATAL_FAILURE({ event_capture::run(test, callback, filter); });
+	ASSERT_NO_FATAL_FAILURE({
+		event_capture::run(test,
+		                   callback,
+		                   filter,
+		                   event_capture::do_nothing,
+		                   event_capture::do_nothing,
+		                   event_capture::do_nothing,
+		                   libsinsp::events::sinsp_state_sc_set());
+	});
 	ASSERT_TRUE(done);
 }
 
@@ -183,21 +192,6 @@ TEST_F(sys_call_test, container_clone_nspid_ioctl) {
 	int flags = CLONE_CHILD_CLEARTID | CLONE_CHILD_SETTID | SIGCHLD | CLONE_NEWPID;
 	bool done = false;
 
-	const int STACK_SIZE = 65536;
-	char* stack;
-	char* stack_top;
-
-	stack = (char*)malloc(STACK_SIZE);
-	if(stack == NULL) {
-		FAIL();
-	}
-	stack_top = stack + STACK_SIZE;
-
-	ctid = clone(clone_callback, stack_top, flags, NULL);
-	if(ctid == -1) {
-		FAIL();
-	}
-
 	//
 	// FILTER
 	//
@@ -206,8 +200,23 @@ TEST_F(sys_call_test, container_clone_nspid_ioctl) {
 	//
 	// TEST CODE
 	//
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector) {
+	run_callback_t test = [&](sinsp* inspector) {
+		const int STACK_SIZE = 65536;
+		char* stack;
+		char* stack_top;
+
+		stack = (char*)malloc(STACK_SIZE);
+		if(stack == NULL) {
+			FAIL();
+		}
+		stack_top = stack + STACK_SIZE;
+
+		ctid = clone(clone_callback, stack_top, flags, NULL);
+		if(ctid == -1) {
+			FAIL();
+		}
 		waitpid(ctid, NULL, 0);
+		free(stack);
 	};
 
 	//
@@ -220,8 +229,15 @@ TEST_F(sys_call_test, container_clone_nspid_ioctl) {
 		}
 	};
 
-	ASSERT_NO_FATAL_FAILURE({ event_capture::run(test, callback, filter); });
-	free(stack);
+	ASSERT_NO_FATAL_FAILURE({
+		event_capture::run(test,
+		                   callback,
+		                   filter,
+		                   event_capture::do_nothing,
+		                   event_capture::do_nothing,
+		                   event_capture::do_nothing,
+		                   libsinsp::events::sinsp_state_sc_set());
+	});
 	ASSERT_TRUE(done);
 }
 
@@ -238,7 +254,7 @@ static void run_container_docker_test(bool fork_after_container_start) {
 		        evt->get_type() == PPME_CONTAINER_JSON_2_E);
 	};
 
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector) {
+	run_callback_async_t test = [&]() {
 		ASSERT_TRUE(system("docker kill libsinsp_docker > /dev/null 2>&1 || true") == 0);
 		ASSERT_TRUE(system("docker rm -v libsinsp_docker > /dev/null 2>&1 || true") == 0);
 
@@ -251,7 +267,7 @@ static void run_container_docker_test(bool fork_after_container_start) {
 			ASSERT_TRUE(false);
 		}
 
-		sleep(2);
+		sleep(5);
 
 		ASSERT_TRUE(system("docker kill libsinsp_docker > /dev/null 2>&1 || true") == 0);
 		ASSERT_TRUE(system("docker rm -v libsinsp_docker > /dev/null 2>&1") == 0);
@@ -293,7 +309,15 @@ static void run_container_docker_test(bool fork_after_container_start) {
 		done = true;
 	};
 
-	ASSERT_NO_FATAL_FAILURE({ event_capture::run(test, callback, filter); });
+	ASSERT_NO_FATAL_FAILURE({
+		event_capture::run(test,
+		                   callback,
+		                   filter,
+		                   event_capture::do_nothing,
+		                   event_capture::do_nothing,
+		                   event_capture::do_nothing,
+		                   libsinsp::events::sinsp_state_sc_set());
+	});
 	ASSERT_TRUE(done);
 }
 
@@ -346,7 +370,7 @@ TEST_F(sys_call_test, container_docker_bad_socket) {
 		return false;
 	};
 
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector) {
+	run_callback_async_t test = []() {
 		ASSERT_TRUE(system("docker kill libsinsp_docker > /dev/null 2>&1 || true") == 0);
 		ASSERT_TRUE(system("docker rm -v libsinsp_docker > /dev/null 2>&1 || true") == 0);
 
@@ -373,7 +397,7 @@ TEST_F(sys_call_test, container_docker_bad_socket) {
 		ASSERT_NE(PPME_CONTAINER_JSON_2_E, param.m_evt->get_type());
 
 		sinsp_threadinfo* tinfo = param.m_evt->get_thread_info(false);
-		ASSERT_TRUE(tinfo->m_container_id.length() == 12);
+		ASSERT_TRUE(tinfo->m_container_id.length() <= 12);
 		ASSERT_TRUE(param.m_inspector->m_container_manager.container_exists(tinfo->m_container_id));
 		const auto container_info =
 		        param.m_inspector->m_container_manager.get_container(tinfo->m_container_id);
@@ -383,11 +407,13 @@ TEST_F(sys_call_test, container_docker_bad_socket) {
 		}
 	};
 
-	before_close_t cleanup = [&](sinsp* inspector) {
+	after_capture_t cleanup = [&](sinsp* inspector) {
 		inspector->set_docker_socket_path("/var/run/docker.sock");
 	};
 
-	ASSERT_NO_FATAL_FAILURE({ event_capture::run(test, callback, filter, setup, cleanup); });
+	ASSERT_NO_FATAL_FAILURE({
+		event_capture::run(test, callback, filter, setup, event_capture::do_nothing, cleanup);
+	});
 	ASSERT_TRUE(done);
 }
 
@@ -399,16 +425,8 @@ TEST_F(sys_call_test, container_libvirt) {
 		return;
 	}
 
-	event_filter_t filter = [&](sinsp_evt* evt) {
-		sinsp_threadinfo* tinfo = evt->get_thread_info();
-		if(tinfo) {
-			return !tinfo->m_container_id.empty() && tinfo->m_comm == "sh";
-		}
-
-		return false;
-	};
-
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector) {
+	// Setup phase before capture has start, to avoid generating too many events
+	before_open_t setup = [](sinsp* inspector) {
 		FILE* f = fopen("/tmp/conf.xml", "w");
 		ASSERT_TRUE(f != NULL);
 		fprintf(f,
@@ -434,15 +452,21 @@ TEST_F(sys_call_test, container_libvirt) {
 		if(system("virsh -c lxc:/// define /tmp/conf.xml") != 0) {
 			ASSERT_TRUE(false);
 		}
+	};
 
+	event_filter_t filter = [&](sinsp_evt* evt) {
+		sinsp_threadinfo* tinfo = evt->get_thread_info();
+		if(tinfo) {
+			return !tinfo->m_container_id.empty() && tinfo->m_comm == "sh";
+		}
+		return false;
+	};
+
+	run_callback_async_t test = []() {
 		if(system("virsh -c lxc:/// start libvirt-container") != 0) {
 			ASSERT_TRUE(false);
 		}
-
 		sleep(2);
-
-		ASSERT_TRUE(system("virsh -c lxc:/// undefine libvirt-container > /dev/null 2>&1") == 0);
-		ASSERT_TRUE(system("virsh -c lxc:/// destroy libvirt-container > /dev/null 2>&1") == 0);
 	};
 
 	captured_event_callback_t callback = [&](const callback_param& param) {
@@ -467,7 +491,20 @@ TEST_F(sys_call_test, container_libvirt) {
 		done = true;
 	};
 
-	ASSERT_NO_FATAL_FAILURE({ event_capture::run(test, callback, filter); });
+	after_capture_t cleanup = [](sinsp* inspector) {
+		ASSERT_TRUE(system("virsh -c lxc:/// undefine libvirt-container > /dev/null 2>&1") == 0);
+		ASSERT_TRUE(system("virsh -c lxc:/// destroy libvirt-container > /dev/null 2>&1") == 0);
+	};
+
+	ASSERT_NO_FATAL_FAILURE({
+		event_capture::run(test,
+		                   callback,
+		                   filter,
+		                   setup,
+		                   event_capture::do_nothing,
+		                   cleanup,
+		                   libsinsp::events::sinsp_state_sc_set());
+	});
 	ASSERT_TRUE(done);
 }
 
@@ -486,18 +523,6 @@ public:
 	bool healthcheck_seen;
 };
 
-static std::string capture_stats(sinsp* inspector) {
-	scap_stats st;
-	inspector->get_capture_stats(&st);
-
-	std::stringstream ss;
-
-	ss << "capture stats: dropped=" << st.n_drops << " buf=" << st.n_drops_buffer
-	   << " pf=" << st.n_drops_pf << " bug=" << st.n_drops_bug;
-
-	return ss.str();
-}
-
 static void update_container_state(sinsp* inspector,
                                    sinsp_evt* evt,
                                    container_state& cstate,
@@ -528,8 +553,7 @@ static void update_container_state(sinsp* inspector,
 			if(!cstate.root_cmd_seen) {
 				cstate.root_cmd_seen = true;
 
-				ASSERT_EQ(tinfo->m_category, sinsp_threadinfo::CAT_CONTAINER)
-				        << capture_stats(inspector);
+				ASSERT_EQ(tinfo->m_category, sinsp_threadinfo::CAT_CONTAINER);
 			} else {
 				// In some cases, it can take so long for the async fetch of container info to
 				// complete (1.5 seconds) that a healthcheck proc might be run before the container
@@ -537,7 +561,7 @@ static void update_container_state(sinsp* inspector,
 				// the container info has a health probe.
 				if(cstate.container_w_health_probe) {
 					cstate.healthcheck_seen = true;
-					ASSERT_EQ(tinfo->m_category, expected_cat) << capture_stats(inspector);
+					ASSERT_EQ(tinfo->m_category, expected_cat);
 				}
 			}
 		}
@@ -547,13 +571,12 @@ static void update_container_state(sinsp* inspector,
 		if(cmdline == "sleep 10") {
 			if(!cstate.second_cmd_seen) {
 				cstate.second_cmd_seen = true;
-				ASSERT_EQ(tinfo->m_category, sinsp_threadinfo::CAT_CONTAINER)
-				        << capture_stats(inspector);
+				ASSERT_EQ(tinfo->m_category, sinsp_threadinfo::CAT_CONTAINER);
 			} else {
 				// See above caveat about slow container info fetches
 				if(cstate.container_w_health_probe) {
 					// Should inherit container healthcheck property from parent.
-					ASSERT_EQ(tinfo->m_category, expected_cat) << capture_stats(inspector);
+					ASSERT_EQ(tinfo->m_category, expected_cat);
 				}
 			}
 		}
@@ -563,7 +586,7 @@ static void update_container_state(sinsp* inspector,
 		if(cmdline == "ut-health-check" || cmdline == "sh -c /bin/ut-health-check") {
 			cstate.healthcheck_seen = true;
 
-			ASSERT_EQ(tinfo->m_category, expected_cat) << capture_stats(inspector);
+			ASSERT_EQ(tinfo->m_category, expected_cat);
 		}
 	}
 }
@@ -579,8 +602,7 @@ static void healthcheck_helper(
         std::vector<std::string>& labels,
         sinsp_threadinfo::command_category expected_cat = sinsp_threadinfo::CAT_HEALTHCHECK) {
 	container_state cstate;
-	bool exited_early = false;
-	std::string capture_stats_str = "(Not Collected Yet)";
+	std::atomic<bool> exited_early = false;
 
 	if(!dutils_check_docker()) {
 		return;
@@ -597,24 +619,14 @@ static void healthcheck_helper(
 
 	ASSERT_TRUE(dhelper.build_image() == 0);
 
-	before_open_t setup = [&](sinsp* inspector) {};
-
 	event_filter_t filter = [&](sinsp_evt* evt) {
 		sinsp_threadinfo* tinfo = evt->get_thread_info();
 
-		return (strcmp(evt->get_name(), "execve") == 0 && evt->get_direction() == SCAP_ED_OUT &&
-		        tinfo->m_container_id != "");
+		return (tinfo != nullptr && strcmp(evt->get_name(), "execve") == 0 &&
+		        evt->get_direction() == SCAP_ED_OUT && !tinfo->m_container_id.empty());
 	};
 
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector_handle) {
-		// Setting dropping mode preserves the execs but
-		// reduces the chances that we'll drop events during
-		// the docker fetch.
-		{
-			std::scoped_lock inspector_handle_lock(inspector_handle);
-			inspector_handle->start_dropping_mode(1);
-		}
-
+	run_callback_async_t test = [&]() {
 		int rc = dhelper.run_container("cont_health_ut", "/bin/sh -c '/bin/sleep 10'");
 
 		ASSERT_TRUE(exited_early || (rc == 0));
@@ -632,17 +644,20 @@ static void healthcheck_helper(
 		}
 	};
 
-	before_close_t cleanup = [&](sinsp* inspector) {
-		capture_stats_str = capture_stats(inspector);
-		inspector->stop_dropping_mode();
-	};
+	ASSERT_NO_FATAL_FAILURE({
+		event_capture::run(test,
+		                   callback,
+		                   filter,
+		                   event_capture::do_nothing,
+		                   event_capture::do_nothing,
+		                   event_capture::do_nothing,
+		                   libsinsp::events::sinsp_state_sc_set());
+	});
 
-	ASSERT_NO_FATAL_FAILURE({ event_capture::run(test, callback, filter, setup, cleanup); });
-
-	ASSERT_TRUE(cstate.root_cmd_seen) << capture_stats_str;
-	ASSERT_TRUE(cstate.second_cmd_seen) << capture_stats_str;
-	ASSERT_EQ(cstate.container_w_health_probe, expect_healthcheck) << capture_stats_str;
-	ASSERT_EQ(cstate.healthcheck_seen, expect_healthcheck) << capture_stats_str;
+	ASSERT_TRUE(cstate.root_cmd_seen);
+	ASSERT_TRUE(cstate.second_cmd_seen);
+	ASSERT_EQ(cstate.container_w_health_probe, expect_healthcheck);
+	ASSERT_EQ(cstate.healthcheck_seen, expect_healthcheck);
 }
 
 static void healthcheck_tracefile_helper(
@@ -657,7 +672,7 @@ static void healthcheck_tracefile_helper(
 	        dockerfile + " . > /dev/null 2>&1");
 	ASSERT_TRUE(system(build_cmdline.c_str()) == 0);
 
-	run_callback_t test = [](concurrent_object_handle<sinsp> inspector_handle) {
+	run_callback_async_t test = []() {
 		// --network=none speeds up the container setup a bit.
 		ASSERT_TRUE(
 		        (system("docker run --rm --network=none --name cont_health_ut cont_health_ut_img "
@@ -671,7 +686,15 @@ static void healthcheck_tracefile_helper(
 
 	captured_event_callback_t callback = [&](const callback_param& param) { return; };
 
-	ASSERT_NO_FATAL_FAILURE({ event_capture::run(test, callback, filter); });
+	ASSERT_NO_FATAL_FAILURE({
+		event_capture::run(test,
+		                   callback,
+		                   filter,
+		                   event_capture::do_nothing,
+		                   event_capture::do_nothing,
+		                   event_capture::do_nothing,
+		                   libsinsp::events::sinsp_state_sc_set());
+	});
 
 	// Now reread the file we just wrote and pass it through
 	// update_container_state.
@@ -687,7 +710,7 @@ static void healthcheck_tracefile_helper(
 	inspector.open_savefile(dumpfile);
 	inspector.start_capture();
 
-	while(1) {
+	while(true) {
 		sinsp_evt* ev;
 		int32_t res = inspector.next(&ev);
 
@@ -704,7 +727,7 @@ static void healthcheck_tracefile_helper(
 		update_container_state(&inspector, ev, cstate, expected_cat);
 	}
 
-	std::string capture_stats_str = capture_stats(&inspector);
+	std::string capture_stats_str = event_capture::capture_stats(&inspector);
 
 	inspector.stop_capture();
 	inspector.close();
@@ -819,19 +842,17 @@ TEST_F(sys_call_test, docker_container_large_json) {
 
 	ASSERT_TRUE(dhelper.build_image() == 0);
 
+	before_open_t before = [&](sinsp* inspector) {
+		inspector->set_container_labels_max_len(60000);
+	};
+
 	event_filter_t filter = [&](sinsp_evt* evt) {
 		return evt->get_type() == PPME_CONTAINER_JSON_E ||
 		       evt->get_type() == PPME_CONTAINER_JSON_2_E;
 	};
 
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector_handle) {
-		// set container label max to huge value
-		{
-			std::scoped_lock inspector_handle_lock(inspector_handle);
-			inspector_handle->set_container_labels_max_len(60000);
-		}
+	run_callback_async_t test = [&]() {
 		int rc = dhelper.run_container("large_container_ut", "/bin/sh -c '/bin/sleep 3'");
-
 		ASSERT_TRUE(rc == 0);
 	};
 
@@ -868,11 +889,21 @@ TEST_F(sys_call_test, docker_container_large_json) {
 		}
 
 		EXPECT_TRUE(labels.empty());
-
-		// reset the value
-		param.m_inspector->set_container_labels_max_len(100);
 	};
 
-	ASSERT_NO_FATAL_FAILURE({ event_capture::run(test, callback, filter); });
+	after_capture_t cleanup = [](sinsp* inspector) {
+		// reset the value
+		inspector->set_container_labels_max_len(100);
+	};
+
+	ASSERT_NO_FATAL_FAILURE({
+		event_capture::run(test,
+		                   callback,
+		                   filter,
+		                   before,
+		                   event_capture::do_nothing,
+		                   cleanup,
+		                   libsinsp::events::sinsp_state_sc_set());
+	});
 	ASSERT_TRUE(saw_container_evt);
 }
