@@ -57,7 +57,7 @@ TEST_F(sys_call_test, forking) {
 	//
 	// TEST CODE
 	//
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector) {
+	run_callback_t test = [&](sinsp* inspector) {
 		pid_t childtid;
 		int status;
 		childtid = fork();
@@ -110,16 +110,13 @@ TEST_F(sys_call_test, forking_while_scap_stopped) {
 	//
 	// TEST CODE
 	//
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector_handle) {
+	run_callback_t test = [&](sinsp* inspector) {
 		int status;
 
 		//
 		// Stop the capture just before the fork so we lose the event.
 		//
-		{
-			std::scoped_lock inspector_handle_lock(inspector_handle);
-			inspector_handle->stop_capture();
-		}
+		inspector->stop_capture();
 
 		ctid = fork();
 
@@ -138,13 +135,13 @@ TEST_F(sys_call_test, forking_while_scap_stopped) {
 				// It's a simple way to make sure the capture is started
 				// after the child's clone returned.
 				//
-				inspector_handle.unsafe_ptr()->start_capture();
+				inspector->start_capture();
 
 				//
 				// Wait for 5 seconds to make sure the process will still
 				// exist when the sinsp will do the lookup to /proc
 				//
-				usleep(5000000);
+				sleep(5);
 				close(fd);
 				_exit(xstatus);  // child exits with specific return code
 			} else               // fork() returns new pid to the parent process
@@ -204,19 +201,25 @@ TEST_F(sys_call_test, forking_while_scap_stopped) {
 }
 
 TEST_F(sys_call_test, forking_process_expired) {
-	int ptid;  // parent tid
-	int ctid;  // child tid
+	int ptid = gettid();  // parent tid
+	int ctid = -1;        // child tid
 	int status;
 
 	//
 	// FILTER
 	//
-	event_filter_t filter = [&](sinsp_evt* evt) { return evt->get_tid() == ptid; };
+	event_filter_t filter = [&](sinsp_evt* evt) {
+		if(evt->get_type() == PPME_SYSCALL_NANOSLEEP_E ||
+		   evt->get_type() == PPME_SYSCALL_NANOSLEEP_X) {
+			return evt->get_tid() == ptid;
+		}
+		return false;
+	};
 
 	//
 	// TEST CODE
 	//
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector) {
+	run_callback_t test = [&](sinsp* inspector) {
 		ctid = fork();
 
 		if(ctid >= 0)  // fork succeeded
@@ -227,17 +230,14 @@ TEST_F(sys_call_test, forking_process_expired) {
 				FAIL();
 			} else  // fork() returns new pid to the parent process
 			{
-				ptid = getpid();
-
 				//
 				// Wait 10 seconds. During this time, the process should NOT be removed
 				//
-				struct timespec req, rem;
-				req.tv_sec = 10;
+				struct timespec req = {0};
+				req.tv_sec = 1;
 				req.tv_nsec = 0;
 
-				syscall(__NR_nanosleep, &req, &rem);
-
+				syscall(__NR_nanosleep, &req, nullptr);
 				kill(ctid, SIGUSR1);
 				wait(&status);
 			}
@@ -253,15 +253,14 @@ TEST_F(sys_call_test, forking_process_expired) {
 	//
 	captured_event_callback_t callback = [&](const callback_param& param) {
 		sinsp_evt* e = param.m_evt;
-
-		if(e->get_tid() == ptid) {
-			if(e->get_type() == PPME_SYSCALL_NANOSLEEP_E && !sleep_caught) {
+		if(!sleep_caught) {
+			if(e->get_type() == PPME_SYSCALL_NANOSLEEP_E) {
 				//
 				// The child should exist
 				//
 				sinsp_threadinfo* ti = param.m_inspector->get_thread_ref(ctid, false, true).get();
 				EXPECT_NE((sinsp_threadinfo*)NULL, ti);
-			} else if(e->get_type() == PPME_SYSCALL_NANOSLEEP_X && !sleep_caught) {
+			} else if(e->get_type() == PPME_SYSCALL_NANOSLEEP_X) {
 				//
 				// The child should exist
 				//
@@ -269,8 +268,6 @@ TEST_F(sys_call_test, forking_process_expired) {
 				EXPECT_NE((sinsp_threadinfo*)NULL, ti);
 				sleep_caught = true;
 			}
-		} else {
-			FAIL();
 		}
 	};
 
@@ -280,7 +277,8 @@ TEST_F(sys_call_test, forking_process_expired) {
 		                   filter,
 		                   event_capture::do_nothing,
 		                   event_capture::do_nothing,
-		                   event_capture::always_continue,
+		                   event_capture::do_nothing,
+		                   {},
 		                   131072,
 		                   5 * ONE_SECOND_IN_NS,
 		                   ONE_SECOND_IN_NS);
@@ -292,7 +290,7 @@ TEST_F(sys_call_test, forking_process_expired) {
 ///////////////////////////////////////////////////////////////////////////////
 // CLONE VARIANTS
 ///////////////////////////////////////////////////////////////////////////////
-int ctid;  // child tid
+std::atomic<int> ctid = -1;  // child tid
 
 typedef struct {
 	int fd;
@@ -314,7 +312,7 @@ static int clone_callback_1(void* arg) {
 }
 
 /*
- * The `sys_call_test.forking_clone_fs` e2e test makes the assuption
+ * The `sys_call_test.forking_clone_fs` e2e test makes the assumption
  * that, if a children closes a file descriptor, the parent trying
  * to close the same file descriptor will get an error. This seems
  * not to be always the case. As the man says `It is probably unwise
@@ -328,7 +326,7 @@ TEST_F(sys_call_test, DISABLED_forking_clone_fs) {
 	int callnum = 0;
 	char bcwd[1024];
 	int prfd;
-	int ptid;  // parent tid
+	int ptid = gettid();  // parent tid
 	pid_t clone_tid;
 	int child_tid;
 	int parent_res;
@@ -346,7 +344,7 @@ TEST_F(sys_call_test, DISABLED_forking_clone_fs) {
 	//
 	// TEST CODE
 	//
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector) {
+	run_callback_t test = [&](sinsp* inspector) {
 		const int STACK_SIZE = 65536; /* Stack size for cloned child */
 		char* stack;                  /* Start of stack buffer area */
 		char* stackTop;               /* End of stack buffer area */
@@ -354,8 +352,6 @@ TEST_F(sys_call_test, DISABLED_forking_clone_fs) {
 		int status;
 		pid_t pid;
 
-		ptid = gettid();
-
 		/* Set up an argument structure to be passed to cloned child, and
 		   set some process attributes that will be modified by child */
 
@@ -397,7 +393,7 @@ TEST_F(sys_call_test, DISABLED_forking_clone_fs) {
 	};
 
 	//
-	// OUTPUT VALDATION
+	// OUTPUT VALIDATION
 	//
 	captured_event_callback_t callback = [&](const callback_param& param) {
 		sinsp_evt* e = param.m_evt;
@@ -467,10 +463,14 @@ TEST_F(sys_call_test, forking_clone_nofs) {
 	int callnum = 0;
 	char bcwd[1024];
 	int prfd;
-	int ptid;  // parent tid
+	int ptid = gettid();  // parent tid
 	int flags = CLONE_FS | CLONE_VM;
 	int drflags = PPM_CL_CLONE_FS | PPM_CL_CLONE_VM;
 
+	const int STACK_SIZE = 65536; /* Stack size for cloned child */
+	char* stack;                  /* Start of stack buffer area */
+	char* stackTop;               /* End of stack buffer area */
+
 	//
 	// FILTER
 	//
@@ -481,16 +481,11 @@ TEST_F(sys_call_test, forking_clone_nofs) {
 	//
 	// TEST CODE
 	//
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector) {
-		const int STACK_SIZE = 65536; /* Stack size for cloned child */
-		char* stack;                  /* Start of stack buffer area */
-		char* stackTop;               /* End of stack buffer area */
-		clone_params cp;              /* Passed to child function */
+	run_callback_t test = [&](sinsp* inspector) {
+		clone_params cp; /* Passed to child function */
 		int status;
 		pid_t pid;
 
-		ptid = getpid();
-
 		/* Set up an argument structure to be passed to cloned child, and
 		   set some process attributes that will be modified by child */
 
@@ -525,13 +520,10 @@ TEST_F(sys_call_test, forking_clone_nofs) {
 			FAIL();
 
 		close(cp.fd);
-
-		sleep(1);
-		free(stack);
 	};
 
 	//
-	// OUTPUT VALDATION
+	// OUTPUT VALIDATION
 	//
 	captured_event_callback_t callback = [&](const callback_param& param) {
 		sinsp_evt* e = param.m_evt;
@@ -586,7 +578,17 @@ TEST_F(sys_call_test, forking_clone_nofs) {
 		}
 	};
 
-	ASSERT_NO_FATAL_FAILURE({ event_capture::run(test, callback, filter); });
+	after_capture_t cleanup = [&](sinsp* inspector) { free(stack); };
+
+	ASSERT_NO_FATAL_FAILURE({
+		event_capture::run(test,
+		                   callback,
+		                   filter,
+		                   event_capture::do_nothing,
+		                   event_capture::do_nothing,
+		                   cleanup);
+	});
+
 	EXPECT_EQ(callnum, 4);
 }
 
@@ -605,11 +607,15 @@ TEST_F(sys_call_test, forking_clone_cwd) {
 	int callnum = 0;
 	char oriwd[1024];
 	char bcwd[256];
-	int ptid;  // parent tid
+	int ptid = gettid();  // parent tid
 	int flags = CLONE_VM | CLONE_FS | CLONE_FILES | CLONE_SIGHAND | CLONE_THREAD;
 	int drflags = PPM_CL_CLONE_VM | PPM_CL_CLONE_FS | PPM_CL_CLONE_FILES | PPM_CL_CLONE_SIGHAND |
 	              PPM_CL_CLONE_THREAD;
 
+	const int STACK_SIZE = 65536; /* Stack size for cloned child */
+	char* stack;                  /* Start of stack buffer area */
+	char* stackTop;               /* End of stack buffer area */
+
 	//
 	// FILTER
 	//
@@ -618,14 +624,7 @@ TEST_F(sys_call_test, forking_clone_cwd) {
 	//
 	// TEST CODE
 	//
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector) {
-		const int STACK_SIZE = 65536; /* Stack size for cloned child */
-		char* stack;                  /* Start of stack buffer area */
-		char* stackTop;               /* End of stack buffer area */
-		clone_params cp;              /* Passed to child function */
-
-		ptid = getpid();
-
+	run_callback_t test = [&](sinsp* inspector) {
 		ASSERT_TRUE(getcwd(oriwd, 1024) != NULL);
 
 		/* Allocate stack for child */
@@ -637,22 +636,21 @@ TEST_F(sys_call_test, forking_clone_cwd) {
 
 		/* Create child; child commences execution in childFunc() */
 
-		if(clone(clone_callback_2, stackTop, flags, &cp) == -1) {
+		if(clone(clone_callback_2, stackTop, flags, nullptr) == -1) {
 			FAIL();
 		}
 
+		// Give new thread enough time to exit
 		sleep(1);
 
+		// The cloned child called chdir("/"); we expect to retrieve "/" here.
 		std::string tmps = getcwd(bcwd, 256);
 
 		ASSERT_TRUE(chdir(oriwd) == 0);
-
-		sleep(1);
-		free(stack);
 	};
 
 	//
-	// OUTPUT VALDATION
+	// OUTPUT VALIDATION
 	//
 	captured_event_callback_t callback = [&](const callback_param& param) {
 		sinsp_evt* e = param.m_evt;
@@ -678,9 +676,15 @@ TEST_F(sys_call_test, forking_clone_cwd) {
 
 			if(ti->m_tid == ptid) {
 				if(callnum > 1) {
+					// last getcwd call in the test
 					EXPECT_EQ(bcwd, ti->get_cwd());
+					EXPECT_EQ(bcwd, std::string("/"));
+				} else {
+					// first getcwd call in the test
+					EXPECT_EQ(std::string(oriwd) + "/", ti->get_cwd());
 				}
 			} else if(ti->m_tid == ctid) {
+				// getcwd call by the child
 				EXPECT_EQ("/", ti->get_cwd());
 			}
 
@@ -688,7 +692,16 @@ TEST_F(sys_call_test, forking_clone_cwd) {
 		}
 	};
 
-	ASSERT_NO_FATAL_FAILURE({ event_capture::run(test, callback, filter); });
+	after_capture_t cleanup = [&](sinsp* inspector) { free(stack); };
+
+	ASSERT_NO_FATAL_FAILURE({
+		event_capture::run(test,
+		                   callback,
+		                   filter,
+		                   event_capture::do_nothing,
+		                   event_capture::do_nothing,
+		                   cleanup);
+	});
 
 	EXPECT_EQ(3, callnum);
 }
@@ -696,7 +709,7 @@ TEST_F(sys_call_test, forking_clone_cwd) {
 TEST_F(sys_call_test, forking_main_thread_exit) {
 	int evtnum = 0;
 	int callnum = 0;
-	int fd;
+	int64_t fd;
 	pid_t cpid;  // parent tid
 
 	event_filter_t filter = [&](sinsp_evt* evt) {
@@ -708,7 +721,7 @@ TEST_F(sys_call_test, forking_main_thread_exit) {
 		}
 	};
 
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector) {
+	run_callback_t test = [&](sinsp* inspector) {
 		int status;
 
 		// ptid = getpid();
@@ -734,13 +747,13 @@ TEST_F(sys_call_test, forking_main_thread_exit) {
 		if(param.m_evt->get_type() == PPME_SYSCALL_OPEN_X) {
 			if(param.m_evt->get_param_value_str("name") == "/etc/passwd") {
 				EXPECT_EQ("<f>/etc/passwd", param.m_evt->get_param_value_str("fd"));
-				fd = *(int64_t*)param.m_evt->get_param(0)->m_val;
+				fd = param.m_evt->get_syscall_return_value();
 				++callnum;
 			}
 		} else if(param.m_evt->get_type() == PPME_SYSCALL_OPENAT_2_X) {
 			if(param.m_evt->get_param_value_str("name") == "/etc/passwd") {
 				EXPECT_EQ("<f>/etc/passwd", param.m_evt->get_param_value_str("fd"));
-				memcpy(&fd, (int64_t*)param.m_evt->get_param(0)->m_val, sizeof(fd));
+				fd = param.m_evt->get_syscall_return_value();
 				++callnum;
 			}
 		} else if(param.m_evt->get_type() == PPME_PROCEXIT_1_E && param.m_evt->get_tid() == cpid) {
@@ -753,7 +766,15 @@ TEST_F(sys_call_test, forking_main_thread_exit) {
 		}
 	};
 
-	ASSERT_NO_FATAL_FAILURE({ event_capture::run(test, callback, filter); });
+	ASSERT_NO_FATAL_FAILURE({
+		event_capture::run(test,
+		                   callback,
+		                   filter,
+		                   event_capture::do_nothing,
+		                   event_capture::do_nothing,
+		                   event_capture::do_nothing,
+		                   libsinsp::events::all_sc_set());
+	});
 	EXPECT_EQ(3, callnum);
 }
 
@@ -776,18 +797,10 @@ TEST_F(sys_call_test, forking_main_thread_exit) {
 // Create the initial stale process. It chdir()s to "/dev", stops the
 // inspector, and returns.
 static int stop_sinsp_and_exit(void* arg) {
-	// Get our own, unlocked concurrent inspector handle
-	concurrent_object_handle<sinsp> inspector_handle = *(concurrent_object_handle<sinsp>*)arg;
-
 	if(chdir("/dev") != 0) {
 		return 1;
 	}
 
-	{
-		std::scoped_lock inspector_handle_lock(inspector_handle);
-		inspector_handle->stop_capture();
-	}
-
 	// Wait 5 seconds. This ensures that the state for this
 	// process will be considered stale when the second process
 	// with the same pid runs.
@@ -878,9 +891,9 @@ static pid_t clone_helper(int (*func)(void*),
 }
 
 TEST_F(sys_call_test, remove_stale_thread_clone_exit) {
-	std::atomic<uint32_t> clones_seen(0);
+	uint32_t clones_seen = 0;
 	stale_clone_ctx ctx;
-	std::atomic<pid_t> recycle_pid(0);
+	pid_t recycle_pid;
 	const char* last_pid_filename = "/proc/sys/kernel/ns_last_pid";
 	struct stat info;
 
@@ -903,11 +916,10 @@ TEST_F(sys_call_test, remove_stale_thread_clone_exit) {
 	// uses the recycled pid.
 	event_filter_t filter = [&](sinsp_evt* evt) {
 		sinsp_threadinfo* tinfo = evt->get_thread_info();
-		pid_t rp = recycle_pid.load();
-		return (rp != 0 && tinfo && tinfo->m_tid == rp);
+		return (tinfo && tinfo->m_tid == recycle_pid);
 	};
 
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector_handle) {
+	run_callback_t test = [&](sinsp* inspector) {
 		pid_t launcher_pid;
 		char* launcher_stack = NULL;
 
@@ -921,18 +933,17 @@ TEST_F(sys_call_test, remove_stale_thread_clone_exit) {
 		// This is asynchronous so wait to make sure the thread has started.
 		sleep(1);
 
-		// Start a thread that runs and stops the inspector_handle right
-		// before exiting. This gives us a pid we can use for the
-		// second thread.
-		recycle_pid.store(clone_helper(stop_sinsp_and_exit, &inspector_handle));
-		ASSERT_GE(recycle_pid.load(), 0);
+		// Start a thread that runs, chdir to /dev/ and the exits.
+		// This gives us a pid we can use for the second thread.
+		// We don't want to capture events from this CLONE.
+		inspector->stop_capture();
 
-		// The first thread has started, turned off the capturing, and
+		recycle_pid = clone_helper(stop_sinsp_and_exit, inspector);
+		ASSERT_GE(recycle_pid, 0);
+
+		// The first thread has started, chdir to /dev, and
 		// exited, so start capturing again.
-		{
-			std::scoped_lock inspector_handle_lock(inspector_handle);
-			inspector_handle->start_capture();
-		}
+		inspector->start_capture();
 
 		// Arrange that the next thread/process created has
 		// pid ctx.m_desired pid by writing to
@@ -955,7 +966,7 @@ TEST_F(sys_call_test, remove_stale_thread_clone_exit) {
 
 			ASSERT_EQ(flock(fileno(last_pid_file), LOCK_EX), 0);
 
-			ASSERT_GT(fprintf(last_pid_file, "%d", recycle_pid.load() - 1), 0);
+			ASSERT_GT(fprintf(last_pid_file, "%d", recycle_pid - 1), 0);
 
 			fclose(last_pid_file);
 
@@ -1009,5 +1020,5 @@ TEST_F(sys_call_test, remove_stale_thread_clone_exit) {
 
 	// We must have seen one clone related to the recycled
 	// pid. Otherwise it never actually checked the cwd at all.
-	EXPECT_EQ(clones_seen.load(), 1u);
+	EXPECT_EQ(clones_seen, 1u);
 }
