@@ -52,8 +52,8 @@ limitations under the License.
 TEST_F(sys_call_test, process_signalfd_kill) {
 	int callnum = 0;
 
-	int ptid;          // parent tid
-	int ctid;          // child tid
+	int ptid = -1;     // parent tid
+	int ctid = -1;     // child tid
 	int gptid;         // grandparent tid
 	int xstatus = 33;  // child exit value
 	int ssfd;
@@ -68,7 +68,7 @@ TEST_F(sys_call_test, process_signalfd_kill) {
 	//
 	// TEST CODE
 	//
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector_handle) {
+	run_callback_t test = [&](sinsp* inspector) {
 		int status;
 		int sfd;
 		ctid = fork();
@@ -136,7 +136,7 @@ TEST_F(sys_call_test, process_signalfd_kill) {
 				//
 				// PARENT PROCESS
 				//
-				ptid = getpid();
+				ptid = gettid();
 				gptid = getppid();
 
 				//
@@ -202,7 +202,15 @@ TEST_F(sys_call_test, process_signalfd_kill) {
 		}
 	};
 
-	ASSERT_NO_FATAL_FAILURE({ event_capture::run(test, callback, filter); });
+	ASSERT_NO_FATAL_FAILURE({
+		event_capture::run(test,
+		                   callback,
+		                   filter,
+		                   event_capture::do_nothing,
+		                   event_capture::do_nothing,
+		                   event_capture::do_nothing,
+		                   libsinsp::events::all_sc_set());
+	});
 
 	EXPECT_EQ(7, callnum);
 }
@@ -219,7 +227,7 @@ TEST_F(sys_call_test, DISABLED_process_usleep) {
 	//
 	// TEST CODE
 	//
-	run_callback_t test = [](concurrent_object_handle<sinsp> inspector_handle) {
+	run_callback_t test = [](sinsp* inspector) {
 		struct timespec req;
 		req.tv_sec = 0;
 		req.tv_nsec = 123456;
@@ -271,7 +279,7 @@ TEST_F(sys_call_test, process_inotify) {
 	//
 	// TEST CODE
 	//
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector_handle) {
+	run_callback_t test = [&](sinsp* inspector) {
 		int length;
 		int wd;
 		char buffer[EVENT_BUF_LEN];
@@ -288,9 +296,9 @@ TEST_F(sys_call_test, process_inotify) {
 
 		//
 		// The IN_MODIFY flag causes a notification when a file is written, which should
-		// heppen immediately in captures
+		// happen immediately under /proc/
 		//
-		wd = inotify_add_watch(fd, LIBSINSP_TEST_CAPTURES_PATH, IN_MODIFY | IN_CREATE | IN_OPEN);
+		wd = inotify_add_watch(fd, "/proc/", IN_MODIFY | IN_CREATE | IN_OPEN);
 
 		//
 		// read to determine the event changes
@@ -336,7 +344,15 @@ TEST_F(sys_call_test, process_inotify) {
 		}
 	};
 
-	ASSERT_NO_FATAL_FAILURE({ event_capture::run(test, callback, filter); });
+	ASSERT_NO_FATAL_FAILURE({
+		event_capture::run(test,
+		                   callback,
+		                   filter,
+		                   event_capture::do_nothing,
+		                   event_capture::do_nothing,
+		                   event_capture::do_nothing,
+		                   libsinsp::events::all_sc_set());
+	});
 
 	EXPECT_EQ(3, callnum);
 }
@@ -378,7 +394,7 @@ TEST(procinfo, process_not_existent) {
 
 TEST_F(sys_call_test, process_rlimit) {
 	int callnum = 0;
-
+	struct rlimit curr_rl;
 	//
 	// FILTER
 	//
@@ -387,21 +403,20 @@ TEST_F(sys_call_test, process_rlimit) {
 	//
 	// TEST CODE
 	//
-	run_callback_t test = [](concurrent_object_handle<sinsp> inspector_handle) {
-		struct rlimit rl;
-		sleep(1);
-
+	run_callback_t test = [&](sinsp* inspector) {
 		// Called directly because libc likes prlimit()
 		syscall(SYS_getrlimit, RLIMIT_NOFILE, (struct rlimit*)33);
-		syscall(SYS_getrlimit, RLIMIT_NOFILE, &rl);
-		rl.rlim_cur = 500;
-		rl.rlim_max = 1000;
-		syscall(SYS_setrlimit, RLIMIT_NOFILE, &rl);
-		syscall(SYS_getrlimit, RLIMIT_NOFILE, &rl);
+		syscall(SYS_getrlimit, RLIMIT_NOFILE, &curr_rl);
+
+		struct rlimit new_rl;
+		new_rl.rlim_cur = 5000;
+		new_rl.rlim_max = 10000;
+		syscall(SYS_setrlimit, RLIMIT_NOFILE, &new_rl);
+		syscall(SYS_getrlimit, RLIMIT_NOFILE, &new_rl);
 	};
 
 	//
-	// OUTPUT VALDATION
+	// OUTPUT VALIDATION
 	//
 	captured_event_callback_t callback = [&](const callback_param& param) {
 		sinsp_evt* e = param.m_evt;
@@ -419,8 +434,8 @@ TEST_F(sys_call_test, process_rlimit) {
 				EXPECT_EQ((int64_t)0, std::stoll(e->get_param_value_str("res", false)));
 
 				if(callnum == 7) {
-					EXPECT_EQ((int64_t)500, std::stoll(e->get_param_value_str("cur", false)));
-					EXPECT_EQ((int64_t)1000, std::stoll(e->get_param_value_str("max", false)));
+					EXPECT_EQ((int64_t)5000, std::stoll(e->get_param_value_str("cur", false)));
+					EXPECT_EQ((int64_t)10000, std::stoll(e->get_param_value_str("max", false)));
 				}
 			}
 
@@ -435,8 +450,8 @@ TEST_F(sys_call_test, process_rlimit) {
 			EXPECT_EQ((int64_t)0, std::stoll(e->get_param_value_str("res", false)));
 
 			if(callnum == 5) {
-				EXPECT_EQ((int64_t)500, std::stoll(e->get_param_value_str("cur", false)));
-				EXPECT_EQ((int64_t)1000, std::stoll(e->get_param_value_str("max", false)));
+				EXPECT_EQ((int64_t)5000, std::stoll(e->get_param_value_str("cur", false)));
+				EXPECT_EQ((int64_t)10000, std::stoll(e->get_param_value_str("max", false)));
 			}
 
 			callnum++;
@@ -463,8 +478,8 @@ TEST_F(sys_call_test, process_rlimit) {
 				break;
 			case 5:
 				EXPECT_EQ(0, res);
-				EXPECT_EQ(500, newcur);
-				EXPECT_EQ(1000, newmax);
+				EXPECT_EQ(5000, newcur);
+				EXPECT_EQ(10000, newmax);
 				EXPECT_EQ(-1, oldcur);
 				EXPECT_EQ(-1, oldmax);
 				break;
@@ -472,14 +487,18 @@ TEST_F(sys_call_test, process_rlimit) {
 				EXPECT_EQ(0, res);
 				EXPECT_EQ(-1, newcur);
 				EXPECT_EQ(-1, newmax);
-				EXPECT_EQ(500, oldcur);
-				EXPECT_EQ(1000, oldmax);
+				EXPECT_EQ(5000, oldcur);
+				EXPECT_EQ(10000, oldmax);
 				break;
 			}
 			callnum++;
 		}
 	};
 
+	after_capture_t cleanup = [&](sinsp* inspector) {
+		syscall(SYS_setrlimit, RLIMIT_NOFILE, &curr_rl);
+	};
+
 	ASSERT_NO_FATAL_FAILURE({ event_capture::run(test, callback, filter); });
 
 	EXPECT_EQ(8, callnum);
@@ -487,7 +506,6 @@ TEST_F(sys_call_test, process_rlimit) {
 
 TEST_F(sys_call_test, process_prlimit) {
 	int callnum = 0;
-	struct rlimit tmprl;
 	struct rlimit orirl;
 
 	//
@@ -498,13 +516,13 @@ TEST_F(sys_call_test, process_prlimit) {
 	//
 	// TEST CODE
 	//
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector_handle) {
+	run_callback_t test = [&](sinsp* inspector) {
 		struct rlimit newrl;
 		struct rlimit oldrl;
 
 		syscall(SYS_prlimit64, getpid(), RLIMIT_NOFILE, NULL, &orirl);
-		newrl.rlim_cur = 500;
-		newrl.rlim_max = 1000;
+		newrl.rlim_cur = 5000;
+		newrl.rlim_max = 10000;
 		syscall(SYS_prlimit64, getpid(), RLIMIT_NOFILE, &newrl, &oldrl);
 		syscall(SYS_prlimit64, getpid(), RLIMIT_NOFILE, NULL, &oldrl);
 	};
@@ -532,8 +550,8 @@ TEST_F(sys_call_test, process_prlimit) {
 				EXPECT_EQ((int64_t)orirl.rlim_max,
 				          std::stoll(e->get_param_value_str("oldmax", false)));
 			} else if(callnum == 3) {
-				EXPECT_EQ((int64_t)500, std::stoll(e->get_param_value_str("newcur", false)));
-				EXPECT_EQ((int64_t)1000, std::stoll(e->get_param_value_str("newmax", false)));
+				EXPECT_EQ((int64_t)5000, std::stoll(e->get_param_value_str("newcur", false)));
+				EXPECT_EQ((int64_t)10000, std::stoll(e->get_param_value_str("newmax", false)));
 				EXPECT_EQ((int64_t)orirl.rlim_cur,
 				          std::stoll(e->get_param_value_str("oldcur", false)));
 				EXPECT_EQ((int64_t)orirl.rlim_max,
@@ -541,19 +559,26 @@ TEST_F(sys_call_test, process_prlimit) {
 			} else if(callnum == 5) {
 				EXPECT_EQ((int64_t)0, std::stoll(e->get_param_value_str("newcur", false)));
 				EXPECT_EQ((int64_t)0, std::stoll(e->get_param_value_str("newmax", false)));
-				EXPECT_EQ((int64_t)500, std::stoll(e->get_param_value_str("oldcur", false)));
-				EXPECT_EQ((int64_t)1000, std::stoll(e->get_param_value_str("oldmax", false)));
+				EXPECT_EQ((int64_t)5000, std::stoll(e->get_param_value_str("oldcur", false)));
+				EXPECT_EQ((int64_t)10000, std::stoll(e->get_param_value_str("oldmax", false)));
 			}
 
 			callnum++;
 		}
 	};
 
-	if(syscall(SYS_prlimit64, getpid(), RLIMIT_NOFILE, NULL, &tmprl) != 0) {
-		return;
-	}
+	after_capture_t cleanup = [&](sinsp* inspector) {
+		syscall(SYS_prlimit64, getpid(), RLIMIT_NOFILE, &orirl, NULL);
+	};
 
-	ASSERT_NO_FATAL_FAILURE({ event_capture::run(test, callback, filter); });
+	ASSERT_NO_FATAL_FAILURE({
+		event_capture::run(test,
+		                   callback,
+		                   filter,
+		                   event_capture::do_nothing,
+		                   event_capture::do_nothing,
+		                   cleanup);
+	});
 
 	EXPECT_EQ(6, callnum);
 }
@@ -617,7 +642,7 @@ TEST_F(sys_call_test, process_scap_proc_get) {
 	//
 	// TEST CODE
 	//
-	run_callback_t test = [](concurrent_object_handle<sinsp> inspector_handle) {
+	run_callback_t test = [](sinsp* inspector) {
 		usleep(1000);
 
 		int s = socket(PF_INET, SOCK_STREAM, IPPROTO_TCP);
@@ -715,7 +740,7 @@ TEST_F(sys_call_test, procinfo_processchild_cpuload) {
 	//
 	// TEST CODE
 	//
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector_handle) {
+	run_callback_t test = [&](sinsp* inspector) {
 		for(uint32_t j = 0; j < 5; j++) {
 			sleep(1);
 		}
@@ -737,11 +762,7 @@ TEST_F(sys_call_test, procinfo_processchild_cpuload) {
 
 			if(tinfo) {
 				if(tinfo->m_tid == ctid) {
-					uint64_t tcpu;
-
-					const sinsp_evt_param* parinfo = e->get_param(0);
-					// tcpu = *(uint64_t*)parinfo->m_val;
-					memcpy(&tcpu, parinfo->m_val, sizeof(uint64_t));
+					auto tcpu = e->get_param(0)->as<uint64_t>();
 
 					uint64_t delta = tcpu - lastcpu;
 
@@ -786,7 +807,7 @@ TEST_F(sys_call_test, procinfo_two_processchilds_cpuload) {
 	//
 	// TEST CODE
 	//
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector_handle) {
+	run_callback_t test = [&](sinsp* inspector) {
 		for(uint32_t j = 0; j < 5; j++) {
 			sleep(1);
 		}
@@ -810,10 +831,7 @@ TEST_F(sys_call_test, procinfo_two_processchilds_cpuload) {
 
 			if(tinfo) {
 				if(tinfo->m_tid == ctid) {
-					uint64_t tcpu;
-
-					const sinsp_evt_param* parinfo = e->get_param(0);
-					tcpu = *(uint64_t*)parinfo->m_val;
+					auto tcpu = e->get_param(0)->as<uint64_t>();
 
 					uint64_t delta = tcpu - lastcpu;
 
@@ -826,10 +844,7 @@ TEST_F(sys_call_test, procinfo_two_processchilds_cpuload) {
 
 					callnum++;
 				} else if(tinfo->m_tid == ctid1) {
-					uint64_t tcpu;
-
-					const sinsp_evt_param* parinfo = e->get_param(0);
-					tcpu = *(uint64_t*)parinfo->m_val;
+					auto tcpu = e->get_param(0)->as<uint64_t>();
 
 					uint64_t delta = tcpu - lastcpu1;
 
