@@ -38,6 +38,8 @@ public:
 	~subprocess();
 
 	void wait_for_start();
+	void kill();
+	bool is_alive();
 	int wait();
 
 	pid_t get_pid();
