@@ -95,7 +95,7 @@ TEST_F(sys_call_test, stat) {
 		return evt_name.find("stat") != std::string::npos && m_tid_filter(evt);
 	};
 
-	run_callback_t test = [](concurrent_object_handle<sinsp> inspector_handle) {
+	run_callback_t test = [](sinsp* inspector) {
 		struct stat sb;
 		stat("/tmp", &sb);
 	};
@@ -114,7 +114,7 @@ TEST_F(sys_call_test, open_close) {
 		       m_tid_filter(evt);
 	};
 
-	run_callback_t test = [](concurrent_object_handle<sinsp> inspector_handle) {
+	run_callback_t test = [](sinsp* inspector) {
 		int fd = open("/tmp", O_RDONLY);
 		close(fd);
 	};
@@ -135,7 +135,7 @@ TEST_F(sys_call_test, open_close) {
 TEST_F(sys_call_test, open_close_dropping) {
 	int callnum = 0;
 
-	before_open_t setup = [&](sinsp* inspector) { inspector->start_dropping_mode(1); };
+	before_capture_t setup = [&](sinsp* inspector) { inspector->start_dropping_mode(1); };
 
 	event_filter_t filter = [&](sinsp_evt* evt) {
 		return (0 == strcmp(evt->get_name(), "open") || 0 == strcmp(evt->get_name(), "openat") ||
@@ -143,7 +143,7 @@ TEST_F(sys_call_test, open_close_dropping) {
 		       m_tid_filter(evt);
 	};
 
-	run_callback_t test = [](concurrent_object_handle<sinsp> inspector_handle) {
+	run_callback_t test = [](sinsp* inspector) {
 		int fd = open("/tmp", O_RDONLY);
 		close(fd);
 	};
@@ -157,9 +157,7 @@ TEST_F(sys_call_test, open_close_dropping) {
 		}
 	};
 
-	before_close_t cleanup = [&](sinsp* inspector) { inspector->stop_dropping_mode(); };
-
-	ASSERT_NO_FATAL_FAILURE({ event_capture::run(test, callback, filter, setup, cleanup); });
+	ASSERT_NO_FATAL_FAILURE({ event_capture::run(test, callback, filter, setup); });
 	EXPECT_EQ(2, callnum);
 }
 
@@ -170,9 +168,7 @@ TEST_F(sys_call_test, fcntl_getfd) {
 		return 0 == strcmp(evt->get_name(), "fcntl") && m_tid_filter(evt);
 	};
 
-	run_callback_t test = [](concurrent_object_handle<sinsp> inspector_handle) {
-		fcntl(0, F_GETFL);
-	};
+	run_callback_t test = [](sinsp* inspector) { fcntl(0, F_GETFL); };
 
 	captured_event_callback_t callback = [&](const callback_param& param) { callnum++; };
 
@@ -183,21 +179,18 @@ TEST_F(sys_call_test, fcntl_getfd) {
 TEST_F(sys_call_test, fcntl_getfd_dropping) {
 	int callnum = 0;
 
-	before_open_t setup = [&](sinsp* inspector) { inspector->start_dropping_mode(1); };
+	before_capture_t setup = [](sinsp* inspector) { inspector->start_dropping_mode(1); };
 
 	event_filter_t filter = [&](sinsp_evt* evt) {
 		return 0 == strcmp(evt->get_name(), "fcntl") && m_tid_filter(evt);
 	};
 
-	run_callback_t test = [](concurrent_object_handle<sinsp> inspector_handle) {
-		fcntl(0, F_GETFL);
-	};
+	run_callback_t test = [](sinsp* inspector) { fcntl(0, F_GETFL); };
 
 	captured_event_callback_t callback = [&](const callback_param& param) { callnum++; };
 
-	before_close_t cleanup = [&](sinsp* inspector) { inspector->stop_dropping_mode(); };
-
-	ASSERT_NO_FATAL_FAILURE({ event_capture::run(test, callback, filter, setup, cleanup); });
+	ASSERT_NO_FATAL_FAILURE(
+	        { event_capture::run(test, callback, filter, event_capture::do_nothing, setup); });
 	EXPECT_EQ(0, callnum);
 }
 
@@ -207,9 +200,7 @@ TEST_F(sys_call_test, bind_error) {
 		return 0 == strcmp(evt->get_name(), "bind") && m_tid_filter(evt);
 	};
 
-	run_callback_t test = [](concurrent_object_handle<sinsp> inspector_handle) {
-		bind(0, NULL, 0);
-	};
+	run_callback_t test = [](sinsp* inspector) { bind(0, NULL, 0); };
 
 	captured_event_callback_t callback = [&](const callback_param& param) { callnum++; };
 
@@ -220,21 +211,18 @@ TEST_F(sys_call_test, bind_error) {
 TEST_F(sys_call_test, bind_error_dropping) {
 	int callnum = 0;
 
-	before_open_t setup = [&](sinsp* inspector) { inspector->start_dropping_mode(1); };
+	before_capture_t setup = [&](sinsp* inspector) { inspector->start_dropping_mode(1); };
 
 	event_filter_t filter = [&](sinsp_evt* evt) {
 		return 0 == strcmp(evt->get_name(), "bind") && m_tid_filter(evt);
 	};
 
-	run_callback_t test = [](concurrent_object_handle<sinsp> inspector_handle) {
-		bind(0, NULL, 0);
-	};
+	run_callback_t test = [](sinsp* inspector) { bind(0, NULL, 0); };
 
 	captured_event_callback_t callback = [&](const callback_param& param) { callnum++; };
 
-	before_close_t cleanup = [&](sinsp* inspector) { inspector->stop_dropping_mode(); };
-
-	ASSERT_NO_FATAL_FAILURE({ event_capture::run(test, callback, filter, setup, cleanup); });
+	ASSERT_NO_FATAL_FAILURE(
+	        { event_capture::run(test, callback, filter, event_capture::do_nothing, setup); });
 	EXPECT_EQ(1, callnum);
 }
 
@@ -244,7 +232,7 @@ TEST_F(sys_call_test, close_badfd) {
 		return 0 == strcmp(evt->get_name(), "close") && m_tid_filter(evt);
 	};
 
-	run_callback_t test = [](concurrent_object_handle<sinsp> inspector_handle) {
+	run_callback_t test = [](sinsp* inspector) {
 		close(-1);
 		close(INT_MAX);
 	};
@@ -265,13 +253,13 @@ TEST_F(sys_call_test, close_badfd) {
 TEST_F(sys_call_test, close_badfd_dropping) {
 	int callnum = 0;
 
-	before_open_t setup = [&](sinsp* inspector) { inspector->start_dropping_mode(1); };
+	before_capture_t setup = [&](sinsp* inspector) { inspector->start_dropping_mode(1); };
 
 	event_filter_t filter = [&](sinsp_evt* evt) {
 		return 0 == strcmp(evt->get_name(), "close") && m_tid_filter(evt);
 	};
 
-	run_callback_t test = [](concurrent_object_handle<sinsp> inspector_handle) {
+	run_callback_t test = [](sinsp* inspector) {
 		close(-1);
 		close(INT_MAX);
 	};
@@ -285,9 +273,8 @@ TEST_F(sys_call_test, close_badfd_dropping) {
 		}
 	};
 
-	before_close_t cleanup = [&](sinsp* inspector) { inspector->stop_dropping_mode(); };
-
-	ASSERT_NO_FATAL_FAILURE({ event_capture::run(test, callback, filter, setup, cleanup); });
+	ASSERT_NO_FATAL_FAILURE(
+	        { event_capture::run(test, callback, filter, event_capture::do_nothing, setup); });
 	EXPECT_EQ(0, callnum);
 }
 
@@ -305,7 +292,7 @@ TEST_F(sys_call_test, poll_timeout) {
 
 	std::string my_pipe[2];
 
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector_handle) {
+	run_callback_t test = [&](sinsp* inspector) {
 		subprocess handle(LIBSINSP_TEST_PATH "/test_helper", {"poll_timeout"});
 		std::stringstream ss;
 		ss << handle.out();
@@ -376,7 +363,7 @@ TEST_F(sys_call_test, ioctl) {
 	event_filter_t filter = [&](sinsp_evt* evt) { return m_tid_filter(evt); };
 
 	int status;
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector_handle) {
+	run_callback_t test = [&](sinsp* inspector) {
 		int fd;
 
 		fd = open("/dev/ttyS0", O_RDONLY);
@@ -413,7 +400,7 @@ TEST_F(sys_call_test, shutdown) {
 	event_filter_t filter = [&](sinsp_evt* evt) { return m_tid_filter(evt); };
 
 	int sock;
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector_handle) {
+	run_callback_t test = [&](sinsp* inspector) {
 		if((sock = socket(PF_INET, SOCK_STREAM, IPPROTO_TCP)) < 0) {
 			FAIL() << "socket() failed";
 			return;
@@ -459,7 +446,7 @@ TEST_F(sys_call_test, timerfd) {
 	event_filter_t filter = [&](sinsp_evt* evt) { return m_tid_filter(evt); };
 
 	int fd;
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector_handle) {
+	run_callback_t test = [&](sinsp* inspector) {
 		int ret;
 		unsigned int ns;
 		unsigned int sec;
@@ -512,7 +499,15 @@ TEST_F(sys_call_test, timerfd) {
 		}
 	};
 
-	ASSERT_NO_FATAL_FAILURE({ event_capture::run(test, callback, filter); });
+	ASSERT_NO_FATAL_FAILURE({
+		event_capture::run(test,
+		                   callback,
+		                   filter,
+		                   event_capture::do_nothing,
+		                   event_capture::do_nothing,
+		                   event_capture::do_nothing,
+		                   libsinsp::events::all_sc_set());
+	});
 
 	EXPECT_EQ(3, callnum);
 }
@@ -523,9 +518,20 @@ TEST_F(sys_call_test, timestamp) {
 	uint64_t timestampv[20];
 	int callnum = 0;
 
+	before_capture_t setup = [&](sinsp* inspector) {
+		// Drop all but generic syscalls (since PPM_SC_GETTIMEOFDAY is generic)
+		// to avoid drops.
+		const auto state_sc_set = libsinsp::events::sinsp_state_sc_set();
+		for(int i = 0; i < PPM_SC_MAX; i++) {
+			if((ppm_sc_code)i != PPM_SC_GETTIMEOFDAY) {
+				inspector->mark_ppm_sc_of_interest((ppm_sc_code)i, false);
+			}
+		}
+	};
+
 	event_filter_t filter = [&](sinsp_evt* evt) { return m_tid_filter(evt); };
 
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector_handle) {
+	run_callback_t test = [&](sinsp* inspector) {
 		useconds_t sleep_period = 10;
 		struct timeval tv;
 		for(uint32_t j = 0; j < sizeof(timestampv) / sizeof(timestampv[0]); ++j) {
@@ -545,7 +551,8 @@ TEST_F(sys_call_test, timestamp) {
 		}
 	};
 
-	ASSERT_NO_FATAL_FAILURE({ event_capture::run(test, callback, filter); });
+	ASSERT_NO_FATAL_FAILURE(
+	        { event_capture::run(test, callback, filter, event_capture::do_nothing, setup); });
 	EXPECT_EQ((int)(sizeof(timestampv) / sizeof(timestampv[0])), callnum);
 }
 
@@ -554,7 +561,7 @@ TEST_F(sys_call_test, brk) {
 
 	event_filter_t filter = [&](sinsp_evt* evt) { return m_tid_filter(evt); };
 
-	run_callback_t test = [](concurrent_object_handle<sinsp> inspector_handle) {
+	run_callback_t test = [](sinsp* inspector) {
 		sbrk(1000);
 		sbrk(100000);
 	};
@@ -616,7 +623,7 @@ TEST_F(sys_call_test, mmap) {
 
 	void* p;
 
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector_handle) {
+	run_callback_t test = [&](sinsp* inspector) {
 		munmap((void*)0x50, 300);
 		p = mmap(0,
 		         0,
@@ -770,7 +777,7 @@ TEST_F(sys_call_test, quotactl_ko) {
 		       evt->get_type() == PPME_SYSCALL_QUOTACTL_E;
 	};
 
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector_handle) {
+	run_callback_t test = [&](sinsp* inspector) {
 		quotactl(QCMD(Q_QUOTAON, USRQUOTA),
 		         "/dev/xxx",
 		         2,
@@ -839,7 +846,7 @@ TEST_F(sys_call_test, quotactl_ok) {
 
 	struct dqblk mydqblk;
 	struct dqinfo mydqinfo;
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector_handle) {
+	run_callback_t test = [&](sinsp* inspector) {
 		quotactl(QCMD(Q_QUOTAON, USRQUOTA),
 		         "/dev/loop0",
 		         2,
@@ -939,7 +946,7 @@ TEST_F(sys_call_test, getsetuid_and_gid) {
 
 	event_filter_t filter = [&](sinsp_evt* evt) { return m_tid_filter(evt); };
 
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector_handle) {
+	run_callback_t test = [&](sinsp* inspector) {
 		auto res = setuid(0);
 		EXPECT_EQ(0, res);
 		res = setgid(test_gid);
@@ -1024,7 +1031,7 @@ TEST_F(sys_call_test32, execve_ia32_emulation) {
 	int callnum = 0;
 
 	std::unique_ptr<sinsp_filter> is_subprocess_execve;
-	before_open_t before_open = [&](sinsp* inspector) {
+	before_capture_t before_open = [&](sinsp* inspector) {
 		sinsp_filter_compiler compiler(inspector,
 		                               "evt.type=execve and proc.apid=" + std::to_string(getpid()));
 		is_subprocess_execve = compiler.compile();
@@ -1032,7 +1039,7 @@ TEST_F(sys_call_test32, execve_ia32_emulation) {
 
 	event_filter_t filter = [&](sinsp_evt* evt) { return is_subprocess_execve->run(evt); };
 
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector_handle) {
+	run_callback_t test = [&](sinsp* inspector) {
 		auto ret = system(LIBSINSP_TEST_RESOURCES_PATH "execve32 " LIBSINSP_TEST_RESOURCES_PATH
 		                                               "execve " LIBSINSP_TEST_RESOURCES_PATH
 		                                               "execve32");
@@ -1081,7 +1088,9 @@ TEST_F(sys_call_test32, execve_ia32_emulation) {
 			}
 		}
 	};
-	ASSERT_NO_FATAL_FAILURE({ event_capture::run(test, callback, filter, before_open); });
+	ASSERT_NO_FATAL_FAILURE({
+		event_capture::run(test, callback, filter, event_capture::do_nothing, before_open);
+	});
 	EXPECT_EQ(8, callnum);
 }
 
@@ -1093,7 +1102,7 @@ TEST_F(sys_call_test32, quotactl_ko) {
 		       evt->get_type() == PPME_SYSCALL_QUOTACTL_E;
 	};
 
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector_handle) {
+	run_callback_t test = [&](sinsp* inspector) {
 		subprocess handle(LIBSINSP_TEST_PATH "/test_helper_32", {"quotactl_ko"});
 		handle.wait();
 	};
@@ -1140,7 +1149,7 @@ TEST_F(sys_call_test, setns_test) {
 		return m_tid_filter(evt) &&
 		       (evt->get_type() == PPME_SYSCALL_SETNS_E || evt->get_type() == PPME_SYSCALL_SETNS_X);
 	};
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector_handle) {
+	run_callback_t test = [&](sinsp* inspector) {
 		fd = open("/proc/self/ns/net", O_RDONLY);
 		ASSERT_NE(0, fd);
 		ASSERT_EQ(0, setns(fd, CLONE_NEWNET));
@@ -1171,7 +1180,7 @@ TEST_F(sys_call_test, unshare_) {
 		       (evt->get_type() == PPME_SYSCALL_UNSHARE_E ||
 		        evt->get_type() == PPME_SYSCALL_UNSHARE_X);
 	};
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector_handle) {
+	run_callback_t test = [&](sinsp* inspector) {
 		auto child = fork();
 		if(child == 0) {
 			unshare(CLONE_NEWUTS);
@@ -1203,7 +1212,7 @@ TEST_F(sys_call_test, sendmsg_recvmsg_SCM_RIGHTS) {
 		auto tinfo = evt->get_thread_info(true);
 		return tinfo->get_comm() == "libsinsp_e2e_te" && evt->get_type() == PPME_SOCKET_RECVMSG_X;
 	};
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector_handle) {
+	run_callback_t test = [&](sinsp* inspector) {
 		int server_sd, worker_sd, pair_sd[2];
 		int rc = socketpair(AF_UNIX, SOCK_DGRAM, 0, pair_sd);
 		ASSERT_GE(rc, 0);
@@ -1290,7 +1299,7 @@ TEST_F(sys_call_test, ppoll_timeout) {
 		       ti->m_comm == "test_helper";
 	};
 
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector) {
+	run_callback_t test = [&](sinsp* inspector) {
 		subprocess handle(LIBSINSP_TEST_PATH "/test_helper", {"ppoll_timeout"});
 		handle.wait();
 	};
@@ -1355,13 +1364,15 @@ TEST_F(sys_call_test, getsetresuid_and_gid) {
 	ret = system("groupdel testsetresgid");
 	usleep(200);
 
+	const pid_t self = getpid();
+
 	//
 	// FILTER
 	//
 	event_filter_t filter = [&](sinsp_evt* evt) {
 		auto type = evt->get_type();
 		auto tinfo = evt->get_thread_info(true);
-		return tinfo->m_comm != "sudo" &&
+		return tinfo->m_comm != "sudo" && tinfo->m_pid == self &&
 		       (type == PPME_USER_ADDED_E || type == PPME_USER_ADDED_X ||
 		        type == PPME_GROUP_ADDED_E || type == PPME_GROUP_ADDED_X ||
 		        type == PPME_SYSCALL_GETRESUID_E || type == PPME_SYSCALL_GETRESUID_X ||
@@ -1373,7 +1384,7 @@ TEST_F(sys_call_test, getsetresuid_and_gid) {
 	//
 	// TEST CODE
 	//
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector) {
+	run_callback_t test = [&](sinsp* inspector) {
 		char command[] =
 		        "useradd -u 5454 testsetresuid && "
 		        "groupadd -g 6565 testsetresgid && "
@@ -1453,19 +1464,29 @@ TEST_F(sys_call_test, getsetresuid_and_gid) {
 		}
 	};
 
-	before_close_t cleanup = [&](sinsp* inspector) {
+	after_capture_t after_capture = [&](sinsp* inspector) {
 		int result = 0;
 
 		result += setresuid(orig_uids[0], orig_uids[1], orig_uids[2]);
 		result += setresgid(orig_gids[0], orig_gids[1], orig_gids[2]);
 
+		// Clean environment
+		result += system("userdel testsetresuid");
+		result += system("groupdel testsetresgid");
+
 		if(result != 0) {
 			FAIL() << "Cannot restore initial id state.";
 		}
 	};
 
-	ASSERT_NO_FATAL_FAILURE(
-	        { event_capture::run(test, callback, filter, event_capture::do_nothing, cleanup); });
+	ASSERT_NO_FATAL_FAILURE({
+		event_capture::run(test,
+		                   callback,
+		                   filter,
+		                   event_capture::do_nothing,
+		                   event_capture::do_nothing,
+		                   after_capture);
+	});
 	EXPECT_EQ(8, callnum);
 }
 
@@ -1484,7 +1505,7 @@ TEST_F(sys_call_test, failing_execve) {
 	printf("%s %s %s %s %s\n", eargv[0], eargv[1], eargv[2], eargv[3], eargv[4]);
 	printf("%s %s %s %s\n", eenvp[0], eenvp[1], eenvp[2], eenvp[3]);
 
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector) {
+	run_callback_t test = [&](sinsp* inspector) {
 		int ret = execve(eargv[0], (char* const*)eargv, (char* const*)eenvp);
 		ASSERT_TRUE(ret < 0);
 	};
@@ -1537,7 +1558,7 @@ TEST_F(sys_call_test, large_execve) {
 		buf.append(std::to_string(random()));
 	}
 
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector) {
+	run_callback_t test = [&](sinsp* inspector) {
 		ctid = fork();
 
 		if(ctid < 0) {
@@ -1623,7 +1644,7 @@ TEST_F(sys_call_test32, failing_execve) {
 
 	// INIT FILTER
 	std::unique_ptr<sinsp_filter> is_subprocess_execve;
-	before_open_t before_open = [&](sinsp* inspector) {
+	before_capture_t before_open = [&](sinsp* inspector) {
 		sinsp_filter_compiler compiler(inspector,
 		                               "evt.type=execve and proc.apid=" + std::to_string(getpid()));
 		is_subprocess_execve.reset(compiler.compile().release());
@@ -1637,7 +1658,7 @@ TEST_F(sys_call_test32, failing_execve) {
 	//
 	// TEST CODE
 	//
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector) {
+	run_callback_t test = [&](sinsp* inspector) {
 		auto ret = system(LIBSINSP_TEST_RESOURCES_PATH "execve32_fail");
 		ASSERT_TRUE(ret > 0);
 		ret = system(LIBSINSP_TEST_RESOURCES_PATH "execve32 ./fail");
@@ -1709,7 +1730,9 @@ TEST_F(sys_call_test32, failing_execve) {
 			}
 		}
 	};
-	ASSERT_NO_FATAL_FAILURE({ event_capture::run(test, callback, filter, before_open); });
+	ASSERT_NO_FATAL_FAILURE({
+		event_capture::run(test, callback, filter, event_capture::do_nothing, before_open);
+	});
 	EXPECT_EQ(10, callnum);
 }
 
@@ -1727,12 +1750,12 @@ TEST_F(sys_call_test32, mmap) {
 		return tinfo && tinfo->m_comm == "test_helper_32" && ps_filter(evt);
 	};
 
-	uint64_t p = 0;
+	uint64_t p = -1;
 
 	//
 	// TEST CODE
 	//
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector_handle) {
+	run_callback_t test = [&](sinsp* inspector) {
 		subprocess handle(LIBSINSP_TEST_PATH "/test_helper_32",
 		                  {
 		                          "mmap_test",
@@ -1743,10 +1766,8 @@ TEST_F(sys_call_test32, mmap) {
 		errno2 = std::stoi(tmp.str());
 		tmp.clear();
 		tmp.str("");
-		tmp << handle.out();
-		p = (uint64_t)std::stoul(tmp.str());
-		tmp.clear();
-		tmp.str("");
+		tmp << std::hex << handle.out();
+		tmp >> p;
 		handle.wait();
 	};
 
@@ -1774,8 +1795,7 @@ TEST_F(sys_call_test32, mmap) {
 				EXPECT_EQ("300", e->get_param_value_str("length"));
 				break;
 			case 7: {
-				uint64_t addr = 0;
-				memcpy(&addr, e->get_param_by_name("addr")->m_val, sizeof(uint64_t));
+				auto addr = e->get_param_by_name("addr")->as<uint64_t>();
 #ifdef __LP64__
 				EXPECT_EQ((uint64_t)p, addr);
 #else
@@ -1790,8 +1810,8 @@ TEST_F(sys_call_test32, mmap) {
 		} else if(type == PPME_SYSCALL_MUNMAP_X) {
 			callnum++;
 
-			memcpy(&exit_vmsize, e->get_param_by_name("vm_size")->m_val, sizeof(uint32_t));
-			memcpy(&exit_vmrss, e->get_param_by_name("vm_rss")->m_val, sizeof(uint32_t));
+			exit_vmsize = e->get_param_by_name("vm_size")->as<uint32_t>();
+			exit_vmrss = e->get_param_by_name("vm_rss")->as<uint32_t>();
 			EXPECT_EQ(e->get_thread_info(false)->m_vmsize_kb, exit_vmsize);
 			EXPECT_EQ(e->get_thread_info(false)->m_vmrss_kb, exit_vmrss);
 
@@ -1848,22 +1868,20 @@ TEST_F(sys_call_test32, mmap) {
 		} else if(type == PPME_SYSCALL_MMAP_X || type == PPME_SYSCALL_MMAP2_X) {
 			callnum++;
 
-			memcpy(&exit_vmsize, e->get_param_by_name("vm_size")->m_val, sizeof(uint32_t));
-			memcpy(&exit_vmrss, e->get_param_by_name("vm_rss")->m_val, sizeof(uint32_t));
+			exit_vmsize = e->get_param_by_name("vm_size")->as<uint32_t>();
+			exit_vmrss = e->get_param_by_name("vm_rss")->as<uint32_t>();
 			EXPECT_EQ(e->get_thread_info(false)->m_vmsize_kb, exit_vmsize);
 			EXPECT_EQ(e->get_thread_info(false)->m_vmrss_kb, exit_vmrss);
 
 			switch(callnum) {
 			case 4: {
-				uint64_t res = 0;
-				memcpy(&res, e->get_param_by_name("res")->m_val, sizeof(uint64_t));
-				EXPECT_EQ(-errno2, (int64_t)res);
+				auto res = e->get_param_by_name("res")->as<int64_t>();
+				EXPECT_EQ(-errno2, res);
 				break;
 			}
 			case 6: {
-				uint64_t res = 0;
-				memcpy(&res, e->get_param_by_name("res")->m_val, sizeof(uint64_t));
-				EXPECT_EQ((uint64_t)p, res);
+				auto res = e->get_param_by_name("res")->as<int64_t>();
+				EXPECT_EQ(p, res);
 				EXPECT_GT(exit_vmsize, enter_vmsize + 500);
 				EXPECT_GE(exit_vmrss, enter_vmrss);
 				break;
@@ -1889,7 +1907,7 @@ TEST_F(sys_call_test32, ppoll_timeout) {
 
 	std::string my_pipe[2];
 
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector) {
+	run_callback_t test = [&](sinsp* inspector) {
 		subprocess handle(LIBSINSP_TEST_PATH "/test_helper_32",
 		                  {
 		                          "ppoll_timeout",
@@ -1976,7 +1994,7 @@ TEST_F(sys_call_test32, fs_preadv) {
 	//
 	// TEST CODE
 	//
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector) {
+	run_callback_t test = [&](sinsp* inspector) {
 		subprocess test_proc(LIBSINSP_TEST_PATH "/test_helper_32", {"preadv_pwritev"});
 		fd = std::stoi(test_proc.out());
 		int bool_n = std::stoi(test_proc.out());
@@ -2075,38 +2093,33 @@ TEST_F(sys_call_test, thread_lookup_static) {
 	event_filter_t filter = [&](sinsp_evt* evt) {
 		return evt->get_type() != PPME_PROCEXIT_1_E && evt->get_tid() > 0;
 	};
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector) { return; };
-	captured_event_callback_t callback = [&](const callback_param& param) { return; };
-	scap_linux_platform* platform;
+	run_callback_t test = [&](sinsp* inspector) { return; };
+	captured_event_callback_t callback = [&](const callback_param& param) {
+		auto* platform = (scap_linux_platform*)param.m_inspector->get_scap_platform();
+		ASSERT_EQ(SCAP_SUCCESS,
+		          scap_proc_read_thread(platform, proc, 1, &scap_tinfo, err_buf, false));
 
-	before_close_t before_close = [&](sinsp* inspector) {
-		platform = (scap_linux_platform*)inspector->get_scap_platform();
+		EXPECT_EQ(1, scap_tinfo.tid);
+		EXPECT_EQ(1, scap_tinfo.pid);
+		EXPECT_EQ(1, scap_tinfo.vtid);
+		EXPECT_EQ(0, scap_tinfo.ptid);
+
+		ASSERT_EQ(SCAP_SUCCESS,
+		          scap_proc_read_thread(platform, proc, 62725, &scap_tinfo, err_buf, false));
+		EXPECT_EQ(62725, scap_tinfo.tid);
+		EXPECT_EQ(62725, scap_tinfo.pid);
+		EXPECT_EQ(62725, scap_tinfo.vtid);
+		EXPECT_EQ(1, scap_tinfo.ptid);
+
+		ASSERT_EQ(SCAP_SUCCESS,
+		          scap_proc_read_thread(platform, proc, 62727, &scap_tinfo, err_buf, false));
+		EXPECT_EQ(62727, scap_tinfo.tid);
+		EXPECT_EQ(62725, scap_tinfo.pid);
+		EXPECT_EQ(62727, scap_tinfo.vtid);
+		EXPECT_EQ(1, scap_tinfo.ptid);
 	};
 
-	ASSERT_NO_FATAL_FAILURE({
-		event_capture::run(test, callback, filter, event_capture::do_nothing, before_close);
-	});
-
-	ASSERT_EQ(SCAP_SUCCESS, scap_proc_read_thread(platform, proc, 1, &scap_tinfo, err_buf, false));
-
-	EXPECT_EQ(1, scap_tinfo.tid);
-	EXPECT_EQ(1, scap_tinfo.pid);
-	EXPECT_EQ(1, scap_tinfo.vtid);
-	EXPECT_EQ(0, scap_tinfo.ptid);
-
-	ASSERT_EQ(SCAP_SUCCESS,
-	          scap_proc_read_thread(platform, proc, 62725, &scap_tinfo, err_buf, false));
-	EXPECT_EQ(62725, scap_tinfo.tid);
-	EXPECT_EQ(62725, scap_tinfo.pid);
-	EXPECT_EQ(62725, scap_tinfo.vtid);
-	EXPECT_EQ(1, scap_tinfo.ptid);
-
-	ASSERT_EQ(SCAP_SUCCESS,
-	          scap_proc_read_thread(platform, proc, 62727, &scap_tinfo, err_buf, false));
-	EXPECT_EQ(62727, scap_tinfo.tid);
-	EXPECT_EQ(62725, scap_tinfo.pid);
-	EXPECT_EQ(62727, scap_tinfo.vtid);
-	EXPECT_EQ(1, scap_tinfo.ptid);
+	ASSERT_NO_FATAL_FAILURE({ event_capture::run(test, callback, filter); });
 }
 
 TEST_F(sys_call_test, thread_lookup_live) {
@@ -2119,7 +2132,7 @@ TEST_F(sys_call_test, thread_lookup_live) {
 	event_filter_t filter = [&](sinsp_evt* evt) {
 		return evt->get_type() != PPME_PROCEXIT_1_E && evt->get_tid() > 0;
 	};
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector) {
+	run_callback_t test = [&](sinsp* inspector) {
 		// a very short sleep to gather some events,
 		// we'll take much longer than this to process them all
 		usleep(1000);
@@ -2153,35 +2166,35 @@ TEST_F(sys_call_test, thread_lookup_live) {
 		}
 	};
 
-	scap_linux_platform* platform;
-
-	before_close_t before_close = [&](sinsp* inspector) {
+	after_capture_t after_capture = [&](sinsp* inspector) {
 		// close scap to maintain the num_consumers at exit == 0 assertion
 		// close_capture(scap, platform);
-		platform = (scap_linux_platform*)inspector->get_scap_platform();
+		auto platform = (scap_linux_platform*)inspector->get_scap_platform();
+
+		ASSERT_EQ(SCAP_SUCCESS,
+		          scap_proc_read_thread(platform, proc, getpid(), &scap_tinfo, err_buf, false));
+		EXPECT_EQ(getpid(), scap_tinfo.tid);
+		EXPECT_EQ(getpid(), scap_tinfo.pid);
+		EXPECT_EQ(getpid(), scap_tinfo.vtid);
+		EXPECT_EQ(getppid(), scap_tinfo.ptid);
+
+		ASSERT_EQ(SCAP_SUCCESS,
+		          scap_proc_read_thread(platform, proc, 1, &scap_tinfo, err_buf, false));
+		EXPECT_EQ(1, scap_tinfo.tid);
+		EXPECT_EQ(1, scap_tinfo.pid);
+		EXPECT_EQ(1, scap_tinfo.vtid);
+		EXPECT_EQ(0, scap_tinfo.ptid);
 	};
+
 	ASSERT_NO_FATAL_FAILURE({
-		event_capture::run(test, callback, filter, event_capture::do_nothing, before_close);
+		event_capture::run(test, callback, filter, event_capture::do_nothing, after_capture);
 	});
-
-	ASSERT_EQ(SCAP_SUCCESS,
-	          scap_proc_read_thread(platform, proc, getpid(), &scap_tinfo, err_buf, false));
-	EXPECT_EQ(getpid(), scap_tinfo.tid);
-	EXPECT_EQ(getpid(), scap_tinfo.pid);
-	EXPECT_EQ(getpid(), scap_tinfo.vtid);
-	EXPECT_EQ(getppid(), scap_tinfo.ptid);
-
-	ASSERT_EQ(SCAP_SUCCESS, scap_proc_read_thread(platform, proc, 1, &scap_tinfo, err_buf, false));
-	EXPECT_EQ(1, scap_tinfo.tid);
-	EXPECT_EQ(1, scap_tinfo.pid);
-	EXPECT_EQ(1, scap_tinfo.vtid);
-	EXPECT_EQ(0, scap_tinfo.ptid);
 }
 
 TEST_F(sys_call_test, fd_name_max_path) {
 	int callnum = 0;
 	std::string pathname("/");
-	// Using only 1022 chars otherwise the path will be "/PATH_TOO_LONG".
+	// Using only 1022 chars otherwise the path will be "/DIR_TOO_LONG/FILENAME_TOO_LONG".
 	pathname.insert(1, 1021, 'A');
 
 	event_filter_t filter = [&](sinsp_evt* evt) {
@@ -2189,9 +2202,7 @@ TEST_F(sys_call_test, fd_name_max_path) {
 		       m_tid_filter(evt);
 	};
 
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector_handle) {
-		open(pathname.c_str(), O_RDONLY);
-	};
+	run_callback_t test = [&](sinsp* inspector) { open(pathname.c_str(), O_RDONLY); };
 
 	sinsp_filter_check_list m_filterlist;
 
