@@ -194,11 +194,9 @@ public:
 	}
 
 	void wait_for_server_ready() {
-		{
-			std::unique_lock<std::mutex> lock(m_mutex);
-			m_condition_server_ready.wait(lock, [this]() { return m_server_ready; });
-			m_server_ready = false;
-		}
+		std::unique_lock<std::mutex> lock(m_mutex);
+		m_condition_server_ready.wait(lock, [this]() { return m_server_ready; });
+		m_server_ready = false;
 	}
 
 	int64_t get_tid() { return m_tid; }
@@ -469,7 +467,7 @@ TEST_F(sys_call_test, udp_client_server) {
 	//
 	// INITIALIZATION
 	//
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector_handle) { udps.start(); };
+	run_callback_t test = [&](sinsp* inspector) { udps.start(); };
 
 	//
 	// OUTPUT VALDATION
@@ -598,7 +596,7 @@ TEST_F(sys_call_test, udp_client_server_with_connect_by_client) {
 	//
 	// INITIALIZATION
 	//
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector_handle) { udps.start(); };
+	run_callback_t test = [&](sinsp* inspector) { udps.start(); };
 
 	//
 	// OUTPUT VALDATION
@@ -635,7 +633,7 @@ TEST_F(sys_call_test, udp_client_server_sendmsg) {
 	//
 	// INITIALIZATION
 	//
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector_handle) { udps.start(); };
+	run_callback_t test = [&](sinsp* inspector) { udps.start(); };
 
 	//
 	// OUTPUT VALDATION
@@ -691,7 +689,7 @@ TEST_F(sys_call_test, udp_client_server_sendmsg_2buf) {
 	//
 	// INITIALIZATION
 	//
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector_handle) { udps.start(); };
+	run_callback_t test = [&](sinsp* inspector) { udps.start(); };
 
 	//
 	// OUTPUT VALDATION
@@ -747,7 +745,7 @@ static void run_fd_name_changed_test(bool use_sendmsg,
 	uint32_t num_name_changed_evts = 0;
 
 	// INIT FILTER
-	before_open_t before_open = [&](sinsp* inspector) {
+	before_capture_t before_open = [&](sinsp* inspector) {
 		sinsp_filter_compiler compiler(inspector, "fd.name_changed=true");
 		fd_name_changed = std::move(compiler.compile());
 	};
@@ -760,7 +758,7 @@ static void run_fd_name_changed_test(bool use_sendmsg,
 	//
 	// INITIALIZATION
 	//
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector_handle) { udps.start(); };
+	run_callback_t test = [&](sinsp* inspector) { udps.start(); };
 
 	//
 	// OUTPUT VALDATION
@@ -772,7 +770,9 @@ static void run_fd_name_changed_test(bool use_sendmsg,
 		}
 	};
 
-	ASSERT_NO_FATAL_FAILURE({ event_capture::run(test, callback, filter, before_open); });
+	ASSERT_NO_FATAL_FAILURE({
+		event_capture::run(test, callback, filter, event_capture::do_nothing, before_open);
+	});
 
 	ASSERT_EQ(num_name_changed_evts, expected_name_changed_evts);
 }
@@ -824,7 +824,7 @@ TEST_F(sys_call_test, udp_client_server_multiple_connect_name_changed) {
 	uint32_t num_name_changed_evts = 0;
 
 	// INIT FILTER
-	before_open_t before_open = [&](sinsp* inspector) {
+	before_capture_t before_open = [&](sinsp* inspector) {
 		sinsp_filter_compiler compiler(inspector, "fd.name_changed=true");
 		fd_name_changed = std::move(compiler.compile());
 	};
@@ -837,7 +837,7 @@ TEST_F(sys_call_test, udp_client_server_multiple_connect_name_changed) {
 	//
 	// INITIALIZATION
 	//
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector_handle) {
+	run_callback_t test = [&](sinsp* inspector) {
 		int sd;
 
 		sd = socket(AF_INET, SOCK_DGRAM, 0);
@@ -872,7 +872,9 @@ TEST_F(sys_call_test, udp_client_server_multiple_connect_name_changed) {
 		}
 	};
 
-	ASSERT_NO_FATAL_FAILURE({ event_capture::run(test, callback, filter, before_open); });
+	ASSERT_NO_FATAL_FAILURE({
+		event_capture::run(test, callback, filter, event_capture::do_nothing, before_open);
+	});
 
 	// Every connect should result in a name changed event other than the duplicate port.
 	ASSERT_EQ(num_name_changed_evts, 4u);
@@ -891,7 +893,7 @@ TEST_F(sys_call_test, statsd_client_snaplen) {
 	        "ipsum:"
 	        "18|c";
 
-	before_open_t setup = [&](sinsp* inspector) { inspector->dynamic_snaplen(true); };
+	before_capture_t setup = [&](sinsp* inspector) { inspector->dynamic_snaplen(true); };
 
 	//
 	// FILTER
@@ -904,7 +906,7 @@ TEST_F(sys_call_test, statsd_client_snaplen) {
 	//
 	// INITIALIZATION
 	//
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector_handle) {
+	run_callback_t test = [&](sinsp* inspector) {
 		// sendto with addr
 		udp_client client(0x0100007F, false, 8125);
 		client.m_payload = payload;
@@ -938,9 +940,8 @@ TEST_F(sys_call_test, statsd_client_snaplen) {
 		n++;
 	};
 
-	before_close_t cleanup = [&](sinsp* inspector) { inspector->dynamic_snaplen(false); };
-
-	ASSERT_NO_FATAL_FAILURE({ event_capture::run(test, callback, filter, setup, cleanup); });
+	ASSERT_NO_FATAL_FAILURE(
+	        { event_capture::run(test, callback, filter, event_capture::do_nothing, setup); });
 	EXPECT_EQ(4, n);
 }
 
@@ -962,7 +963,7 @@ TEST_F(sys_call_test, statsd_client_no_snaplen) {
 	//
 	// INITIALIZATION
 	//
-	run_callback_t test = [&](concurrent_object_handle<sinsp> inspector_handle) {
+	run_callback_t test = [&](sinsp* inspector) {
 		// sendto with addr
 		// Different port
 		udp_client client(0x0100007F, false, 8126);
