@@ -341,29 +341,18 @@ static const char* event_prog_names[PPM_EVENT_MAX] = {
         [PPME_SYSCALL_SETREGID_X] = "setregid_x",
 };
 
-/* Some events can require more than one bpf program to collect all the data. */
-static const char* extra_event_prog_names[TAIL_EXTRA_EVENT_PROG_MAX] = {
+/* Some exit events can require more than one bpf program to collect all the data. */
+static const char* sys_exit_extra_event_names[SYS_EXIT_EXTRA_CODE_MAX] = {
         [T1_EXECVE_X] = "t1_execve_x",
         [T1_EXECVEAT_X] = "t1_execveat_x",
         [T1_CLONE_X] = "t1_clone_x",
         [T1_CLONE3_X] = "t1_clone3_x",
         [T1_FORK_X] = "t1_fork_x",
         [T1_VFORK_X] = "t1_vfork_x",
-#ifdef CAPTURE_SCHED_PROC_EXEC
-        [T1_SCHED_PROC_EXEC] = "t1_sched_p_exec",
-        [T2_SCHED_PROC_EXEC] = "t2_sched_p_exec",
-#endif
-#ifdef CAPTURE_SCHED_PROC_FORK
-        [T1_SCHED_PROC_FORK] = "t1_sched_p_fork",
-        [T2_SCHED_PROC_FORK] = "t2_sched_p_fork",
-#endif
         [T2_CLONE_X] = "t2_clone_x",
         [T2_CLONE3_X] = "t2_clone3_x",
         [T2_FORK_X] = "t2_fork_x",
         [T2_VFORK_X] = "t2_vfork_x",
-        [T1_DROP_E] = "t1_drop_e",
-        [T1_DROP_X] = "t1_drop_x",
-        [T1_HOTPLUG_E] = "t1_hotplug_e",
         [T1_OPEN_BY_HANDLE_AT_X] = "t1_open_by_handle_at_x",
         [T2_EXECVE_X] = "t2_execve_x",
         [T2_EXECVEAT_X] = "t2_execveat_x",
