@@ -67,6 +67,18 @@ void pman_close_probe() {
 		g_state.stats = NULL;
 	}
 
+	if(g_state.inner_ringbuf_map_fd != -1) {
+		close(g_state.inner_ringbuf_map_fd);
+		g_state.inner_ringbuf_map_fd = -1;
+	}
+
+	for(int i = 0; i < MODERN_BPF_PROG_ATTACHED_MAX; i++) {
+		if(g_state.attached_progs_fds[i] != -1) {
+			close(g_state.attached_progs_fds[i]);
+			g_state.attached_progs_fds[i] = -1;
+		}
+	}
+
 	if(g_state.cons_pos) {
 		free(g_state.cons_pos);
 		g_state.cons_pos = NULL;
