@@ -120,15 +120,6 @@ void pman_fill_syscall_sampling_table() {
 	}
 }
 
-void pman_fill_syscall_tracepoint_table() {
-	/* Right now these are the only 2 tracepoints involved in the dropping logic. We need to add
-	 * them here */
-	g_state.skel->bss->g_64bit_sampling_tracepoint_table[PPME_PROCEXIT_1_E] = UF_NEVER_DROP;
-	g_state.skel->bss->g_64bit_sampling_tracepoint_table[PPME_SCHEDSWITCH_6_E] = 0;
-	g_state.skel->bss->g_64bit_sampling_tracepoint_table[PPME_PAGE_FAULT_E] = UF_ALWAYS_DROP;
-	g_state.skel->bss->g_64bit_sampling_tracepoint_table[PPME_SIGNALDELIVER_E] = UF_ALWAYS_DROP;
-}
-
 void pman_fill_ia32_to_64_table() {
 	for(int syscall_id = 0; syscall_id < SYSCALL_TABLE_SIZE; syscall_id++) {
 		// Note: we will map all syscalls from the upper limit of the ia32 table
@@ -258,25 +249,25 @@ clean_fill_syscalls_tail_table:
 	return errno;
 }
 
-int pman_fill_extra_event_prog_tail_table() {
-	int extra_event_prog_tail_table_fd = 0;
-	const char* tail_prog_name;
-
-	extra_event_prog_tail_table_fd = bpf_map__fd(g_state.skel->maps.extra_event_prog_tail_table);
-	if(extra_event_prog_tail_table_fd <= 0) {
-		pman_print_error("unable to get the extra event programs tail table");
+int pman_fill_syscall_exit_extra_tail_table() {
+	int extra_sys_exit_tail_table_fd =
+	        bpf_map__fd(g_state.skel->maps.syscall_exit_extra_tail_table);
+	if(extra_sys_exit_tail_table_fd <= 0) {
+		pman_print_error("unable to get the extra sys exit tail table");
 		return errno;
 	}
 
-	for(int j = 0; j < TAIL_EXTRA_EVENT_PROG_MAX; j++) {
-		tail_prog_name = extra_event_prog_names[j];
+	const char* tail_prog_name = NULL;
+	for(int j = 0; j < SYS_EXIT_EXTRA_CODE_MAX; j++) {
+		tail_prog_name = sys_exit_extra_event_names[j];
 
 		if(!tail_prog_name) {
-			continue;
+			pman_print_error("unknown entry in the extra sys exit tail table");
+			return -1;
 		}
 
-		if(add_bpf_program_to_tail_table(extra_event_prog_tail_table_fd, tail_prog_name, j)) {
-			close(extra_event_prog_tail_table_fd);
+		if(add_bpf_program_to_tail_table(extra_sys_exit_tail_table_fd, tail_prog_name, j)) {
+			close(extra_sys_exit_tail_table_fd);
 			return errno;
 		}
 	}
@@ -339,9 +330,8 @@ int pman_finalize_maps_after_loading() {
 
 	/* We have to fill all ours tail tables. */
 	pman_fill_syscall_sampling_table();
-	pman_fill_syscall_tracepoint_table();
 	pman_fill_ia32_to_64_table();
 	err = pman_fill_syscalls_tail_table();
-	err = err ?: pman_fill_extra_event_prog_tail_table();
+	err = err ?: pman_fill_syscall_exit_extra_tail_table();
 	return err;
 }
