@@ -19,15 +19,15 @@ limitations under the License.
 #define BPF_ENGINE "bpf"
 
 #ifdef __cplusplus
-extern "C"
-{
+extern "C" {
 #endif
 
-	struct scap_bpf_engine_params
-	{
-		unsigned long buffer_bytes_dim; ///< Dimension of a single per-CPU buffer in bytes. Please note: this buffer will be mapped twice in the process virtual memory, so pay attention to its size.
-		const char* bpf_probe;	    ///<  The path to the BPF probe object file.
-	};
+struct scap_bpf_engine_params {
+	unsigned long buffer_bytes_dim;  ///< Dimension of a single per-CPU buffer in bytes. Please
+	                                 ///< note: this buffer will be mapped twice in the process
+	                                 ///< virtual memory, so pay attention to its size.
+	const char* bpf_probe;           ///<  The path to the BPF probe object file.
+};
 
 #ifdef __cplusplus
 };
