@@ -194,7 +194,9 @@ int32_t fill_event_read_e(scap_sized_buffer scap_buf,
 int32_t fill_event_read_x(scap_sized_buffer scap_buf,
                           size_t* event_size,
                           char* scap_err,
-                          int64_t res);
+                          int64_t res,
+                          int64_t fd,
+                          uint32_t size);
 
 int32_t fill_event_pread_e(scap_sized_buffer scap_buf,
                            size_t* event_size,
@@ -206,7 +208,10 @@ int32_t fill_event_pread_e(scap_sized_buffer scap_buf,
 int32_t fill_event_pread_x(scap_sized_buffer scap_buf,
                            size_t* event_size,
                            char* scap_err,
-                           int64_t res);
+                           int64_t res,
+                           int64_t fd,
+                           uint32_t size,
+                           uint64_t pos);
 
 int32_t fill_event_readv_e(scap_sized_buffer scap_buf,
                            size_t* event_size,
@@ -254,7 +259,10 @@ int32_t fill_event_socket_e(scap_sized_buffer scap_buf,
 int32_t fill_event_socket_x(scap_sized_buffer scap_buf,
                             size_t* event_size,
                             char* scap_err,
-                            int64_t fd);
+                            int64_t fd,
+                            uint32_t domain,
+                            uint32_t type,
+                            uint32_t protocol);
 
 int32_t fill_event_chdir_e(scap_sized_buffer scap_buf, size_t* event_size, char* scap_err);
 
@@ -436,7 +444,8 @@ int32_t fill_event_bind_x(scap_sized_buffer scap_buf,
                           size_t* event_size,
                           char* scap_err,
                           int64_t res,
-                          scap_const_sized_buffer addr);
+                          scap_const_sized_buffer addr,
+                          int64_t fd);
 
 int32_t fill_event_accept_5_e(scap_sized_buffer scap_buf, size_t* event_size, char* scap_err);
 
