@@ -21,7 +21,6 @@ limitations under the License.
 #include <signal.h>
 #include <libscap/scap.h>
 #include <libscap/scap-int.h>
-#include <arpa/inet.h>
 #include <sys/time.h>
 #include <libscap/strl.h>
 #include <libscap/scap_engines.h>
@@ -159,10 +158,6 @@ static const struct scap_vtable* vtable = NULL;
 static uint64_t g_nevts = 0;                 /* total number of events captured. */
 static uint64_t g_total_number_of_bytes = 0; /* total dimension of events in bytes. */
 static scap_t* g_h = NULL;                   /* global scap handler. */
-static uint16_t* lens16 = NULL;              /* pointer used to print the length of event params. */
-static char* valptr = NULL;
-/* pointer used to print the value of event params. */ /* pointer used to print the value of
-                                                          event params. */
 static struct timeval tval_start, tval_end, tval_result;
 static unsigned long number_of_timeouts;  /* Times in which there were no events in the buffer. */
 static unsigned long number_of_scap_next; /* Times in which the 'scap-next' method is called. */
@@ -266,235 +261,6 @@ void enable_simple_set() {
 
 /*=============================== SYSCALLS/TRACEPOINTS ===========================*/
 
-/*=============================== PRINT EVENT PARAMS ===========================*/
-
-void print_ipv4(int starting_index) {
-	char ipv4_string[50];
-	uint8_t* ipv4 = (uint8_t*)(valptr + starting_index);
-	snprintf(ipv4_string, sizeof(ipv4_string), "%d.%d.%d.%d", ipv4[0], ipv4[1], ipv4[2], ipv4[3]);
-	printf("- ipv4: %s\n", ipv4_string);
-}
-
-void print_ipv6(int starting_index) {
-	uint32_t ipv6[4] = {0, 0, 0, 0};
-	ipv6[0] = *(uint32_t*)(valptr + starting_index);
-	ipv6[1] = *(uint32_t*)(valptr + starting_index + 4);
-	ipv6[2] = *(uint32_t*)(valptr + starting_index + 8);
-	ipv6[3] = *(uint32_t*)(valptr + starting_index + 12);
-
-	char ipv6_string[150];
-	inet_ntop(AF_INET6, ipv6, ipv6_string, 150);
-	printf("- ipv6: %s\n", ipv6_string);
-}
-
-void print_unix_path(int starting_index) {
-	printf("- unix path: %s\n", (char*)(valptr + starting_index));
-}
-
-void print_port(int starting_index) {
-	printf("- port: %d\n", *(uint16_t*)(valptr + starting_index));
-}
-
-void print_parameter(int16_t num_param) {
-	int16_t param_type = g_event_info[evt_type].params[num_param].type;
-	int16_t len = lens16[num_param];
-
-	if(len == 0) {
-		printf("PARAM %d: is empty\n", num_param);
-		return;
-	}
-
-	switch(param_type) {
-	case PT_FLAGS8:
-		printf("PARAM %d: %X\n", num_param, *(uint8_t*)(valptr));
-		break;
-
-	case PT_FLAGS16:
-		printf("PARAM %d: %X\n", num_param, *(uint16_t*)(valptr));
-		break;
-
-	case PT_FLAGS32:
-		printf("PARAM %d: %X\n", num_param, *(uint32_t*)(valptr));
-		break;
-
-	case PT_INT8:
-		printf("PARAM %d: %d\n", num_param, *(int8_t*)(valptr));
-		break;
-
-	case PT_INT16:
-		printf("PARAM %d: %d\n", num_param, *(int16_t*)(valptr));
-		break;
-
-	case PT_INT32:
-		printf("PARAM %d: %d\n", num_param, *(int32_t*)(valptr));
-		break;
-
-	case PT_INT64:
-	case PT_ERRNO:
-	case PT_PID:
-		printf("PARAM %d: %ld\n", num_param, *(int64_t*)(valptr));
-		break;
-
-	case PT_UINT8:
-	case PT_SIGTYPE:
-	case PT_ENUMFLAGS8:
-		printf("PARAM %d: %d\n", num_param, *(uint8_t*)(valptr));
-		break;
-
-	case PT_UINT16:
-	case PT_SYSCALLID:
-	case PT_ENUMFLAGS16:
-		printf("PARAM %d: %d\n", num_param, *(uint16_t*)(valptr));
-		break;
-
-	case PT_UINT32:
-	case PT_UID:
-	case PT_GID:
-	case PT_SIGSET:
-	case PT_MODE:
-	case PT_ENUMFLAGS32:
-		printf("PARAM %d: %d\n", num_param, *(uint32_t*)(valptr));
-		break;
-
-	case PT_UINT64:
-	case PT_RELTIME:
-	case PT_ABSTIME:
-		printf("PARAM %d: %lu\n", num_param, *(uint64_t*)(valptr));
-		break;
-
-	case PT_FD:
-		printf("PARAM %d: %d\n", num_param, *(int32_t*)(valptr));
-		break;
-
-	case PT_SOCKADDR: {
-		printf("PARAM %d:\n", num_param);
-		uint8_t sock_family = *(uint8_t*)(valptr);
-		printf("- sock_family: %d\n", sock_family);
-		switch(sock_family) {
-		case PPM_AF_INET:
-			/* ipv4 dest. */
-			print_ipv4(1);
-
-			/* port dest. */
-			print_port(5);
-			break;
-
-		case PPM_AF_INET6:
-			/* ipv6 dest. */
-			print_ipv6(1);
-
-			/* port dest. */
-			print_port(17);
-			break;
-
-		case PPM_AF_UNIX:
-			/* unix_path. */
-			print_unix_path(1);
-			break;
-
-		default:
-			printf("-  error\n");
-			break;
-		}
-		break;
-	}
-
-	case PT_SOCKTUPLE: {
-		printf("PARAM %d:\n", num_param);
-		uint8_t sock_family = *(uint8_t*)(valptr);
-		printf("- sock_family: %d\n", sock_family);
-		switch(sock_family) {
-		case PPM_AF_INET:
-			/* ipv4 src. */
-			print_ipv4(1);
-
-			/* ipv4 dest. */
-			print_ipv4(5);
-
-			/* port src. */
-			print_port(9);
-
-			/* port dest. */
-			print_port(11);
-			break;
-
-		case PPM_AF_INET6:
-			/* ipv6 src. */
-			print_ipv6(1);
-
-			/* ipv6 dest. */
-			print_ipv6(17);
-
-			/* port src. */
-			print_port(33);
-
-			/* port dest. */
-			print_port(35);
-			break;
-
-		case PPM_AF_UNIX:
-			/* Here there are also some kernel pointers but right
-			 * now we are not interested in catching them.
-			 * 8 + 8 = 16 bytes
-			 */
-
-			/* unix_path. */
-			print_unix_path(17);
-			break;
-
-		default:
-			printf("-  error\n");
-			break;
-		}
-		break;
-	}
-
-	case PT_CHARBUF:
-	case PT_BYTEBUF:
-	case PT_FSPATH:
-	case PT_CHARBUFARRAY:
-	case PT_FSRELPATH:
-		printf("PARAM %d: ", num_param);
-		for(int j = 0; j < len; j++) {
-			printf("%c", *(char*)(valptr + j));
-		}
-		printf("\n");
-		break;
-
-	default:
-		printf("PARAM %d: TYPE NOT KNOWN\n", num_param);
-		break;
-	}
-	valptr += len;
-}
-
-void print_event(scap_evt* ev) {
-	lens16 = (uint16_t*)((char*)ev + sizeof(struct ppm_evt_hdr));
-	valptr = (char*)lens16 + ev->nparams * sizeof(uint16_t);
-	printf("\n------------------ EVENT: %d TID:%lu\n", evt_type, ev->tid);
-
-	printf("------ HEADER\n");
-	printf("timestamp: %lu\n", ev->ts);
-	printf("tid: %lu\n", ev->tid);
-	printf("len: %d\n", ev->len);
-	printf("type: %d\n", ev->type);
-	printf("num params: %d\n", ev->nparams);
-	printf("------\n");
-	printf("------ PARAMS\n");
-
-	for(int i = 0; i < ev->nparams; i++) {
-		print_parameter(i);
-	}
-	if(ev->nparams == 0) {
-		printf("- This event has no parameter\n");
-	}
-
-	printf("------\n");
-	printf("------------------\n");
-}
-
-/*=============================== PRINT EVENT PARAMS ===========================*/
-
 /*=============================== PRINT CAPTURE INFO ===========================*/
 
 void print_help() {
@@ -988,7 +754,7 @@ int main(int argc, char** argv) {
 		}
 
 		if(ev->type == evt_type) {
-			print_event(ev);
+			scap_print_event(ev, PRINT_FULL);
 		}
 		count_syscalls(ev);
 		g_total_number_of_bytes += ev->len;
