@@ -295,6 +295,10 @@ static const ppm_sc_code *g_events_to_sc_map[] = {
                                            PPM_SC_LSM_LIST_MODULES,
                                            PPM_SC_MSEAL,
                                            PPM_SC_URETPROBE,
+                                           PPM_SC_REMOVEXATTRAT,
+                                           PPM_SC_LISTXATTRAT,
+                                           PPM_SC_GETXATTRAT,
+                                           PPM_SC_SETXATTRAT,
                                            -1},
         [PPME_GENERIC_X] = (ppm_sc_code[]){PPM_SC_RESTART_SYSCALL,
                                            PPM_SC_EXIT,
@@ -560,6 +564,10 @@ static const ppm_sc_code *g_events_to_sc_map[] = {
                                            PPM_SC_LSM_GET_SELF_ATTR,
                                            PPM_SC_MSEAL,
                                            PPM_SC_URETPROBE,
+                                           PPM_SC_LISTXATTRAT,
+                                           PPM_SC_GETXATTRAT,
+                                           PPM_SC_SETXATTRAT,
+                                           PPM_SC_REMOVEXATTRAT,
                                            -1},
         [PPME_SYSCALL_OPEN_E] = (ppm_sc_code[]){PPM_SC_OPEN, -1},
         [PPME_SYSCALL_OPEN_X] = (ppm_sc_code[]){PPM_SC_OPEN, -1},
