@@ -313,6 +313,7 @@ int32_t scap_event_encode_params_v(const struct scap_sized_buffer event_buf,
 			}
 			break;
 		default:
+			ASSERT(false);
 			snprintf(error,
 			         SCAP_LASTERR_SIZE,
 			         "unexpected param %d length %zu for event with type %d",
@@ -354,3 +355,190 @@ int32_t scap_event_encode_params_v(const struct scap_sized_buffer event_buf,
 
 	return SCAP_SUCCESS;
 }
+
+// This should be only used for testing purposes in production we should use directly `memcmp` for
+// the whole event
+bool scap_compare_events(scap_evt *curr, scap_evt *expected, char *error) {
+	//////////////////////////////
+	// Start comparing the header
+	//////////////////////////////
+	// `UINT64_MAX - 1` can be used to skip the comparison
+	if(expected->ts != (UINT64_MAX - 1) && curr->ts != expected->ts) {
+		snprintf(error,
+		         SCAP_LASTERR_SIZE,
+		         "Event timestamp mismatch. Current (%ld) != expected (%ld)",
+		         curr->ts,
+		         expected->ts);
+		return false;
+	}
+	if(curr->tid != expected->tid) {
+		snprintf(error,
+		         SCAP_LASTERR_SIZE,
+		         "Event tid mismatch. Current (%ld) != expected (%ld)",
+		         curr->tid,
+		         expected->tid);
+		return false;
+	}
+	if(curr->type != expected->type) {
+		snprintf(error,
+		         SCAP_LASTERR_SIZE,
+		         "Event type mismatch. Current (%d) != expected (%d)",
+		         curr->type,
+		         expected->type);
+		return false;
+	}
+	if(curr->nparams != expected->nparams) {
+		snprintf(error,
+		         SCAP_LASTERR_SIZE,
+		         "Event nparams mismatch. Current (%d) != expected (%d)",
+		         curr->nparams,
+		         expected->nparams);
+		return false;
+	}
+	if(curr->len != expected->len) {
+		snprintf(error,
+		         SCAP_LASTERR_SIZE,
+		         "Event len mismatch. Current (%d) != expected (%d)",
+		         curr->len,
+		         expected->len);
+		return false;
+	}
+	//////////////////////////////
+	// Comparing the length of the parameters
+	//////////////////////////////
+	for(int i = 0; i < curr->nparams; i++) {
+		uint16_t curr_param_len = 0;
+		uint16_t expected_param_len = 0;
+		memcpy(&curr_param_len,
+		       (char *)curr + sizeof(struct ppm_evt_hdr) + sizeof(uint16_t) * i,
+		       sizeof(uint16_t));
+		memcpy(&expected_param_len,
+		       (char *)expected + sizeof(struct ppm_evt_hdr) + sizeof(uint16_t) * i,
+		       sizeof(uint16_t));
+		if(curr_param_len != expected_param_len) {
+			snprintf(error,
+			         SCAP_LASTERR_SIZE,
+			         "Param %d length mismatch. Current (%d) != expected (%d)",
+			         i,
+			         curr_param_len,
+			         expected_param_len);
+			return false;
+		}
+	}
+	//////////////////////////////
+	// Comparing each parameter
+	//////////////////////////////
+	char *curr_pos = (char *)curr + sizeof(struct ppm_evt_hdr) + sizeof(uint16_t) * curr->nparams;
+	char *expected_pos =
+	        (char *)expected + sizeof(struct ppm_evt_hdr) + sizeof(uint16_t) * curr->nparams;
+	for(int i = 0; i < curr->nparams; i++) {
+		uint16_t curr_param_len = 0;
+		memcpy(&curr_param_len,
+		       (char *)curr + sizeof(struct ppm_evt_hdr) + sizeof(uint16_t) * i,
+		       sizeof(uint16_t));
+		// todo!: we can improve this by printing the parameter for the specific type.
+		if(memcmp(curr_pos, expected_pos, curr_param_len) != 0) {
+			snprintf(error, SCAP_LASTERR_SIZE, "Param %d mismatch. Current != expected", i);
+			return false;
+		}
+		curr_pos += curr_param_len;
+		expected_pos += curr_param_len;
+	}
+	return true;
+}
+
+scap_evt *scap_create_event_v(char *error,
+                              uint64_t ts,
+                              uint64_t tid,
+                              ppm_event_code event_type,
+                              uint32_t n,
+                              va_list args) {
+	struct scap_sized_buffer event_buf = {NULL, 0};
+	size_t event_size = 0;
+	va_list args2;
+	va_copy(args2, args);
+	int32_t ret = scap_event_encode_params_v(event_buf, &event_size, error, event_type, n, args);
+	if(ret != SCAP_INPUT_TOO_SMALL) {
+		goto error;
+	}
+	event_buf.buf = malloc(event_size);
+	event_buf.size = event_size;
+	if(event_buf.buf == NULL) {
+		snprintf(error, SCAP_LASTERR_SIZE, "cannot alloc %ld bytes.", event_size);
+		goto error;
+	}
+	ret = scap_event_encode_params_v(event_buf, &event_size, error, event_type, n, args2);
+	if(ret != SCAP_SUCCESS) {
+		event_buf.size = 0;
+		free(event_buf.buf);
+		goto error;
+	}
+	scap_evt *event = (scap_evt *)(event_buf.buf);
+	event->ts = ts;
+	event->tid = tid;
+	va_end(args2);
+	return event;
+error:
+	va_end(args2);
+	return NULL;
+}
+
+// If this returns NULL, check the error message.
+scap_evt *scap_create_event(char *error,
+                            uint64_t ts,
+                            uint64_t tid,
+                            ppm_event_code event_type,
+                            uint32_t n,
+                            ...) {
+	va_list args;
+	va_start(args, n);
+	scap_evt *ret = scap_create_event_v(error, ts, tid, event_type, n, args);
+	va_end(args);
+	return ret;
+}
+
+// Only enter events have a convention on the fd parameter position.
+// Should be always the first parameter apart from some exceptions.
+int get_enter_event_fd_location(ppm_event_code etype) {
+	ASSERT(etype < PPM_EVENT_MAX);
+	ASSERT(PPME_IS_ENTER(etype));
+	ASSERT(scap_get_event_info_table()[etype].flags & EF_USES_FD);
+
+	// For almost all parameters the default position is `0`
+	int location = 0;
+	switch(etype) {
+	case PPME_SYSCALL_MMAP_E:
+	case PPME_SYSCALL_MMAP2_E:
+		location = 4;
+		break;
+	case PPME_SYSCALL_SPLICE_E:
+		location = 1;
+		break;
+	default:
+		break;
+	}
+	return location;
+}
+
+// In the exit events we don't have a precise convention on the fd parameter position.
+int get_exit_event_fd_location(ppm_event_code etype) {
+	ASSERT(etype < PPM_EVENT_MAX);
+	ASSERT(PPME_IS_EXIT(etype));
+	ASSERT(scap_get_event_info_table()[etype].flags & EF_USES_FD);
+
+	// we want to return -1 as location if we forgot to handle something
+	int location = -1;
+	switch(etype) {
+	case PPME_SOCKET_LISTEN_X:
+		location = 1;
+		break;
+	case PPME_SYSCALL_READ_X:
+	case PPME_SYSCALL_PREAD_X:
+	case PPME_SOCKET_BIND_X:
+		location = 2;
+		break;
+	default:
+		break;
+	}
+	return location;
+}
