@@ -18,17 +18,13 @@ limitations under the License.
 
 #pragma once
 
-#define uthash_fatal(msg) uth_status = SCAP_FAILURE 
+#define uthash_fatal(msg) uth_status = SCAP_FAILURE
 
 /* `uthash.h` is generated at build time, see `uthash.cmake` */
 #include "uthash.h"
 
 /* Further definitions on top of 'uthash.h' */
-#define HASH_FIND_INT32(head,findint,out)                                        \
-    HASH_FIND(hh,head,findint,sizeof(uint32_t),out)
-#define HASH_ADD_INT32(head,intfield,add)                                        \
-    HASH_ADD(hh,head,intfield,sizeof(uint32_t),add)
-#define HASH_FIND_INT64(head,findint,out)                                        \
-    HASH_FIND(hh,head,findint,sizeof(uint64_t),out)
-#define HASH_ADD_INT64(head,intfield,add)                                        \
-    HASH_ADD(hh,head,intfield,sizeof(uint64_t),add)
+#define HASH_FIND_INT32(head, findint, out) HASH_FIND(hh, head, findint, sizeof(uint32_t), out)
+#define HASH_ADD_INT32(head, intfield, add) HASH_ADD(hh, head, intfield, sizeof(uint32_t), add)
+#define HASH_FIND_INT64(head, findint, out) HASH_FIND(hh, head, findint, sizeof(uint64_t), out)
+#define HASH_ADD_INT64(head, intfield, add) HASH_ADD(hh, head, intfield, sizeof(uint64_t), add)
