@@ -69,10 +69,6 @@ public:
 		get().m_cri_runtime_type = v;
 	}
 
-	static const std::string &get_cri_unix_socket_path() { return get().m_cri_unix_socket_path; }
-
-	static void set_cri_unix_socket_path(const std::string &v) { get().m_cri_unix_socket_path = v; }
-
 	static const bool &get_cri_extra_queries() { return get().m_cri_extra_queries; }
 
 	static void set_cri_extra_queries(const bool &v) { get().m_cri_extra_queries = v; }
@@ -93,7 +89,6 @@ private:
 	int64_t m_cri_timeout;
 	int64_t m_cri_size_timeout;
 	sinsp_container_type m_cri_runtime_type;
-	std::string m_cri_unix_socket_path;
 	bool m_cri_extra_queries;
 };
 
@@ -366,6 +361,22 @@ public:
 	                                   const Json::Value &root,
 	                                   sinsp_container_info &container);
 
+	/**
+	 * @brief fill out pod sandbox network namespace mode info
+	 * @param status `status` field of the PodSandboxStatusResponse
+	 * @param container the container info to fill out
+	 */
+	void parse_cri_pod_sandbox_pid(const typename api::PodSandboxStatus &status,
+	                               sinsp_container_info &container);
+
+	/**
+	 * @brief fill out pod sandbox ipc namespace mode info
+	 * @param status `status` field of the PodSandboxStatusResponse
+	 * @param container the container info to fill out
+	 */
+	void parse_cri_pod_sandbox_ipc(const typename api::PodSandboxStatus &status,
+	                               sinsp_container_info &container);
+
 	/////////////////////////////
 	// Generic parsers helpers
 	/////////////////////////////
