@@ -24,7 +24,6 @@ limitations under the License.
 #include <algorithm>
 #include <unistd.h>
 #else
-#define NOMINMAX
 #define localtime_r(a, b) (localtime_s(b, a) == 0 ? b : NULL)
 #endif
 
@@ -36,6 +35,7 @@ limitations under the License.
 
 #include <libsinsp/sinsp.h>
 #include <libsinsp/sinsp_int.h>
+#include <libsinsp/user.h>
 #include <libscap/strl.h>
 
 #include <libscap/scap.h>
@@ -79,27 +79,13 @@ sinsp_evt::sinsp_evt():
         m_errorcode(0),
         m_rawbuf_str_len(0),
         m_filtered_out(false),
-        m_event_info_table(g_infotables.m_event_info) {}
+        m_event_info_table(g_infotables.m_event_info),
+        m_source_idx(sinsp_no_event_source_idx),
+        m_source_name(NULL) {}
 
-sinsp_evt::sinsp_evt(sinsp *inspector):
-        m_inspector(inspector),
-        m_pevt(NULL),
-        m_pevt_storage(NULL),
-        m_cpuid(0),
-        m_evtnum(0),
-        m_flags(EF_NONE),
-        m_params_loaded(false),
-        m_info(NULL),
-        m_paramstr_storage(1024),
-        m_resolved_paramstr_storage(1024),
-        m_tinfo(NULL),
-        m_fdinfo(NULL),
-        m_fdinfo_name_changed(false),
-        m_iosize(0),
-        m_errorcode(0),
-        m_rawbuf_str_len(0),
-        m_filtered_out(false),
-        m_event_info_table(g_infotables.m_event_info) {}
+sinsp_evt::sinsp_evt(sinsp *inspector): sinsp_evt() {
+	m_inspector = inspector;
+}
 
 sinsp_evt::~sinsp_evt() {
 	if(m_pevt_storage) {
@@ -1325,7 +1311,7 @@ const char *sinsp_evt::get_param_as_str(uint32_t id,
 			sinsp_threadinfo *tinfo = get_thread_info();
 			scap_userinfo *user_info = NULL;
 			if(tinfo) {
-				user_info = m_inspector->m_usergroup_manager.get_user(tinfo->m_container_id, val);
+				user_info = m_inspector->m_usergroup_manager->get_user(tinfo->m_container_id, val);
 			}
 			if(user_info != NULL) {
 				strcpy_sanitized(&m_resolved_paramstr_storage[0],
@@ -1354,7 +1340,8 @@ const char *sinsp_evt::get_param_as_str(uint32_t id,
 			sinsp_threadinfo *tinfo = get_thread_info();
 			scap_groupinfo *group_info = NULL;
 			if(tinfo) {
-				group_info = m_inspector->m_usergroup_manager.get_group(tinfo->m_container_id, val);
+				group_info =
+				        m_inspector->m_usergroup_manager->get_group(tinfo->m_container_id, val);
 			}
 			if(group_info != NULL) {
 				strcpy_sanitized(&m_resolved_paramstr_storage[0],
