@@ -680,6 +680,99 @@ public:
 
 	inline std::vector<sinsp_evt_param>& get_params() { return m_params; }
 
+	inline char extract_typechar() {
+		switch(PPME_MAKE_ENTER(get_type())) {
+		case PPME_SYSCALL_OPENAT_E:
+		case PPME_SYSCALL_OPENAT_2_E:
+		case PPME_SYSCALL_OPENAT2_E:
+		case PPME_SYSCALL_CREAT_E:
+			return CHAR_FD_FILE;
+		case PPME_SOCKET_SOCKET_E:
+		case PPME_SOCKET_ACCEPT_E:
+		case PPME_SOCKET_ACCEPT_5_E:
+		case PPME_SOCKET_ACCEPT4_E:
+		case PPME_SOCKET_ACCEPT4_5_E:
+		case PPME_SOCKET_ACCEPT4_6_E:
+			//
+			// Note, this is not accurate, because it always
+			// returns IPv4 even if this could be IPv6 or unix.
+			// For the moment, I assume it's better than nothing, and doing
+			// real event parsing here would be a pain.
+			//
+			return CHAR_FD_IPV4_SOCK;
+		case PPME_SYSCALL_PIPE_E:
+		case PPME_SYSCALL_PIPE2_E:
+			return CHAR_FD_FIFO;
+		case PPME_SYSCALL_EVENTFD_E:
+		case PPME_SYSCALL_EVENTFD2_E:
+			return CHAR_FD_EVENT;
+		case PPME_SYSCALL_SIGNALFD_E:
+		case PPME_SYSCALL_SIGNALFD4_E:
+			return CHAR_FD_SIGNAL;
+		case PPME_SYSCALL_TIMERFD_CREATE_E:
+			return CHAR_FD_TIMERFD;
+		case PPME_SYSCALL_INOTIFY_INIT_E:
+		case PPME_SYSCALL_INOTIFY_INIT1_E:
+			return CHAR_FD_INOTIFY;
+		default:
+			return 'o';
+		}
+	}
+
+	inline bool is_syscall_event() const { return get_info()->category & EC_SYSCALL; }
+
+	inline bool has_return_value() {
+		// This event does not have a return value
+		if(get_type() == PPME_GENERIC_X) {
+			return false;
+		}
+
+		// The event has a return value if:
+		// * it is a syscall event.
+		// * it is an exit event.
+		// * it has at least one parameter. Some exit events are not instrumented, see
+		// `PPME_SOCKET_GETSOCKNAME_X`
+		if(is_syscall_event() && PPME_IS_EXIT(get_type()) && get_num_params() > 0) {
+			return true;
+		}
+
+		return false;
+	}
+
+	inline int64_t get_syscall_return_value() {
+		if(!has_return_value()) {
+			throw sinsp_exception(
+			        "Called get_syscall_return_value() on an event that does not have a return "
+			        "value. "
+			        "Event type: " +
+			        std::to_string(get_type()));
+		}
+
+		// The return value is always the first parameter of the syscall event
+		// It could have different names depending on the event type `res`,`fd`, etc.
+		const sinsp_evt_param* p = get_param(0);
+		if(p == NULL) {
+			// We should always have the return value in the syscall
+			ASSERT(false);
+			return 0;
+		}
+
+		// the only return values should be on 32 or 64 bits
+		switch(p->m_len) {
+		case sizeof(int32_t):
+			return (int64_t)p->as<int32_t>();
+		case sizeof(int64_t):
+			return p->as<int64_t>();
+		default:
+			ASSERT(false);
+			return 0;
+		}
+	}
+
+	inline bool uses_fd() const { return get_info_flags() & EF_USES_FD; }
+
+	inline bool creates_fd() const { return get_info_flags() & EF_CREATES_FD; }
+
 private:
 	sinsp* m_inspector;
 	scap_evt* m_pevt;
