@@ -31,7 +31,7 @@ limitations under the License.
 #define RGX_IDENTIFIER "([a-zA-Z]+[a-zA-Z0-9_]*)"
 #define RGX_FIELDNAME "([a-zA-Z]+[a-zA-Z0-9_]*(\\.[a-zA-Z]+[a-zA-Z0-9_]*)+)"
 #define RGX_FIELDARGBARESTR "([^][\"'[:space:]]+)"
-#define RGX_HEXNUM "(0[xX][0-9a-zA-Z]+)"
+#define RGX_HEXNUM "(0[xX][0-9a-fA-F]+)"
 #define RGX_NUMBER "([+\\-]?[0-9]+[\\.]?[0-9]*([eE][+\\-][0-9]+)?)"
 #define RGX_BARESTR "([^()\"'[:space:]=,]+)"
 
@@ -66,7 +66,8 @@ static const std::vector<std::string> s_unary_ops = {"exists"};
 
 static const std::vector<std::string> s_binary_num_ops = {"<=", "<", ">=", ">"};
 
-// todo(jasondellaluce): we should accept any blank after these (even line breaks)
+// note: by convention, we put a space at the end of operators requiring
+// a blank character after them (i.e. whitespace, line break, ...)
 static const std::vector<std::string> s_binary_str_ops = {
         "==",
         "=",
@@ -90,12 +91,11 @@ static const std::vector<std::string> s_binary_list_ops = {
 
 static constexpr const char* s_field_transformer_val = "val(";
 
-static const std::vector<std::string> s_field_transformers = {
-        "tolower(",
-        "toupper(",
-        "b64(",
-        "basename(",
-};
+static const std::vector<std::string> s_field_transformers = {"tolower(",
+                                                              "toupper(",
+                                                              "b64(",
+                                                              "basename(",
+                                                              "len("};
 
 static inline void update_pos(const char c, ast::pos_info& pos) {
 	pos.col++;
@@ -593,19 +593,19 @@ inline bool parser::lex_bare_str() {
 }
 
 inline bool parser::lex_unary_op() {
-	return lex_helper_str_list(s_unary_ops);
+	return lex_helper_operator_list(s_unary_ops);
 }
 
 inline bool parser::lex_num_op() {
-	return lex_helper_str_list(s_binary_num_ops);
+	return lex_helper_operator_list(s_binary_num_ops);
 }
 
 inline bool parser::lex_str_op() {
-	return lex_helper_str_list(s_binary_str_ops);
+	return lex_helper_operator_list(s_binary_str_ops);
 }
 
 inline bool parser::lex_list_op() {
-	return lex_helper_str_list(s_binary_list_ops);
+	return lex_helper_operator_list(s_binary_list_ops);
 }
 
 inline bool parser::lex_field_transformer_val() {
@@ -644,6 +644,25 @@ bool parser::lex_helper_str_list(const std::vector<std::string>& list) {
 	return false;
 }
 
+bool parser::lex_helper_operator_list(const std::vector<std::string>& list) {
+	for(auto& op : list) {
+		// if there's no ending whitespace, just parse the operator as-is
+		if(op.back() != ' ') {
+			if(lex_helper_str(op)) {
+				return true;
+			}
+			continue;
+		}
+
+		// if there's an ending whitespace, we need to make sure there's
+		// a blank after the operator (as long as we have an operator lexer match)
+		if(lex_helper_str(trim_str(op))) {
+			return lex_blank();
+		}
+	}
+	return false;
+}
+
 inline const char* parser::cursor() {
 	return m_input.c_str() + m_pos.idx;
 }
