@@ -45,6 +45,7 @@ limitations under the License.
 #include <cstdlib>
 #include <cstring>
 #include <filesystem>
+#include <user.h>
 
 /**
  * This is the maximum size assigned to the concurrent asynchronous event
@@ -56,6 +57,79 @@ limitations under the License.
  */
 #define DEFAULT_ASYNC_EVENT_QUEUE_SIZE 1000
 
+// Small sinsp event filter wrapper logic
+// that uses RAII to eventually filter out events.
+struct sinsp_evt_filter {
+	bool do_filter_later;
+	sinsp_evt* evt;
+
+	explicit sinsp_evt_filter(sinsp_evt* e): do_filter_later(false), evt(e) {
+		//
+		// Filtering
+		//
+		const auto inspector = evt->get_inspector();
+		const bool is_live = inspector->is_live() || inspector->is_syscall_plugin();
+		const uint16_t etype = evt->get_type();
+
+		evt->set_filtered_out(false);
+
+		//
+		// When debug mode is not enabled, filter out events about itself
+		//
+		if(is_live && !inspector->is_debug_enabled()) {
+			if(evt->get_tid() == inspector->m_self_pid && etype != PPME_SCHEDSWITCH_1_E &&
+			   etype != PPME_SCHEDSWITCH_6_E && etype != PPME_DROP_E && etype != PPME_DROP_X &&
+			   etype != PPME_SCAPEVENT_E && etype != PPME_PROCINFO_E &&
+			   etype != PPME_CPU_HOTPLUG_E && inspector->m_self_pid) {
+				evt->set_filtered_out(true);
+				return;
+			}
+		}
+
+		if(inspector->m_filter) {
+			ppm_event_flags eflags = evt->get_info_flags();
+			if(eflags & EF_MODIFIES_STATE) {
+				do_filter_later = true;
+			} else {
+				if(!inspector->run_filters_on_evt(evt)) {
+					if(evt->get_tinfo() != NULL) {
+						if(!(eflags & EF_SKIPPARSERESET || etype == PPME_SCHEDSWITCH_6_E)) {
+							evt->get_tinfo()->set_lastevent_type(PPM_EVENT_MAX);
+						}
+					}
+					evt->set_filtered_out(true);
+				}
+			}
+		}
+	}
+
+	~sinsp_evt_filter() {
+		//
+		// With some state-changing events like clone, execve and open, we do the
+		// filtering after having updated the state
+		//
+		const auto inspector = evt->get_inspector();
+		if(do_filter_later) {
+			if(!inspector->run_filters_on_evt(evt)) {
+				evt->set_filtered_out(true);
+				return;
+			}
+			evt->set_filtered_out(false);
+		}
+
+		//
+		// Offline captures can produce events with the SCAP_DF_STATE_ONLY. They are
+		// supposed to go through the engine, but they must be filtered out before
+		// reaching the user.
+		//
+		if(inspector->is_capture()) {
+			if(evt->get_dump_flags() & SCAP_DF_STATE_ONLY) {
+				evt->set_filtered_out(true);
+			}
+		}
+	}
+};
+
 int32_t on_new_entry_from_proc(void* context,
                                char* error,
                                int64_t tid,
@@ -75,9 +149,7 @@ sinsp::sinsp(bool with_metrics):
         m_lastevent_ts(0),
         m_host_root(scap_get_host_root()),
         m_container_manager(this),
-        m_usergroup_manager(this),
         m_async_events_queue(DEFAULT_ASYNC_EVENT_QUEUE_SIZE),
-        m_suppressed_comms(),
         m_inited(false) {
 	++instance_count;
 #if !defined(MINIMAL_BUILD) && !defined(__EMSCRIPTEN__)
@@ -90,6 +162,7 @@ sinsp::sinsp(bool with_metrics):
 	m_is_dumping = false;
 	m_parser = std::make_unique<sinsp_parser>(this);
 	m_thread_manager = std::make_unique<sinsp_thread_manager>(this);
+	m_usergroup_manager = std::make_unique<sinsp_usergroup_manager>(this);
 	m_max_fdtable_size = MAX_FD_TABLE_SIZE;
 	m_containers_purging_scan_time_ns = DEFAULT_INACTIVE_CONTAINER_SCAN_TIME_S * ONE_SECOND_IN_NS;
 	m_usergroups_purging_scan_time_ns = DEFAULT_DELETED_USERS_GROUPS_SCAN_TIME_S * ONE_SECOND_IN_NS;
@@ -159,7 +232,7 @@ bool sinsp::is_initialstate_event(scap_evt* pevent) const {
 	return pevent->type == PPME_CONTAINER_E || pevent->type == PPME_CONTAINER_JSON_E ||
 	       pevent->type == PPME_CONTAINER_JSON_2_E || pevent->type == PPME_USER_ADDED_E ||
 	       pevent->type == PPME_USER_DELETED_E || pevent->type == PPME_GROUP_ADDED_E ||
-	       pevent->type == PPME_GROUP_DELETED_E;
+	       pevent->type == PPME_GROUP_DELETED_E || pevent->type == PPME_ASYNCEVENT_E;
 }
 
 void sinsp::consume_initialstate_events() {
@@ -181,7 +254,7 @@ void sinsp::consume_initialstate_events() {
 		if(res == SCAP_SUCCESS) {
 			// Setting these to non-null will make sinsp::next use them as a scap event
 			// to avoid a call to scap_next. In this way, we can avoid the state parsing phase
-			// once we reach a container-unrelated event.
+			// once we reach a non-initialstate event.
 			m_replay_scap_evt = pevent;
 			m_replay_scap_cpuid = pcpuid;
 			m_replay_scap_flags = flags;
@@ -228,9 +301,9 @@ void sinsp::init() {
 	m_fds_to_remove.clear();
 
 	//
-	// If we're reading from file, we try to pre-parse the container events before
+	// If we're reading from file, we try to pre-parse all initial state-building events before
 	// importing the thread table, so that thread table filtering will work with
-	// container filters
+	// full information.
 	//
 	if(is_capture()) {
 		consume_initialstate_events();
@@ -285,9 +358,8 @@ void sinsp::init() {
 	m_inited = true;
 }
 
-void sinsp::set_import_users(bool import_users, bool user_details) {
-	m_usergroup_manager.m_import_users = import_users;
-	m_usergroup_manager.m_user_details_enabled = user_details;
+void sinsp::set_import_users(bool import_users) {
+	m_usergroup_manager->m_import_users = import_users;
 }
 
 /*=============================== OPEN METHODS ===============================*/
@@ -304,11 +376,7 @@ void sinsp::open_common(scap_open_args* oargs,
 	/* We need to save the actual mode and the engine used by the inspector. */
 	m_mode = mode;
 
-	oargs->import_users = m_usergroup_manager.m_import_users;
-	// We need to subscribe to container manager notifiers before
-	// scap starts scanning proc.
-	m_usergroup_manager.subscribe_container_mgr();
-
+	oargs->import_users = m_usergroup_manager->m_import_users;
 	oargs->log_fn = &sinsp_scap_log_fn;
 	oargs->proc_scan_timeout_ms = m_proc_scan_timeout_ms;
 	oargs->proc_scan_log_interval_ms = m_proc_scan_log_interval_ms;
@@ -371,7 +439,10 @@ void sinsp::open_common(scap_open_args* oargs,
 	// notify registered plugins of capture open
 	for(auto& p : m_plugin_manager->plugins()) {
 		if(p->caps() & CAP_CAPTURE_LISTENING) {
-			p->capture_open();
+			if(!p->capture_open()) {
+				throw sinsp_exception("capture_open error for plugin '" + p->name() +
+				                      "' : " + p->get_last_error());
+			}
 		}
 	}
 }
@@ -646,8 +717,19 @@ std::string sinsp::generate_gvisor_config(const std::string& socket_path) {
 }
 
 int64_t sinsp::get_file_size(const std::string& fname, char* error) {
+	std::filesystem::path p(fname);
+	auto s = std::filesystem::status(p);
+
+	// scap files can be streamed and the source can be one
+	// of the following. In that case we return 0 as file size.
+	if(s.type() == std::filesystem::file_type::character ||
+	   s.type() == std::filesystem::file_type::fifo ||
+	   s.type() == std::filesystem::file_type::socket) {
+		return 0;
+	}
+
 	std::error_code ec;
-	auto sz = std::filesystem::file_size(fname, ec);
+	auto sz = std::filesystem::file_size(p, ec);
 	if(ec) {
 		strlcpy(error, ec.message().c_str(), SCAP_LASTERR_SIZE);
 		return -1;
@@ -741,7 +823,10 @@ void sinsp::close() {
 	if(m_mode != SINSP_MODE_NONE) {
 		for(auto& p : m_plugin_manager->plugins()) {
 			if(p->caps() & CAP_CAPTURE_LISTENING) {
-				p->capture_close();
+				if(!p->capture_close()) {
+					throw sinsp_exception("capture_close error for plugin '" + p->name() +
+					                      "' : " + p->get_last_error());
+				}
 			}
 		}
 	}
@@ -912,17 +997,17 @@ void sinsp::import_user_list() {
 
 	if(ul) {
 		for(j = 0; j < ul->nusers; j++) {
-			m_usergroup_manager.add_user("",
-			                             -1,
-			                             ul->users[j].uid,
-			                             ul->users[j].gid,
-			                             ul->users[j].name,
-			                             ul->users[j].homedir,
-			                             ul->users[j].shell);
+			m_usergroup_manager->add_user("",
+			                              -1,
+			                              ul->users[j].uid,
+			                              ul->users[j].gid,
+			                              ul->users[j].name,
+			                              ul->users[j].homedir,
+			                              ul->users[j].shell);
 		}
 
 		for(j = 0; j < ul->ngroups; j++) {
-			m_usergroup_manager.add_group("", -1, ul->groups[j].gid, ul->groups[j].name);
+			m_usergroup_manager->add_group("", -1, ul->groups[j].gid, ul->groups[j].name);
 		}
 	}
 }
@@ -1189,7 +1274,7 @@ int32_t sinsp::next(sinsp_evt** puevt) {
 	}
 
 	if(m_auto_usergroups_purging && !is_offline()) {
-		m_usergroup_manager.clear_host_users_groups();
+		m_usergroup_manager->clear_host_users_groups();
 	}
 
 	//
@@ -1211,19 +1296,51 @@ int32_t sinsp::next(sinsp_evt** puevt) {
 	}
 
 	//
-	// Run the state engine
+	// Cleanup the event-related state
 	//
-	m_parser->process_event(evt);
+	m_parser->reset(evt);
 
-	// run plugin-implemented parsers
-	// note: we run the parsers even if the event has been filtered out,
-	// because we have no guarantee that the plugin parsers will not use a given
-	// event for state updates. Sinsp understands this through the
-	// EF_MODIFIES_STATE flag, which however is only relevant in the context of
-	// the internal implementation of libsinsp.
-	for(auto& pp : m_plugin_parsers) {
-		// todo(jason): should we log parsing errors here?
-		pp.process_event(evt, m_event_sources);
+	// Since evt_filter object below uses RAII, create a new scope.
+	{
+		// Object that uses RAII to enable event filtered out flag
+		sinsp_evt_filter evt_filter(evt);
+		// Object that uses RAII to automatically update user/group associated with a threadinfo
+		// upon threadinfo's container_id changes.
+		// Since the threadinfo state might get changed from a plugin parser,
+		// evaluate this one after all parsers get run.
+		user_group_updater usr_grp_updater(evt);
+
+		if(!evt->is_filtered_out()) {
+			//
+			// Run the state engine
+			//
+			m_parser->process_event(evt);
+		}
+
+		// run plugin-implemented parsers
+		// note: we run the parsers even if the event has been filtered out,
+		// because we have no guarantee that the plugin parsers will not use a given
+		// event for state updates. Sinsp understands this through the
+		// EF_MODIFIES_STATE flag, which however is only relevant in the context of
+		// the internal implementation of libsinsp.
+		for(auto& pp : m_plugin_parsers) {
+			// todo(jason): should we log parsing errors here?
+			pp.process_event(evt, m_event_sources);
+		}
+
+		// Once we processed all events, make sure to call all
+		// requested post-process callbacks.
+		// At this point, any plugin could have modified state tables,
+		// thus we can guarantee that any post-process callback
+		// will see the full post-event-processed state.
+		// NOTE: we don't use a RAII object because
+		// we cannot guarantee that no exception will be thrown by the callbacks.
+		if(m_observer != nullptr) {
+			for(; !m_post_process_cbs.empty(); m_post_process_cbs.pop()) {
+				auto cb = m_post_process_cbs.front();
+				cb(m_observer, evt);
+			}
+		}
 	}
 
 	// Finally set output evt;
@@ -1531,7 +1648,7 @@ std::string sinsp::get_filter() const {
 	return m_filterstring;
 }
 
-bool sinsp::run_filters_on_evt(sinsp_evt* evt) {
+bool sinsp::run_filters_on_evt(sinsp_evt* evt) const {
 	//
 	// First run the global filter, if there is one.
 	//
@@ -1775,7 +1892,7 @@ bool sinsp_thread_manager::remove_inactive_threads() {
 
 		m_last_flush_time_ns = m_inspector->get_lastevent_ts();
 
-		libsinsp_logger()->format(sinsp_logger::SEV_INFO, "Flushing thread table");
+		libsinsp_logger()->format(sinsp_logger::SEV_DEBUG, "Flushing thread table");
 
 		/* Here we loop over the table in search of threads to delete. We remove:
 		 * 1. Invalid threads.
