@@ -24,7 +24,7 @@ limitations under the License.
 #include <libsinsp/filter_compare.h>
 #include <libsinsp/filter_field.h>
 #include <libsinsp/filter_cache.h>
-#include <libsinsp/sinsp_filter_transformer.h>
+#include <libsinsp/sinsp_filter_transformers.h>
 
 #include <json/json.h>
 
@@ -137,7 +137,7 @@ public:
 	//
 	// Extract the field from the event. If sanitize_strings is true, any
 	// string values are sanitized to remove nonprintable characters.
-	// By default, this fills the vector with only one value, retireved by calling the single-result
+	// By default, this fills the vector with only one value, retrieved by calling the single-result
 	// extract method.
 	// If a NULL value is returned by extract, the vector is emptied.
 	// Subclasses are meant to either override this, or the single-valued extract method.
@@ -238,7 +238,7 @@ private:
 	        const std::vector<extract_value_t>& values);
 	inline void check_rhs_field_type_consistency() const;
 
-	std::list<sinsp_filter_transformer> m_transformers;
+	std::list<std::unique_ptr<sinsp_filter_transformer>> m_transformers;
 	std::unique_ptr<sinsp_filter_check> m_rhs_filter_check = nullptr;
 	std::unique_ptr<filtercheck_field_info> m_transformed_field = nullptr;
 
