@@ -48,6 +48,9 @@ public:
 		TYPE_CONTAINER_DURATION,
 		TYPE_CONTAINER_IP_ADDR,
 		TYPE_CONTAINER_CNIRESULT,
+		TYPE_CONTAINER_HOST_PID,
+		TYPE_CONTAINER_HOST_NETWORK,
+		TYPE_CONTAINER_HOST_IPC,
 	};
 
 	sinsp_filter_check_container();
