@@ -549,6 +549,13 @@ int32_t sinsp_filter_check_event::parse_field_name(std::string_view val,
 
 		res = extract_arg("evt.rawarg", val, &m_arginfo);
 
+		// These fields will be overridden with correct ones from the current event
+		// while extracting from event.
+		// But we also need to set them at init time to something different than `PT_DYN`
+		// to allow `eval_filter` expressions to be properly compiled.
+		// Note: even if they'll be overridden,
+		// it is safe to guess that eg: `size` param will always be a numeric type.
+		// Of course if we had a `size` param that is string, it would be troublesome.
 		m_customfield.m_type = m_arginfo->type;
 		m_customfield.m_print_format = m_arginfo->fmt;
 	} else if(STR_MATCH("evt.around")) {
@@ -650,10 +657,15 @@ void sinsp_filter_check_event::validate_filter_value(const char* str, uint32_t l
 	}
 }
 
-uint8_t* extract_argraw(sinsp_evt* evt, uint32_t* len, const char* argname) {
-	const sinsp_evt_param* pi = evt->get_param_by_name(argname);
+uint8_t* sinsp_filter_check_event::extract_argraw(sinsp_evt* evt,
+                                                  uint32_t* len,
+                                                  const char* argname) {
+	auto pi = evt->get_param_by_name(argname);
 
 	if(pi != NULL) {
+		m_arginfo = pi->get_info();
+		m_customfield.m_type = m_arginfo->type;
+		m_customfield.m_print_format = m_arginfo->fmt;
 		*len = pi->m_len;
 		return (uint8_t*)pi->m_val;
 	} else {
@@ -693,7 +705,7 @@ uint8_t* sinsp_filter_check_event::extract_abspath(sinsp_evt* evt, uint32_t* len
 		//
 		// We can extract the file path only in case of a successful file opening (fd>0).
 		//
-		fd = evt->get_param(0)->as<int64_t>();
+		fd = evt->get_syscall_return_value();
 
 		if(fd > 0) {
 			//
@@ -787,7 +799,7 @@ inline uint8_t* sinsp_filter_check_event::extract_buflen(sinsp_evt* evt, uint32_
 		//
 		// Extract the return value
 		//
-		m_val.s64 = evt->get_param(0)->as<int64_t>();
+		m_val.s64 = evt->get_syscall_return_value();
 
 		if(m_val.s64 >= 0) {
 			RETURN_EXTRACT_VAR(m_val.s64);
@@ -821,31 +833,17 @@ Json::Value sinsp_filter_check_event::extract_as_js(sinsp_evt* evt, uint32_t* le
 }
 
 uint8_t* sinsp_filter_check_event::extract_error_count(sinsp_evt* evt, uint32_t* len) {
-	const sinsp_evt_param* pi = evt->get_param_by_name("res");
-
-	if(pi != NULL) {
-		int64_t res = pi->as<int64_t>();
-		if(res < 0) {
-			m_val.u32 = 1;
-			RETURN_EXTRACT_VAR(m_val.u32);
-		} else {
-			return NULL;
-		}
+	// todo!: we need to understand if we want to return `0` or `<NA>`.
+	// At the moment we return `<NA>`.
+	if(!evt->has_return_value()) {
+		return NULL;
 	}
 
-	if((evt->get_info_flags() & EF_CREATES_FD) && PPME_IS_EXIT(evt->get_type())) {
-		pi = evt->get_param_by_name("fd");
-
-		if(pi != NULL) {
-			int64_t res = pi->as<int64_t>();
-			if(res < 0) {
-				m_val.u32 = 1;
-				RETURN_EXTRACT_VAR(m_val.u32);
-			}
-		}
+	m_val.u32 = 0;
+	if(evt->get_syscall_return_value() < 0) {
+		m_val.u32 = 1;
 	}
-
-	return NULL;
+	RETURN_EXTRACT_VAR(m_val.u32);
 }
 
 uint8_t* sinsp_filter_check_event::extract_single(sinsp_evt* evt,
@@ -1192,7 +1190,7 @@ uint8_t* sinsp_filter_check_event::extract_single(sinsp_evt* evt,
 		m_val.u16 = evt->get_cpuid();
 		RETURN_EXTRACT_VAR(m_val.u16);
 	case TYPE_ARGRAW:
-		return extract_argraw(evt, len, m_arginfo->name);
+		return extract_argraw(evt, len, m_argname.c_str());
 		break;
 	case TYPE_ARGSTR: {
 		const char* resolved_argstr;
@@ -1200,18 +1198,17 @@ uint8_t* sinsp_filter_check_event::extract_single(sinsp_evt* evt,
 
 		ASSERT(m_inspector != NULL);
 
+		sinsp_evt::param_fmt format =
+		        m_is_compare ? sinsp_evt::param_fmt::PF_NORMAL : m_inspector->get_buffer_format();
+
 		if(m_argid != -1) {
 			if(m_argid >= (int32_t)evt->get_num_params()) {
 				return NULL;
 			}
 
-			argstr = evt->get_param_as_str(m_argid,
-			                               &resolved_argstr,
-			                               m_inspector->get_buffer_format());
+			argstr = evt->get_param_as_str(m_argid, &resolved_argstr, format);
 		} else {
-			argstr = evt->get_param_value_str(m_argname,
-			                                  &resolved_argstr,
-			                                  m_inspector->get_buffer_format());
+			argstr = evt->get_param_value_str(m_argname, &resolved_argstr, format);
 		}
 
 		if(resolved_argstr != NULL && resolved_argstr[0] != 0) {
@@ -1286,89 +1283,30 @@ uint8_t* sinsp_filter_check_event::extract_single(sinsp_evt* evt,
 			return extract_buflen(evt, len);
 		}
 		break;
-	case TYPE_RESRAW: {
-		const sinsp_evt_param* pi = evt->get_param_by_name("res");
-
-		if(pi != NULL) {
-			*len = pi->m_len;
-			return (uint8_t*)pi->m_val;
+	case TYPE_RESRAW:
+		if(!evt->has_return_value()) {
+			return NULL;
 		}
 
-		if((evt->get_info_flags() & EF_CREATES_FD) && PPME_IS_EXIT(evt->get_type())) {
-			pi = evt->get_param_by_name("fd");
-
-			if(pi != NULL) {
-				*len = pi->m_len;
-				return (uint8_t*)pi->m_val;
-			}
-		}
-
-		return NULL;
-	} break;
+		m_val.s64 = evt->get_syscall_return_value();
+		RETURN_EXTRACT_VAR(m_val.s64);
 	case TYPE_RESSTR: {
-		const char* resolved_argstr;
-		const char* argstr;
-
-		const sinsp_evt_param* pi = evt->get_param_by_name("res");
-
-		if(pi != NULL) {
-			int64_t res = pi->as<int64_t>();
-
-			if(res >= 0) {
-				RETURN_EXTRACT_CSTR("SUCCESS");
-			} else {
-				argstr = evt->get_param_value_str("res", &resolved_argstr);
-				ASSERT(resolved_argstr != NULL && resolved_argstr[0] != 0);
-
-				if(resolved_argstr != NULL && resolved_argstr[0] != 0) {
-					RETURN_EXTRACT_CSTR(resolved_argstr);
-				} else if(argstr != NULL) {
-					RETURN_EXTRACT_CSTR(argstr);
-				}
-			}
-		} else {
-			if((evt->get_info_flags() & EF_CREATES_FD) && PPME_IS_EXIT(evt->get_type())) {
-				pi = evt->get_param_by_name("fd");
-				if(pi) {
-					int64_t res = pi->as<int64_t>();
-
-					if(res >= 0) {
-						RETURN_EXTRACT_CSTR("SUCCESS");
-					} else {
-						argstr = evt->get_param_value_str("fd", &resolved_argstr);
-						ASSERT(resolved_argstr != NULL && resolved_argstr[0] != 0);
-
-						if(resolved_argstr != NULL && resolved_argstr[0] != 0) {
-							RETURN_EXTRACT_CSTR(resolved_argstr);
-						} else if(argstr != NULL) {
-							RETURN_EXTRACT_CSTR(argstr);
-						}
-					}
-				}
-			}
+		if(!evt->has_return_value()) {
+			return NULL;
 		}
 
-		return NULL;
-	} break;
-	case TYPE_FAILED: {
-		m_val.u32 = 0;
-		const sinsp_evt_param* pi = evt->get_param_by_name("res");
-
-		if(pi != NULL) {
-			if(pi->as<int64_t>() < 0) {
-				m_val.u32 = 1;
-			}
-		} else if((evt->get_info_flags() & EF_CREATES_FD) && PPME_IS_EXIT(evt->get_type())) {
-			pi = evt->get_param_by_name("fd");
-
-			if(pi != NULL) {
-				if(pi->as<int64_t>() < 0) {
-					m_val.u32 = 1;
-				}
-			}
+		int64_t res = evt->get_syscall_return_value();
+		if(res >= 0) {
+			RETURN_EXTRACT_CSTR("SUCCESS");
 		}
 
-		RETURN_EXTRACT_VAR(m_val.u32);
+		// todo!: we should check if a failed syscall can return something that is not an errno.
+		// When res is < 0 usually it is an errno. In that case we could directly call
+		// `sinsp_utils::errno_to_str`
+		//
+		// m_strstorage = sinsp_utils::errno_to_str((int32_t)res);
+		m_strstorage = evt->get_param_value_str(0, true);
+		RETURN_EXTRACT_STRING(m_strstorage);
 	} break;
 	case TYPE_ISIO: {
 		ppm_event_flags eflags = evt->get_info_flags();
@@ -1455,6 +1393,7 @@ uint8_t* sinsp_filter_check_event::extract_single(sinsp_evt* evt,
 	case TYPE_COUNT:
 		m_val.u32 = 1;
 		RETURN_EXTRACT_VAR(m_val.u32);
+	case TYPE_FAILED:
 	case TYPE_COUNT_ERROR:
 		return extract_error_count(evt, len);
 	case TYPE_COUNT_ERROR_FILE: {
@@ -1538,30 +1477,23 @@ uint8_t* sinsp_filter_check_event::extract_single(sinsp_evt* evt,
 		} else {
 			return NULL;
 		}
-	case TYPE_COUNT_PROCINFO: {
-		uint16_t etype = evt->get_type();
-
-		if(etype == PPME_PROCINFO_E) {
-			sinsp_threadinfo* tinfo = evt->get_thread_info();
-
-			if(tinfo != NULL && tinfo->is_main_thread()) {
-				m_val.u32 = 1;
-				RETURN_EXTRACT_VAR(m_val.u32);
-			}
-		}
-	}
-
-	break;
+	case TYPE_COUNT_PROCINFO:
 	case TYPE_COUNT_THREADINFO: {
-		uint16_t etype = evt->get_type();
-
-		if(etype == PPME_PROCINFO_E) {
-			m_val.u32 = 1;
+		m_val.u32 = 0;
+		if(evt->get_type() != PPME_PROCINFO_E) {
 			RETURN_EXTRACT_VAR(m_val.u32);
 		}
-	}
 
-	break;
+		if(m_field_id == TYPE_COUNT_THREADINFO) {
+			m_val.u32 = 1;
+		} else if(m_field_id == TYPE_COUNT_PROCINFO) {
+			sinsp_threadinfo* tinfo = evt->get_thread_info();
+			if(tinfo != NULL && tinfo->is_main_thread()) {
+				m_val.u32 = 1;
+			}
+		}
+		RETURN_EXTRACT_VAR(m_val.u32);
+	}
 	case TYPE_ABSPATH:
 		return extract_abspath(evt, len);
 	case TYPE_BUFLEN_IN:
@@ -1670,8 +1602,8 @@ uint8_t* sinsp_filter_check_event::extract_single(sinsp_evt* evt,
 				}
 
 				// If PPM_O_TMPFILE is set and syscall is successful the file is created
-				if(flags & PPM_O_TMPFILE) {
-					int64_t retval = evt->get_param(0)->as<int64_t>();
+				if((flags & PPM_O_TMPFILE) && evt->has_return_value()) {
+					int64_t retval = evt->get_syscall_return_value();
 
 					if(retval >= 0) {
 						m_val.u32 = 1;
