@@ -20,11 +20,9 @@ limitations under the License.
 
 #include <libsinsp/sinsp_filtercheck.h>
 
-class sinsp_filter_check_fdlist : public sinsp_filter_check
-{
+class sinsp_filter_check_fdlist : public sinsp_filter_check {
 public:
-	enum check_type
-	{
+	enum check_type {
 		TYPE_FDNUMS = 0,
 		TYPE_FDNAMES = 1,
 		TYPE_CLIENTIPS = 2,
@@ -39,9 +37,8 @@ public:
 	std::unique_ptr<sinsp_filter_check> allocate_new() override;
 
 protected:
-	uint8_t* extract(sinsp_evt*, OUT uint32_t* len, bool sanitize_strings = true) override;
+	uint8_t* extract_single(sinsp_evt*, uint32_t* len, bool sanitize_strings = true) override;
 
 private:
 	std::string m_strval;
-	char m_addrbuff[100];
 };
