@@ -111,7 +111,7 @@ static const filtercheck_field_info sinsp_filter_check_thread_fields[] = {
          "Name",
          "The process name (truncated after 16 characters) generating the event (task->comm). "
          "Truncation is determined by kernel settings and not by Falco. This field is collected "
-         "from the syscalls args or, as a fallback, extracted from /proc/PID/status. The name of "
+         "from the syscalls args or, as a fallback, extracted from /proc/PID/comm. The name of "
          "the process and the name of the executable file on disk (if applicable) can be different "
          "if a process is given a custom name which is often the case for example for java "
          "applications."},
@@ -120,7 +120,7 @@ static const filtercheck_field_info sinsp_filter_check_thread_fields[] = {
          PF_NA,
          "proc.pname",
          "Parent Name",
-         "The proc.name truncated after 16 characters) of the process generating the event."},
+         "The proc.name (truncated after 16 characters) of the parent process."},
         {PT_CHARBUF,
          EPF_ARG_ALLOWED | EPF_NO_RHS | EPF_NO_TRANSFORMER,
          PF_NA,
@@ -153,8 +153,7 @@ static const filtercheck_field_info sinsp_filter_check_thread_fields[] = {
          PF_NA,
          "proc.pcmdline",
          "Parent Command Line",
-         "The proc.cmdline (full command line (proc.name + proc.args)) of the parent of the "
-         "process generating the event."},
+         "The proc.cmdline (full command line (proc.name + proc.args)) of the parent process."},
         {PT_CHARBUF,
          EPF_ARG_ALLOWED | EPF_NO_RHS | EPF_NO_TRANSFORMER,
          PF_NA,
@@ -326,6 +325,39 @@ static const filtercheck_field_info sinsp_filter_check_thread_fields[] = {
          "the process with proc.vpgid == proc.vpid or the eldest ancestor that has the same vpgid "
          "as the current process. The description of `proc.is_vpgid_leader` offers additional "
          "insights."},
+        {PT_INT64,
+         EPF_NONE,
+         PF_ID,
+         "proc.pgid",
+         "Process Group ID",
+         "The process group id of the process generating the event, as seen from host PID "
+         "namespace."},
+        {PT_CHARBUF,
+         EPF_NONE,
+         PF_NA,
+         "proc.pgid.name",
+         "Process Group Name",
+         "The name of the current process's process group leader. This is either the process with "
+         "proc.pgid == proc.pid or the eldest ancestor that has the same pgid as the current "
+         "process. The description of `proc.is_pgid_leader` offers additional insights."},
+        {PT_CHARBUF,
+         EPF_NONE,
+         PF_NA,
+         "proc.pgid.exe",
+         "Process Group First Argument",
+         "The first command line argument argv[0] (usually the executable name or a custom one) of "
+         "the current process's process group leader. This is either the process with proc.pgid "
+         "== proc.pid or the eldest ancestor that has the same pgid as the current process. The "
+         "description of `proc.is_pgid_leader` offers additional insights."},
+        {PT_CHARBUF,
+         EPF_NONE,
+         PF_NA,
+         "proc.pgid.exepath",
+         "Process Group Executable Path",
+         "The full executable path of the current process's process group leader. This is either "
+         "the process with proc.pgid == proc.pid or the eldest ancestor that has the same pgid "
+         "as the current process. The description of `proc.is_pgid_leader` offers additional "
+         "insights."},
         {PT_RELTIME,
          EPF_NONE,
          PF_DEC,
@@ -400,6 +432,17 @@ static const filtercheck_field_info sinsp_filter_check_thread_fields[] = {
          "bash history logging, `is_vpgid_leader` would be 'true') or executed as descendent "
          "process in the same process group which for example is the case when subprocesses are "
          "spawned from a script (`is_vpgid_leader` would be 'false')."},
+        {PT_BOOL,
+         EPF_NONE,
+         PF_NA,
+         "proc.is_pgid_leader",
+         "Process Is Process Group Leader",
+         "'true' if this process is the leader of the process group, proc.pgid == "
+         "proc.pid. Can help to "
+         "distinguish if the process was 'directly' executed for instance in a tty (similar to "
+         "bash history logging, `is_pgid_leader` would be 'true') or executed as descendent "
+         "process in the same process group which for example is the case when subprocesses are "
+         "spawned from a script (`is_pgid_leader` would be 'false')."},
         {PT_INT64,
          EPF_NONE,
          PF_DEC,
@@ -1029,226 +1072,42 @@ uint8_t* sinsp_filter_check_thread::extract_single(sinsp_evt* evt,
 		RETURN_EXTRACT_VAR(tinfo->m_sid);
 	case TYPE_VPGID:
 		RETURN_EXTRACT_VAR(tinfo->m_vpgid);
-	case TYPE_SNAME: {
-		int64_t sid = tinfo->m_sid;
-
-		if(!tinfo->is_in_pid_namespace()) {
-			// Relying on the convention that a session id is the process id of the session leader.
-			// `threadinfo` lookup only applies when the process is running on the host and not in a
-			// pid namespace. However, if the process is running in a pid namespace, we instead
-			// traverse the process lineage until we find a match.
-			sinsp_threadinfo* sinfo = m_inspector->get_thread_ref(sid, false, true).get();
-			if(sinfo != NULL) {
-				m_tstr = sinfo->get_comm();
-				RETURN_EXTRACT_STRING(m_tstr);
-			}
-		}
-
-		// This can occur when the session leader process has exited or if the process
-		// is running in a pid namespace and we only have the virtual session id, as
-		// seen from its pid namespace.
-		// Find the highest ancestor process that has the same session id and
-		// declare it to be the session leader.
-		sinsp_threadinfo* session_leader = tinfo;
-
-		sinsp_threadinfo::visitor_func_t visitor = [sid, &session_leader](sinsp_threadinfo* pt) {
-			if(pt->m_sid != sid) {
-				return false;
-			}
-			session_leader = pt;
-			return true;
-		};
-
-		tinfo->traverse_parent_state(visitor);
-
-		// session_leader has been updated to the highest process that has the same session id.
-		// session_leader's comm is considered the session leader.
-		m_tstr = session_leader->get_comm();
+	case TYPE_SID_NAME:
+		m_tstr = tinfo->get_ancestor_field_as_string(
+		        [](sinsp_threadinfo* t) { return t->m_sid; },
+		        [](sinsp_threadinfo* t) { return t->get_comm(); },
+		        true);
 		RETURN_EXTRACT_STRING(m_tstr);
-	}
-	case TYPE_SID_EXE: {
-		int64_t sid = tinfo->m_sid;
-
-		if(!tinfo->is_in_pid_namespace()) {
-			// Relying on the convention that a session id is the process id of the session leader.
-			// `threadinfo` lookup only applies when the process is running on the host and not in a
-			// pid namespace. However, if the process is running in a pid namespace, we instead
-			// traverse the process lineage until we find a match.
-			sinsp_threadinfo* sinfo = m_inspector->get_thread_ref(sid, false, true).get();
-			if(sinfo != NULL) {
-				m_tstr = sinfo->get_exe();
-				RETURN_EXTRACT_STRING(m_tstr);
-			}
-		}
-
-		// This can occur when the session leader process has exited or if the process
-		// is running in a pid namespace and we only have the virtual session id, as
-		// seen from its pid namespace.
-		// Find the highest ancestor process that has the same session id and
-		// declare it to be the session leader.
-		sinsp_threadinfo* session_leader = tinfo;
-
-		sinsp_threadinfo::visitor_func_t visitor = [sid, &session_leader](sinsp_threadinfo* pt) {
-			if(pt->m_sid != sid) {
-				return false;
-			}
-			session_leader = pt;
-			return true;
-		};
-
-		tinfo->traverse_parent_state(visitor);
-
-		// session_leader has been updated to the highest process that has the same session id.
-		// session_leader's exe is considered the session leader.
-		m_tstr = session_leader->get_exe();
+	case TYPE_SID_EXE:
+		m_tstr = tinfo->get_ancestor_field_as_string(
+		        [](sinsp_threadinfo* t) { return t->m_sid; },
+		        [](sinsp_threadinfo* t) { return t->get_exe(); },
+		        true);
 		RETURN_EXTRACT_STRING(m_tstr);
-	}
-	case TYPE_SID_EXEPATH: {
-		int64_t sid = tinfo->m_sid;
-
-		if(!tinfo->is_in_pid_namespace()) {
-			// Relying on the convention that a session id is the process id of the session leader.
-			// `threadinfo` lookup only applies when the process is running on the host and not in a
-			// pid namespace. However, if the process is running in a pid namespace, we instead
-			// traverse the process lineage until we find a match.
-			sinsp_threadinfo* sinfo = m_inspector->get_thread_ref(sid, false, true).get();
-			if(sinfo != NULL) {
-				m_tstr = sinfo->get_exepath();
-				RETURN_EXTRACT_STRING(m_tstr);
-			}
-		}
-
-		// This can occur when the session leader process has exited or if the process
-		// is running in a pid namespace and we only have the virtual session id, as
-		// seen from its pid namespace.
-		// Find the highest ancestor process that has the same session id and
-		// declare it to be the session leader.
-		sinsp_threadinfo* session_leader = tinfo;
-
-		sinsp_threadinfo::visitor_func_t visitor = [sid, &session_leader](sinsp_threadinfo* pt) {
-			if(pt->m_sid != sid) {
-				return false;
-			}
-			session_leader = pt;
-			return true;
-		};
-
-		tinfo->traverse_parent_state(visitor);
-
-		// session_leader has been updated to the highest process that has the same session id.
-		// session_leader's exepath is considered the session leader.
-		m_tstr = session_leader->get_exepath();
+	case TYPE_SID_EXEPATH:
+		m_tstr = tinfo->get_ancestor_field_as_string(
+		        [](sinsp_threadinfo* t) { return t->m_sid; },
+		        [](sinsp_threadinfo* t) { return t->get_exepath(); },
+		        true);
 		RETURN_EXTRACT_STRING(m_tstr);
-	}
-	case TYPE_VPGID_NAME: {
-		int64_t vpgid = tinfo->m_vpgid;
-
-		if(!tinfo->is_in_pid_namespace()) {
-			// Relying on the convention that a process group id is the process id of the process
-			// group leader. `threadinfo` lookup only applies when the process is running on the
-			// host and not in a pid namespace. However, if the process is running in a pid
-			// namespace, we instead traverse the process lineage until we find a match.
-			sinsp_threadinfo* vpgidinfo = m_inspector->get_thread_ref(vpgid, false, true).get();
-			if(vpgidinfo != NULL) {
-				m_tstr = vpgidinfo->get_comm();
-				RETURN_EXTRACT_STRING(m_tstr);
-			}
-		}
-		// This can occur when the process group leader process has exited or if the process
-		// is running in a pid namespace and we only have the virtual process group id, as
-		// seen from its pid namespace.
-		// Find the highest ancestor process that has the same process group id and
-		// declare it to be the process group leader.
-		sinsp_threadinfo* group_leader = tinfo;
-
-		sinsp_threadinfo::visitor_func_t visitor = [vpgid, &group_leader](sinsp_threadinfo* pt) {
-			if(pt->m_vpgid != vpgid) {
-				return false;
-			}
-			group_leader = pt;
-			return true;
-		};
-
-		tinfo->traverse_parent_state(visitor);
-
-		// group_leader has been updated to the highest process that has the same process group id.
-		// group_leader's comm is considered the process group leader.
-		m_tstr = group_leader->get_comm();
+	case TYPE_VPGID_NAME:
+		m_tstr = tinfo->get_ancestor_field_as_string(
+		        [](sinsp_threadinfo* t) { return t->m_vpgid; },
+		        [](sinsp_threadinfo* t) { return t->get_comm(); },
+		        true);
 		RETURN_EXTRACT_STRING(m_tstr);
-	}
-	case TYPE_VPGID_EXE: {
-		int64_t vpgid = tinfo->m_vpgid;
-
-		if(!tinfo->is_in_pid_namespace()) {
-			// Relying on the convention that a process group id is the process id of the process
-			// group leader. `threadinfo` lookup only applies when the process is running on the
-			// host and not in a pid namespace. However, if the process is running in a pid
-			// namespace, we instead traverse the process lineage until we find a match.
-			sinsp_threadinfo* vpgidinfo = m_inspector->get_thread_ref(vpgid, false, true).get();
-			if(vpgidinfo != NULL) {
-				m_tstr = vpgidinfo->get_exe();
-				RETURN_EXTRACT_STRING(m_tstr);
-			}
-		}
-		// This can occur when the process group leader process has exited or if the process
-		// is running in a pid namespace and we only have the virtual process group id, as
-		// seen from its pid namespace.
-		// Find the highest ancestor process that has the same process group id and
-		// declare it to be the process group leader.
-		sinsp_threadinfo* group_leader = tinfo;
-
-		sinsp_threadinfo::visitor_func_t visitor = [vpgid, &group_leader](sinsp_threadinfo* pt) {
-			if(pt->m_vpgid != vpgid) {
-				return false;
-			}
-			group_leader = pt;
-			return true;
-		};
-
-		tinfo->traverse_parent_state(visitor);
-
-		// group_leader has been updated to the highest process that has the same process group id.
-		// group_leader's exe is considered the process group leader.
-		m_tstr = group_leader->get_exe();
+	case TYPE_VPGID_EXE:
+		m_tstr = tinfo->get_ancestor_field_as_string(
+		        [](sinsp_threadinfo* t) { return t->m_vpgid; },
+		        [](sinsp_threadinfo* t) { return t->get_exe(); },
+		        true);
 		RETURN_EXTRACT_STRING(m_tstr);
-	}
-	case TYPE_VPGID_EXEPATH: {
-		int64_t vpgid = tinfo->m_vpgid;
-
-		if(!tinfo->is_in_pid_namespace()) {
-			// Relying on the convention that a process group id is the process id of the process
-			// group leader. `threadinfo` lookup only applies when the process is running on the
-			// host and not in a pid namespace. However, if the process is running in a pid
-			// namespace, we instead traverse the process lineage until we find a match.
-			sinsp_threadinfo* vpgidinfo = m_inspector->get_thread_ref(vpgid, false, true).get();
-			if(vpgidinfo != NULL) {
-				m_tstr = vpgidinfo->get_exepath();
-				RETURN_EXTRACT_STRING(m_tstr);
-			}
-		}
-
-		// This can occur when the process group leader process has exited or if the process
-		// is running in a pid namespace and we only have the virtual process group id, as
-		// seen from its pid namespace.
-		// Find the highest ancestor process that has the same process group id and
-		// declare it to be the process group leader.
-		sinsp_threadinfo* group_leader = tinfo;
-
-		sinsp_threadinfo::visitor_func_t visitor = [vpgid, &group_leader](sinsp_threadinfo* pt) {
-			if(pt->m_vpgid != vpgid) {
-				return false;
-			}
-			group_leader = pt;
-			return true;
-		};
-
-		tinfo->traverse_parent_state(visitor);
-
-		// group_leader has been updated to the highest process that has the same process group id.
-		// group_leader's exepath is considered the process group leader.
-		m_tstr = group_leader->get_exepath();
+	case TYPE_VPGID_EXEPATH:
+		m_tstr = tinfo->get_ancestor_field_as_string(
+		        [](sinsp_threadinfo* t) { return t->m_vpgid; },
+		        [](sinsp_threadinfo* t) { return t->get_exepath(); },
+		        true);
 		RETURN_EXTRACT_STRING(m_tstr);
-	}
 	case TYPE_TTY:
 		RETURN_EXTRACT_VAR(tinfo->m_tty);
 	case TYPE_NAME:
@@ -1404,89 +1263,48 @@ uint8_t* sinsp_filter_check_thread::extract_single(sinsp_evt* evt,
 			return NULL;
 		}
 	}
-	case TYPE_PPID:
-		if(tinfo->is_main_thread()) {
-			if(!should_extract_xid(tinfo->m_ptid)) {
-				return NULL;
-			}
-			RETURN_EXTRACT_VAR(tinfo->m_ptid);
-		} else {
-			sinsp_threadinfo* mt = tinfo->get_main_thread();
-
-			if(mt != NULL) {
-				if(!should_extract_xid(mt->m_ptid)) {
-					return NULL;
-				}
-				RETURN_EXTRACT_VAR(mt->m_ptid);
-			} else {
-				return NULL;
-			}
-		}
-	case TYPE_PNAME: {
-		sinsp_threadinfo* ptinfo = m_inspector->get_thread_ref(tinfo->m_ptid, false, true).get();
-
-		if(ptinfo != NULL) {
-			m_tstr = ptinfo->get_comm();
-			RETURN_EXTRACT_STRING(m_tstr);
-		} else {
+	case TYPE_PPID: {
+		sinsp_threadinfo* mt = tinfo->get_ancestor_process();
+		if(!mt) {
 			return NULL;
 		}
+
+		if(!should_extract_xid(mt->m_pid)) {
+			return NULL;
+		}
+		RETURN_EXTRACT_VAR(mt->m_pid);
+	}
+	case TYPE_PNAME: {
+		sinsp_threadinfo* ptinfo = tinfo->get_ancestor_process();
+		if(!ptinfo) {
+			return NULL;
+		}
+
+		m_tstr = ptinfo->get_comm();
+		RETURN_EXTRACT_STRING(m_tstr);
 	}
 	case TYPE_PCMDLINE: {
-		sinsp_threadinfo* ptinfo = m_inspector->get_thread_ref(tinfo->m_ptid, false, true).get();
-
-		if(ptinfo != NULL) {
-			sinsp_threadinfo::populate_cmdline(m_tstr, ptinfo);
-			RETURN_EXTRACT_STRING(m_tstr);
-		} else {
+		sinsp_threadinfo* ptinfo = tinfo->get_ancestor_process();
+		if(!ptinfo) {
 			return NULL;
 		}
+
+		sinsp_threadinfo::populate_cmdline(m_tstr, ptinfo);
+		RETURN_EXTRACT_STRING(m_tstr);
 	}
 	case TYPE_ACMDLINE: {
-		sinsp_threadinfo* mt = NULL;
-
-		if(tinfo->is_main_thread()) {
-			mt = tinfo;
-		} else {
-			mt = tinfo->get_main_thread();
-
-			if(mt == NULL) {
-				return NULL;
-			}
+		sinsp_threadinfo* mt = tinfo->get_ancestor_process(m_argid);
+		if(!mt) {
+			return NULL;
 		}
 
-		for(int32_t j = 0; j < m_argid; j++) {
-			mt = mt->get_parent_thread();
-
-			if(mt == NULL) {
-				return NULL;
-			}
-		}
 		sinsp_threadinfo::populate_cmdline(m_tstr, mt);
 		RETURN_EXTRACT_STRING(m_tstr);
 	}
 	case TYPE_APID: {
-		sinsp_threadinfo* mt = NULL;
-
-		if(tinfo->is_main_thread()) {
-			mt = tinfo;
-		} else {
-			mt = tinfo->get_main_thread();
-
-			if(mt == NULL) {
-				return NULL;
-			}
-		}
-
-		//
-		// Search for a specific ancestors
-		//
-		for(int32_t j = 0; j < m_argid; j++) {
-			mt = mt->get_parent_thread();
-
-			if(mt == NULL) {
-				return NULL;
-			}
+		sinsp_threadinfo* mt = tinfo->get_ancestor_process(m_argid);
+		if(!mt) {
+			return NULL;
 		}
 
 		if(!should_extract_xid(mt->m_pid)) {
@@ -1495,92 +1313,45 @@ uint8_t* sinsp_filter_check_thread::extract_single(sinsp_evt* evt,
 		RETURN_EXTRACT_VAR(mt->m_pid);
 	}
 	case TYPE_ANAME: {
-		sinsp_threadinfo* mt = NULL;
-
-		if(tinfo->is_main_thread()) {
-			mt = tinfo;
-		} else {
-			mt = tinfo->get_main_thread();
-
-			if(mt == NULL) {
-				return NULL;
-			}
-		}
-
-		for(int32_t j = 0; j < m_argid; j++) {
-			mt = mt->get_parent_thread();
-
-			if(mt == NULL) {
-				return NULL;
-			}
+		sinsp_threadinfo* mt = tinfo->get_ancestor_process(m_argid);
+		if(!mt) {
+			return NULL;
 		}
 
 		m_tstr = mt->get_comm();
 		RETURN_EXTRACT_STRING(m_tstr);
 	}
 	case TYPE_PEXE: {
-		sinsp_threadinfo* ptinfo = m_inspector->get_thread_ref(tinfo->m_ptid, false, true).get();
-
-		if(ptinfo != NULL) {
-			m_tstr = ptinfo->get_exe();
-			RETURN_EXTRACT_STRING(m_tstr);
-		} else {
+		sinsp_threadinfo* ptinfo = tinfo->get_ancestor_process();
+		if(!ptinfo) {
 			return NULL;
 		}
+
+		m_tstr = ptinfo->get_exe();
+		RETURN_EXTRACT_STRING(m_tstr);
 	}
 	case TYPE_AEXE: {
-		sinsp_threadinfo* mt = NULL;
-
-		if(tinfo->is_main_thread()) {
-			mt = tinfo;
-		} else {
-			mt = tinfo->get_main_thread();
-
-			if(mt == NULL) {
-				return NULL;
-			}
-		}
-
-		for(int32_t j = 0; j < m_argid; j++) {
-			mt = mt->get_parent_thread();
-
-			if(mt == NULL) {
-				return NULL;
-			}
+		sinsp_threadinfo* mt = tinfo->get_ancestor_process(m_argid);
+		if(!mt) {
+			return NULL;
 		}
 
 		m_tstr = mt->get_exe();
 		RETURN_EXTRACT_STRING(m_tstr);
 	}
 	case TYPE_PEXEPATH: {
-		sinsp_threadinfo* ptinfo = m_inspector->get_thread_ref(tinfo->m_ptid, false, true).get();
-
-		if(ptinfo != NULL) {
-			m_tstr = ptinfo->get_exepath();
-			RETURN_EXTRACT_STRING(m_tstr);
-		} else {
+		sinsp_threadinfo* ptinfo = tinfo->get_ancestor_process();
+		if(!ptinfo) {
 			return NULL;
 		}
+
+		m_tstr = ptinfo->get_exepath();
+		RETURN_EXTRACT_STRING(m_tstr);
 	}
 	case TYPE_AEXEPATH: {
-		sinsp_threadinfo* mt = NULL;
-
-		if(tinfo->is_main_thread()) {
-			mt = tinfo;
-		} else {
-			mt = tinfo->get_main_thread();
-
-			if(mt == NULL) {
-				return NULL;
-			}
-		}
-
-		for(int32_t j = 0; j < m_argid; j++) {
-			mt = mt->get_parent_thread();
-
-			if(mt == NULL) {
-				return NULL;
-			}
+		sinsp_threadinfo* mt = tinfo->get_ancestor_process(m_argid);
+		if(!mt) {
+			return NULL;
 		}
 
 		m_tstr = mt->get_exepath();
@@ -1618,7 +1389,7 @@ uint8_t* sinsp_filter_check_thread::extract_single(sinsp_evt* evt,
 
 		RETURN_EXTRACT_PTR(res);
 	}
-	case TYPE_DURATION:
+	case TYPE_DURATION: {
 		if(tinfo->m_clone_ts != 0) {
 			m_val.s64 = evt->get_ts() - tinfo->m_clone_ts;
 			ASSERT(m_val.s64 > 0);
@@ -1626,18 +1397,18 @@ uint8_t* sinsp_filter_check_thread::extract_single(sinsp_evt* evt,
 		} else {
 			return NULL;
 		}
+	}
 	case TYPE_PPID_DURATION: {
-		sinsp_threadinfo* ptinfo = m_inspector->get_thread_ref(tinfo->m_ptid, false, true).get();
-
-		if(ptinfo != NULL) {
-			if(ptinfo->m_clone_ts != 0) {
-				m_val.s64 = evt->get_ts() - ptinfo->m_clone_ts;
-				ASSERT(m_val.s64 > 0);
-				RETURN_EXTRACT_VAR(m_val.s64);
-			}
-		} else {
+		sinsp_threadinfo* ptinfo = tinfo->get_ancestor_process();
+		if(!ptinfo) {
 			return NULL;
 		}
+
+		if(ptinfo->m_clone_ts != 0) {
+			m_val.s64 = evt->get_ts() - ptinfo->m_clone_ts;
+			ASSERT(m_val.s64 > 0);
+			RETURN_EXTRACT_VAR(m_val.s64);
+		}
 	}
 	case TYPE_FDOPENCOUNT:
 		m_val.u64 = tinfo->get_fd_opencount();
@@ -1736,56 +1507,6 @@ uint8_t* sinsp_filter_check_thread::extract_single(sinsp_evt* evt,
 
 		m_val.u64 = tinfo->m_vpid;
 		RETURN_EXTRACT_VAR(m_val.u64);
-		/*
-		    case TYPE_PROC_CPU:
-		        {
-		            uint16_t etype = evt->get_type();
-
-		            if(etype == PPME_PROCINFO_E)
-		            {
-		                double thval;
-		                uint64_t tcpu;
-
-		                sinsp_evt_param* parinfo = evt->get_param(0);
-		                tcpu = *(uint64_t*)parinfo->m_val;
-
-		                parinfo = evt->get_param(1);
-		                tcpu += *(uint64_t*)parinfo->m_val;
-
-		                if(tinfo->m_last_t_tot_cpu != 0)
-		                {
-		                    uint64_t deltaval = tcpu - tinfo->m_last_t_tot_cpu;
-		                    thval = (double)deltaval;// / (ONE_SECOND_IN_NS / 100);
-		                    if(thval > 100)
-		                    {
-		                        thval = 100;
-		                    }
-		                }
-		                else
-		                {
-		                    thval = 0;
-		                }
-
-		                tinfo->m_last_t_tot_cpu = tcpu;
-
-		                uint64_t ets = evt->get_ts();
-		                sinsp_threadinfo* mt = tinfo->get_main_thread();
-
-		                if(ets != mt->m_last_mt_cpu_ts)
-		                {
-		                    mt->m_last_mt_tot_cpu = 0;
-		                    mt->m_last_mt_cpu_ts = ets;
-		                }
-
-		                mt->m_last_mt_tot_cpu += thval;
-		                m_val.d = mt->m_last_mt_tot_cpu;
-
-		                RETURN_EXTRACT_VAR(m_val.d);
-		            }
-
-		            return NULL;
-		        }
-		*/
 	case TYPE_THREAD_CPU: {
 		return extract_thread_cpu(evt, len, tinfo, true, true);
 	}
@@ -1946,6 +1667,26 @@ uint8_t* sinsp_filter_check_thread::extract_single(sinsp_evt* evt,
 		m_tstr = fdinfo->m_name.c_str();
 		RETURN_EXTRACT_STRING(m_tstr);
 	}
+	case TYPE_PGID:
+		RETURN_EXTRACT_VAR(tinfo->m_pgid);
+	case TYPE_PGID_NAME:
+		m_tstr = tinfo->get_ancestor_field_as_string(
+		        [](sinsp_threadinfo* t) { return t->m_pgid; },
+		        [](sinsp_threadinfo* t) { return t->get_comm(); });
+		RETURN_EXTRACT_STRING(m_tstr);
+	case TYPE_PGID_EXE:
+		m_tstr = tinfo->get_ancestor_field_as_string(
+		        [](sinsp_threadinfo* t) { return t->m_pgid; },
+		        [](sinsp_threadinfo* t) { return t->get_exe(); });
+		RETURN_EXTRACT_STRING(m_tstr);
+	case TYPE_PGID_EXEPATH:
+		m_tstr = tinfo->get_ancestor_field_as_string(
+		        [](sinsp_threadinfo* t) { return t->m_pgid; },
+		        [](sinsp_threadinfo* t) { return t->get_exepath(); });
+		RETURN_EXTRACT_STRING(m_tstr);
+	case TYPE_IS_PGID_LEADER:
+		m_val.u32 = tinfo->m_pgid == tinfo->m_pid;
+		RETURN_EXTRACT_VAR(m_val.u32);
 	default:
 		ASSERT(false);
 		return NULL;
