@@ -51,13 +51,17 @@ public:
 		TYPE_VPID,
 		TYPE_PVPID,
 		TYPE_SID,
-		TYPE_SNAME,
+		TYPE_SID_NAME,
 		TYPE_SID_EXE,
 		TYPE_SID_EXEPATH,
 		TYPE_VPGID,
 		TYPE_VPGID_NAME,
 		TYPE_VPGID_EXE,
 		TYPE_VPGID_EXEPATH,
+		TYPE_PGID,
+		TYPE_PGID_NAME,
+		TYPE_PGID_EXE,
+		TYPE_PGID_EXEPATH,
 		TYPE_DURATION,
 		TYPE_PPID_DURATION,
 		TYPE_PID_CLONE_TS,
@@ -68,6 +72,7 @@ public:
 		TYPE_IS_EXE_FROM_MEMFD,
 		TYPE_IS_SID_LEADER,
 		TYPE_IS_VPGID_LEADER,
+		TYPE_IS_PGID_LEADER,
 		TYPE_EXE_INO,
 		TYPE_EXE_INO_CTIME,
 		TYPE_EXE_INO_MTIME,
