@@ -20,11 +20,9 @@ limitations under the License.
 
 #include <libsinsp/sinsp_filtercheck.h>
 
-class sinsp_filter_check_user : public sinsp_filter_check
-{
+class sinsp_filter_check_user : public sinsp_filter_check {
 public:
-	enum check_type
-	{
+	enum check_type {
 		TYPE_UID = 0,
 		TYPE_NAME = 1,
 		TYPE_HOMEDIR = 2,
@@ -39,8 +37,12 @@ public:
 	std::unique_ptr<sinsp_filter_check> allocate_new() override;
 
 protected:
-	uint8_t* extract(sinsp_evt*, OUT uint32_t* len, bool sanitize_strings = true) override;
+	uint8_t* extract_single(sinsp_evt*, uint32_t* len, bool sanitize_strings = true) override;
 
 private:
-	int64_t m_s64val;
+	union {
+		uint32_t u32;
+		int64_t s64;
+	} m_val;
+	std::string m_strval;
 };
