@@ -19,6 +19,7 @@ limitations under the License.
 #include <gtest/gtest.h>
 
 #include <sinsp_with_test_input.h>
+#include <helpers/threads_helpers.h>
 #include "test_utils.h"
 
 /* Assert if the thread `exepath` is set to the right value
@@ -719,23 +720,19 @@ TEST_F(sinsp_with_test_input, spawn_process) {
 	// check that the name is updated
 	ASSERT_EQ(get_field_as_string(evt, "proc.name"), "test-exe");
 	ASSERT_EQ(get_field_as_string(evt, "proc.aname[0]"), "test-exe");
-	ASSERT_EQ(get_field_as_string(evt, "proc.aname"), "test-exe");
 
 	// check that the pid is updated
 	ASSERT_EQ(get_field_as_string(evt, "proc.pid"), "20");
 	ASSERT_EQ(get_field_as_string(evt, "proc.vpid"), "20");
 	ASSERT_EQ(get_field_as_string(evt, "proc.apid[0]"), "20");
-	ASSERT_EQ(get_field_as_string(evt, "proc.apid"), "20");
 
 	// check that the exe is updated (first arg given in this test setup is same as full exepath)
 	ASSERT_EQ(get_field_as_string(evt, "proc.exe"), "/bin/test-exe");
 	ASSERT_EQ(get_field_as_string(evt, "proc.aexe[0]"), "/bin/test-exe");
-	ASSERT_EQ(get_field_as_string(evt, "proc.aexe"), "/bin/test-exe");
 
 	// check that the exepath is updated
 	ASSERT_EQ(get_field_as_string(evt, "proc.exepath"), "/bin/test-exe");
 	ASSERT_EQ(get_field_as_string(evt, "proc.aexepath[0]"), "/bin/test-exe");
-	ASSERT_EQ(get_field_as_string(evt, "proc.aexepath"), "/bin/test-exe");
 
 	// check session leader (sid) related fields
 	ASSERT_EQ(get_field_as_string(evt, "proc.sid"), "0");
@@ -774,7 +771,6 @@ TEST_F(sinsp_with_test_input, spawn_process) {
 	ASSERT_EQ(get_field_as_string(evt, "proc.pcmdline"), "init");
 	ASSERT_EQ(get_field_as_string(evt, "proc.acmdline[0]"),
 	          "test-exe -c 'echo aGVsbG8K | base64 -d'");
-	ASSERT_EQ(get_field_as_string(evt, "proc.acmdline"), "test-exe -c 'echo aGVsbG8K | base64 -d'");
 	ASSERT_EQ(get_field_as_string(evt, "proc.acmdline[1]"), "init");
 	ASSERT_FALSE(field_has_value(evt, "proc.acmdline[2]"));
 
@@ -1356,3 +1352,20 @@ TEST_F(sinsp_with_test_input, last_exec_ts) {
 	// Check we execed after the last clone
 	ASSERT_GT(evt->get_thread_info()->m_lastexec_ts, evt->get_thread_info()->m_clone_ts);
 }
+
+TEST_F(sinsp_with_test_input, proc_ppid_apid) {
+	/* Instantiate the default tree */
+	DEFAULT_TREE
+
+	/* Create a child for `p2_t3` */
+	int64_t p7_t1_tid = 100;
+	[[maybe_unused]] int64_t p7_t1_pid = 100;
+	[[maybe_unused]] int64_t p7_t1_ptid = p2_t3_tid;
+
+	auto evt = generate_clone_x_event(p7_t1_tid, p2_t3_tid, p2_t3_pid, p2_t3_ptid);
+	ASSERT_THREAD_CHILDREN(p2_t3_tid, 1, 1, p7_t1_tid);
+
+	/* Check that proc.ppid and proc.apid[1] are the same and that this holds even in the case
+	    a thread performed a clone */
+	ASSERT_EQ(get_field_as_string(evt, "proc.ppid"), get_field_as_string(evt, "proc.apid[1]"));
+}
