@@ -67,14 +67,16 @@ TEST_F(sinsp_with_test_input, PROC_FILTER_exepath) {
 	DEFAULT_TREE
 
 	/* Now we call an execve on p6_t1 */
-	auto evt = generate_execve_enter_and_exit_event(0,
-	                                                p6_t1_tid,
-	                                                p6_t1_tid,
-	                                                p6_t1_pid,
-	                                                p6_t1_ptid,
-	                                                "/good-exe",
-	                                                "good-exe",
-	                                                "/usr/bin/bad-exe");
+	auto evt =
+	        generate_execve_enter_and_exit_event(0,
+	                                             p6_t1_tid,
+	                                             p6_t1_tid,
+	                                             p6_t1_pid,
+	                                             p6_t1_ptid,
+	                                             "/good-exe",
+	                                             "good-exe",
+	                                             // Please note that the `deleted` will be removed.
+	                                             "/usr/bin/bad-exe (deleted)");
 
 	ASSERT_EQ(get_field_as_string(evt, "proc.exepath"), "/usr/bin/bad-exe");
 	ASSERT_EQ(get_field_as_string(evt, "proc.name"), "good-exe");
@@ -163,22 +165,79 @@ TEST_F(sinsp_with_test_input, PROC_FILTER_aname) {
 	EXPECT_FALSE(eval_filter(evt, "proc.aname in (bad-exe)"));
 }
 
+TEST_F(sinsp_with_test_input, PROC_FILTER_pgid_family) {
+	DEFAULT_TREE
+
+	auto p3_t1_tinfo = m_inspector.get_thread_ref(p3_t1_tid, false).get();
+	ASSERT_TRUE(p3_t1_tinfo);
+
+	auto p1_t1_tinfo = m_inspector.get_thread_ref(p1_t1_tid, false).get();
+	ASSERT_TRUE(p1_t1_tinfo);
+
+	//
+	// Direct access in the thread table
+	//
+
+	// manually set the pgid to p1_t1
+	p3_t1_tinfo->m_pgid = p1_t1_pid;
+	// Be sure we will obtain specific values not shared by other threads
+	p1_t1_tinfo->m_comm = "p1_t1_comm";
+	p1_t1_tinfo->m_exe = "p1_t1_exe";
+	p1_t1_tinfo->m_exepath = "p1_t1_exepath";
+
+	// Generate random event to call filter-checks
+	auto evt = generate_random_event(p3_t1_tid);
+
+	ASSERT_EQ(get_field_as_string(evt, "proc.pgid"), std::to_string(p1_t1_pid));
+	ASSERT_EQ(get_field_as_string(evt, "proc.pgid.name"), p1_t1_tinfo->get_comm());
+	ASSERT_EQ(get_field_as_string(evt, "proc.pgid.exe"), p1_t1_tinfo->get_exe());
+	ASSERT_EQ(get_field_as_string(evt, "proc.pgid.exepath"), p1_t1_tinfo->get_exepath());
+	ASSERT_EQ(get_field_as_string(evt, "proc.is_pgid_leader"), "false");
+
+	//
+	// Current process is leader
+	//
+
+	p3_t1_tinfo->m_pgid = p3_t1_pid;
+	p3_t1_tinfo->m_comm = "p3_t1_comm";
+	p3_t1_tinfo->m_exe = "p3_t1_exe";
+	p3_t1_tinfo->m_exepath = "p3_t1_exepath";
+	evt = generate_random_event(p3_t1_tid);
+	ASSERT_EQ(get_field_as_string(evt, "proc.pgid"), std::to_string(p3_t1_tid));
+	ASSERT_EQ(get_field_as_string(evt, "proc.pgid.name"), p3_t1_tinfo->get_comm());
+	ASSERT_EQ(get_field_as_string(evt, "proc.pgid.exe"), p3_t1_tinfo->get_exe());
+	ASSERT_EQ(get_field_as_string(evt, "proc.pgid.exepath"), p3_t1_tinfo->get_exepath());
+	ASSERT_EQ(get_field_as_string(evt, "proc.is_pgid_leader"), "true");
+
+	//
+	// Missing process group find ancestor
+	//
+
+	auto p2_t1_tinfo = m_inspector.get_thread_ref(p2_t1_tid, false).get();
+	ASSERT_TRUE(p2_t1_tinfo);
+
+	int64_t random_pgid = 100000;
+	p3_t1_tinfo->m_pgid = random_pgid;
+	// p2_t1 is the last ancestor with the same pgid
+	p2_t1_tinfo->m_pgid = random_pgid;
+	p2_t1_tinfo->m_comm = "p2_t1_comm";
+	p2_t1_tinfo->m_exe = "p2_t1_exe";
+	p2_t1_tinfo->m_exepath = "p2_t1_exepath";
+	evt = generate_random_event(p3_t1_tid);
+	ASSERT_EQ(get_field_as_string(evt, "proc.pgid"), std::to_string(random_pgid));
+	ASSERT_EQ(get_field_as_string(evt, "proc.pgid.name"), p2_t1_tinfo->get_comm());
+	ASSERT_EQ(get_field_as_string(evt, "proc.pgid.exe"), p2_t1_tinfo->get_exe());
+	ASSERT_EQ(get_field_as_string(evt, "proc.pgid.exepath"), p2_t1_tinfo->get_exepath());
+	ASSERT_EQ(get_field_as_string(evt, "proc.is_pgid_leader"), "false");
+}
+
 #if !defined(_WIN32) && !defined(__EMSCRIPTEN__) && !defined(__APPLE__)
 TEST_F(sinsp_with_test_input, PROC_FILTER_stdin_stdout_stderr) {
 	DEFAULT_TREE
 	sinsp_evt* evt = NULL;
-	int64_t client_fd = 3, return_value = 0;
 	int64_t stdin_fd = 0, stdout_fd = 1, stderr_fd = 2;
 
-	// Create a connected socket
-	add_event_advance_ts(increasing_ts(),
-	                     1,
-	                     PPME_SOCKET_SOCKET_E,
-	                     3,
-	                     (uint32_t)PPM_AF_INET,
-	                     (uint32_t)SOCK_STREAM,
-	                     0);
-	add_event_advance_ts(increasing_ts(), 1, PPME_SOCKET_SOCKET_X, 1, client_fd);
+	generate_socket_events();
 
 	sockaddr_in client =
 	        test_utils::fill_sockaddr_in(DEFAULT_CLIENT_PORT, DEFAULT_IPV4_CLIENT_STRING);
@@ -193,7 +252,7 @@ TEST_F(sinsp_with_test_input, PROC_FILTER_stdin_stdout_stderr) {
 	        1,
 	        PPME_SOCKET_CONNECT_E,
 	        2,
-	        client_fd,
+	        sinsp_test_input::socket_params::default_fd,
 	        scap_const_sized_buffer{server_sockaddr.data(), server_sockaddr.size()});
 
 	std::vector<uint8_t> socktuple =
@@ -203,34 +262,46 @@ TEST_F(sinsp_with_test_input, PROC_FILTER_stdin_stdout_stderr) {
 	                           1,
 	                           PPME_SOCKET_CONNECT_X,
 	                           3,
-	                           return_value,
+	                           (int64_t)0,
 	                           scap_const_sized_buffer{socktuple.data(), socktuple.size()},
-	                           client_fd);
+	                           sinsp_test_input::socket_params::default_fd);
 
 	// The socket is duped to stdin, stdout, stderr
-	evt = add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_DUP2_E, 1, client_fd);
+	evt = add_event_advance_ts(increasing_ts(),
+	                           1,
+	                           PPME_SYSCALL_DUP2_E,
+	                           1,
+	                           sinsp_test_input::socket_params::default_fd);
 	evt = add_event_advance_ts(increasing_ts(),
 	                           1,
 	                           PPME_SYSCALL_DUP2_X,
 	                           3,
 	                           stdin_fd,
-	                           client_fd,
+	                           sinsp_test_input::socket_params::default_fd,
 	                           stdin_fd);
-	evt = add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_DUP2_E, 1, client_fd);
+	evt = add_event_advance_ts(increasing_ts(),
+	                           1,
+	                           PPME_SYSCALL_DUP2_E,
+	                           1,
+	                           sinsp_test_input::socket_params::default_fd);
 	evt = add_event_advance_ts(increasing_ts(),
 	                           1,
 	                           PPME_SYSCALL_DUP2_X,
 	                           3,
 	                           stdout_fd,
-	                           client_fd,
+	                           sinsp_test_input::socket_params::default_fd,
 	                           stdout_fd);
-	evt = add_event_advance_ts(increasing_ts(), 1, PPME_SYSCALL_DUP2_E, 1, client_fd);
+	evt = add_event_advance_ts(increasing_ts(),
+	                           1,
+	                           PPME_SYSCALL_DUP2_E,
+	                           1,
+	                           sinsp_test_input::socket_params::default_fd);
 	evt = add_event_advance_ts(increasing_ts(),
 	                           1,
 	                           PPME_SYSCALL_DUP2_X,
 	                           3,
 	                           stderr_fd,
-	                           client_fd,
+	                           sinsp_test_input::socket_params::default_fd,
 	                           stderr_fd);
 
 	// Exec a process and check stdin, stdout and stderr types and names
