@@ -155,6 +155,16 @@ TEST_F(sinsp_with_test_input, plugin_syscall_extract) {
 	// This plugin tells that it can receive `syscall` events
 	add_plugin_filterchecks(&m_inspector, pl, sinsp_syscall_event_source_name, pl_flist);
 
+	// Since `%ample.is_open` field was requested by the plugin as an addOutput field,
+	// its filtercheck should have the EPF_FORMAT_SUGGESTED flag..
+	std::vector<const filter_check_info*> fields;
+	pl_flist.get_all_fields(fields);
+	for(const auto& field : fields) {
+		if(field->m_name == "sample.is_open") {
+			ASSERT_TRUE(field->m_flags & EPF_FORMAT_SUGGESTED);
+		}
+	}
+
 	// Open the inspector in test mode
 	add_default_init_thread();
 	open_inspector();
@@ -346,6 +356,16 @@ TEST_F(sinsp_with_test_input, plugin_custom_source) {
 	// the GENERIC platform type does not fill in machine_info
 	ASSERT_EQ(m_inspector.get_machine_info()->num_cpus, 0);
 
+	// Since `%sample.hello` field was requested by the plugin as an addOutput field,
+	// its value should be present in the output.
+	std::vector<const filter_check_info*> fields;
+	filterlist.get_all_fields(fields);
+	for(const auto& field : fields) {
+		if(field->m_name == "sample.hello") {
+			ASSERT_TRUE(field->m_flags & EPF_FORMAT_SUGGESTED);
+		}
+	}
+
 	auto evt = next_event();
 	ASSERT_NE(evt, nullptr);
 	ASSERT_EQ(evt->get_type(), PPME_PLUGINEVENT_E);
@@ -358,6 +378,76 @@ TEST_F(sinsp_with_test_input, plugin_custom_source) {
 	ASSERT_EQ(next_event(), nullptr);  // EOF is expected
 }
 
+class plugin_test_event_processor : public libsinsp::event_processor {
+public:
+	explicit plugin_test_event_processor(const char* ev_name) {
+		num_async_evts = 0;
+		event_name = ev_name;
+	}
+
+	void on_capture_start() override {}
+
+	void process_event(sinsp_evt* evt, libsinsp::event_return rc) override {
+		if(evt->get_type() == PPME_ASYNCEVENT_E) {
+			// Retrieve internal event name
+			auto ev_name = evt->get_param(1)->as<std::string>();
+			if(ev_name == event_name) {
+				num_async_evts++;
+			}
+		}
+	}
+
+	int num_async_evts;
+
+private:
+	std::string event_name;
+};
+
+// scenario: a plugin with dump capability is requested a dump and then the capture file is read.
+// * register a plugin with async event capability
+// * open inspector in no driver mode
+// * request a scap file dump to a temporary text file
+// * at this stage, the plugin will be requested to dump its state; in our test case, the plugin
+// will just dump 10 fake events
+// * open a replay inspector to read the generated scap file
+// * register our event processor that just counts number of PPME_ASYNC_EVENT_E
+// * remove the test scap file
+// note: emscripten has trouble with the nodriver engine and async events
+#if !defined(__EMSCRIPTEN__)
+TEST_F(sinsp_with_test_input, plugin_dump) {
+	uint64_t max_count = 1;
+	uint64_t period_ns = 1000000;  // 1ms
+	std::string async_pl_cfg = std::to_string(max_count) + ":" + std::to_string(period_ns);
+	register_plugin(&m_inspector, get_plugin_api_sample_syscall_async);
+
+	// we will not use the test scap engine here, but open the src plugin instead
+	// note: we configure the plugin to just emit 1 event through its open params
+	m_inspector.open_nodriver();
+
+	auto evt = next_event();
+	ASSERT_NE(evt, nullptr);
+	ASSERT_EQ(evt->get_type(), PPME_ASYNCEVENT_E);
+
+	auto sinspdumper = sinsp_dumper();
+	sinspdumper.open(&m_inspector, "test.scap", false);
+	sinspdumper.close();
+
+	m_inspector.close();
+
+	// Here we open a replay inspector just to trigger the initstate events parsing
+	auto replay_inspector = sinsp();
+	//
+	auto processor = plugin_test_event_processor("sampleticker");
+	replay_inspector.register_external_event_processor(processor);
+	ASSERT_NO_THROW(replay_inspector.open_savefile("test.scap"));
+
+	ASSERT_EQ(processor.num_async_evts, 10);
+
+	replay_inspector.close();
+	remove("test.scap");
+}
+#endif
+
 TEST(sinsp_plugin, plugin_extract_compatibility) {
 	std::string tmp;
 	sinsp i;
@@ -939,6 +1029,110 @@ TEST_F(sinsp_with_test_input, plugin_subtables_array) {
 	ASSERT_EQ(subtable->entries_count(), 0);
 }
 
+TEST_F(sinsp_with_test_input, plugin_subtables_array_pair) {
+	const constexpr auto num_entries_from_plugin = 10;
+
+	auto& reg = m_inspector.get_table_registry();
+
+	register_plugin(&m_inspector, get_plugin_api_sample_syscall_subtables_array_pair);
+
+	auto table = reg->get_table<int64_t>("threads");
+	ASSERT_NE(table, nullptr);
+	ASSERT_EQ(table->name(), "threads");
+	ASSERT_EQ(table->entries_count(), 0);
+	ASSERT_EQ(table->key_info(), libsinsp::state::typeinfo::of<int64_t>());
+	ASSERT_EQ(table->dynamic_fields()->fields().size(), 0);
+
+	// Test "cgroups" field
+	auto field = table->static_fields()->find("cgroups");
+	ASSERT_NE(field, table->static_fields()->end());
+	ASSERT_EQ(field->second.readonly(), true);
+	ASSERT_EQ(field->second.valid(), true);
+	ASSERT_EQ(field->second.name(), "cgroups");
+	ASSERT_EQ(field->second.info(), libsinsp::state::typeinfo::of<libsinsp::state::base_table*>());
+
+	ASSERT_EQ(table->entries_count(), 0);
+
+	// add a new entry to the thread table
+	ASSERT_NE(table->add_entry(5, table->new_entry()), nullptr);
+	auto entry = table->get_entry(5);
+	ASSERT_NE(entry, nullptr);
+	ASSERT_EQ(table->entries_count(), 1);
+
+	// obtain a pointer to the subtable (check typing too)
+	auto subtable_acc = field->second.new_accessor<libsinsp::state::base_table*>();
+	auto subtable = dynamic_cast<libsinsp::state::stl_container_table_adapter<
+	        std::vector<std::pair<std::string, std::string>>,
+	        libsinsp::state::pair_table_entry_adapter<std::string, std::string>>*>(
+	        entry->get_static_field(subtable_acc));
+	ASSERT_NE(subtable, nullptr);
+	ASSERT_EQ(subtable->name(), "cgroups");
+	ASSERT_EQ(subtable->entries_count(), 0);
+	// get an accessor to a dynamic field representing the array's values
+	ASSERT_EQ(subtable->dynamic_fields()->fields().size(), 2);  // pair.first, pair.second
+
+	auto dfield_first = subtable->dynamic_fields()->fields().find("first");
+	ASSERT_NE(dfield_first, subtable->dynamic_fields()->fields().end());
+	ASSERT_EQ(dfield_first->second.readonly(), false);
+	ASSERT_EQ(dfield_first->second.valid(), true);
+	ASSERT_EQ(dfield_first->second.name(), "first");
+	ASSERT_EQ(dfield_first->second.info(), libsinsp::state::typeinfo::of<std::string>());
+	auto dfield_first_acc = dfield_first->second.new_accessor<std::string>();
+
+	auto dfield_second = subtable->dynamic_fields()->fields().find("second");
+	ASSERT_NE(dfield_second, subtable->dynamic_fields()->fields().end());
+	ASSERT_EQ(dfield_second->second.readonly(), false);
+	ASSERT_EQ(dfield_second->second.valid(), true);
+	ASSERT_EQ(dfield_second->second.name(), "second");
+	ASSERT_EQ(dfield_second->second.info(), libsinsp::state::typeinfo::of<std::string>());
+	auto dfield_second_acc = dfield_second->second.new_accessor<std::string>();
+
+	// start the event capture
+	// we coordinate with the plugin by sending open events: for each one received,
+	// the plugin will take a subsequent action on which we then assert the status
+	open_inspector();
+
+	// step #0: the plugin should populate the fdtable
+	add_event_advance_ts(increasing_ts(),
+	                     0,
+	                     PPME_SYSCALL_OPEN_E,
+	                     3,
+	                     "/tmp/the_file",
+	                     PPM_O_RDWR,
+	                     0);
+	ASSERT_EQ(subtable->entries_count(), num_entries_from_plugin);
+
+	auto itt = [&](libsinsp::state::table_entry& e) -> bool {
+		std::string first, second;
+		e.get_dynamic_field(dfield_first_acc, first);
+		e.get_dynamic_field(dfield_second_acc, second);
+		EXPECT_EQ(first, "hello");
+		EXPECT_EQ(second, "world");
+		return true;
+	};
+	ASSERT_TRUE(subtable->foreach_entry(itt));
+
+	// step #1: the plugin should remove one entry from the fdtable
+	add_event_advance_ts(increasing_ts(),
+	                     0,
+	                     PPME_SYSCALL_OPEN_E,
+	                     3,
+	                     "/tmp/the_file",
+	                     PPM_O_RDWR,
+	                     0);
+	ASSERT_EQ(subtable->entries_count(), num_entries_from_plugin - 1);
+
+	// step #2: the plugin should cleae the fdtable
+	add_event_advance_ts(increasing_ts(),
+	                     0,
+	                     PPME_SYSCALL_OPEN_E,
+	                     3,
+	                     "/tmp/the_file",
+	                     PPM_O_RDWR,
+	                     0);
+	ASSERT_EQ(subtable->entries_count(), 0);
+}
+
 // Scenario: we load a plugin expecting it to log
 // when it's initialized and destroyed.
 // We use a callback attached to the logger to assert the message.
@@ -996,8 +1190,6 @@ TEST(sinsp_plugin, plugin_set_config) {
 	libsinsp_logger()->remove_callback_log();
 }
 
-#ifdef __linux__
-
 TEST_F(sinsp_with_test_input, plugin_metrics) {
 	uint32_t test_metrics_flags = (METRICS_V2_PLUGINS);
 	libs::metrics::libs_metrics_collector libs_metrics_collector(&m_inspector, test_metrics_flags);
@@ -1034,8 +1226,6 @@ TEST_F(sinsp_with_test_input, plugin_metrics) {
 	ASSERT_EQ(metrics_snapshot.back().value.u64, events);
 }
 
-#endif
-
 #if defined(ENABLE_THREAD_POOL) && !defined(__EMSCRIPTEN__)
 
 TEST_F(sinsp_with_test_input, plugin_routines) {
@@ -1092,7 +1282,7 @@ TEST_F(sinsp_with_test_input, plugin_routines) {
 	                     PPM_O_RDWR,
 	                     0);
 	std::this_thread::sleep_for(
-	        std::chrono::nanoseconds(1000));  // wait for a bit to let routine finish
+	        std::chrono::milliseconds(100));  // wait for a bit to let routine finish
 	routines_num = tp->routines_num();
 	ASSERT_EQ(routines_num, 1);
 
@@ -1100,7 +1290,7 @@ TEST_F(sinsp_with_test_input, plugin_routines) {
 	// unsubscribe it on capture close
 	m_inspector.close();
 	std::this_thread::sleep_for(
-	        std::chrono::nanoseconds(100));  // wait for a bit to let routine finish
+	        std::chrono::milliseconds(100));  // wait for a bit to let routine finish
 	routines_num = tp->routines_num();
 	ASSERT_EQ(routines_num, 0);
 }
