@@ -141,7 +141,7 @@ ss_plugin_rc plugin_set_async_event_handler(ss_plugin_t* s,
 				        err,
 				        PPME_ASYNCEVENT_E,
 				        3,
-				        0,
+				        (uint32_t)0,
 				        "unsupportedname",
 				        scap_const_sized_buffer{data, strlen(data) + 1});
 				ps->async_evt->tid = 1;
@@ -161,7 +161,7 @@ ss_plugin_rc plugin_set_async_event_handler(ss_plugin_t* s,
 				        err,
 				        PPME_ASYNCEVENT_E,
 				        3,
-				        0,
+				        (uint32_t)0,
 				        name,
 				        scap_const_sized_buffer{data, strlen(data) + 1});
 				ps->async_evt->tid = 1;
@@ -188,6 +188,43 @@ ss_plugin_rc plugin_set_async_event_handler(ss_plugin_t* s,
 	return SS_PLUGIN_SUCCESS;
 }
 
+ss_plugin_rc plugin_dump_state(ss_plugin_t* s,
+                               ss_plugin_owner_t* owner,
+                               const ss_plugin_async_event_handler_t handler) {
+	static uint8_t evt_buf[256];
+	static ss_plugin_event* evt;
+	char err[PLUGIN_MAX_ERRLEN];
+	const char* name = "sampleticker";
+
+	for(int i = 0; i < 10; i++) {
+		evt = (ss_plugin_event*)evt_buf;
+
+		std::string data = "hello world #" + std::to_string(i);
+
+		char error[SCAP_LASTERR_SIZE];
+		int32_t encode_res = scap_event_encode_params(
+		        scap_sized_buffer{evt, sizeof(evt_buf)},
+		        nullptr,
+		        error,
+		        PPME_ASYNCEVENT_E,
+		        3,
+		        (uint32_t)0,
+		        name,
+		        scap_const_sized_buffer{(void*)data.c_str(), data.length() + 1});
+
+		if(encode_res == SCAP_FAILURE) {
+			return SS_PLUGIN_FAILURE;
+		}
+		if(SS_PLUGIN_SUCCESS != handler(owner, evt, err)) {
+			printf("sample_syscall_async: unexpected failure in sending asynchronous event "
+			       "from plugin: %s\n",
+			       err);
+			exit(1);
+		}
+	}
+	return SS_PLUGIN_SUCCESS;
+}
+
 }  // anonymous namespace
 
 void get_plugin_api_sample_syscall_async(plugin_api& out) {
@@ -203,4 +240,5 @@ void get_plugin_api_sample_syscall_async(plugin_api& out) {
 	out.get_async_event_sources = plugin_get_async_event_sources;
 	out.get_async_events = plugin_get_async_events;
 	out.set_async_event_handler = plugin_set_async_event_handler;
+	out.dump_state = plugin_dump_state;
 }
