@@ -124,10 +124,14 @@ const libsinsp::events::set<ppm_event_code> expected_sinsp_state_event_set = {
         PPME_SOCKET_RECVFROM_X,
         PPME_SOCKET_RECVMSG_E,
         PPME_SOCKET_RECVMSG_X,
+        PPME_SOCKET_RECVMMSG_E,
+        PPME_SOCKET_RECVMMSG_X,
         PPME_SOCKET_GETSOCKOPT_E,
         PPME_SOCKET_GETSOCKOPT_X,
         PPME_SOCKET_SENDMSG_E,
         PPME_SOCKET_SENDMSG_X,
+        PPME_SOCKET_SENDMMSG_E,
+        PPME_SOCKET_SENDMMSG_X,
         PPME_SOCKET_SENDTO_E,
         PPME_SOCKET_SENDTO_X,
         PPME_SYSCALL_SETGID_E,
@@ -218,39 +222,23 @@ const libsinsp::events::set<ppm_event_code> expected_sinsp_state_event_set = {
         PPME_SYSCALL_SETREGID_X};
 
 const libsinsp::events::set<ppm_sc_code> expected_sinsp_state_sc_set = {
-        PPM_SC_ACCEPT,         PPM_SC_ACCEPT4,
-        PPM_SC_BIND,           PPM_SC_CAPSET,
-        PPM_SC_CHDIR,          PPM_SC_CHROOT,
-        PPM_SC_CLONE,          PPM_SC_CLONE3,
-        PPM_SC_CLOSE,          PPM_SC_CONNECT,
-        PPM_SC_CREAT,          PPM_SC_DUP,
-        PPM_SC_DUP2,           PPM_SC_DUP3,
-        PPM_SC_EVENTFD,        PPM_SC_EVENTFD2,
-        PPM_SC_EXECVE,         PPM_SC_EXECVEAT,
-        PPM_SC_FCHDIR,         PPM_SC_FCNTL,
-        PPM_SC_FCNTL64,        PPM_SC_FORK,
-        PPM_SC_INOTIFY_INIT,   PPM_SC_INOTIFY_INIT1,
-        PPM_SC_IO_URING_SETUP, PPM_SC_MOUNT,
-        PPM_SC_OPEN,           PPM_SC_OPEN_BY_HANDLE_AT,
-        PPM_SC_OPENAT,         PPM_SC_OPENAT2,
-        PPM_SC_PIPE,           PPM_SC_PIPE2,
-        PPM_SC_PRLIMIT64,      PPM_SC_RECVFROM,
-        PPM_SC_RECVMSG,        PPM_SC_GETSOCKOPT,
-        PPM_SC_SENDMSG,        PPM_SC_SENDTO,
-        PPM_SC_SETGID,         PPM_SC_SETGID32,
-        PPM_SC_SETPGID,        PPM_SC_SETRESGID,
-        PPM_SC_SETRESGID32,    PPM_SC_SETRESUID,
-        PPM_SC_SETRESUID32,    PPM_SC_SETRLIMIT,
-        PPM_SC_SETSID,         PPM_SC_SETUID,
-        PPM_SC_SETUID32,       PPM_SC_SHUTDOWN,
-        PPM_SC_SIGNALFD,       PPM_SC_SIGNALFD4,
-        PPM_SC_SOCKET,         PPM_SC_SOCKETPAIR,
-        PPM_SC_TIMERFD_CREATE, PPM_SC_UMOUNT,
-        PPM_SC_UMOUNT2,        PPM_SC_USERFAULTFD,
-        PPM_SC_VFORK,          PPM_SC_EPOLL_CREATE,
-        PPM_SC_EPOLL_CREATE1,  PPM_SC_SCHED_PROCESS_EXIT,
-        PPM_SC_PRCTL,          PPM_SC_MEMFD_CREATE,
-        PPM_SC_PIDFD_OPEN,     PPM_SC_PIDFD_GETFD,
+        PPM_SC_ACCEPT,         PPM_SC_ACCEPT4,      PPM_SC_BIND,          PPM_SC_CAPSET,
+        PPM_SC_CHDIR,          PPM_SC_CHROOT,       PPM_SC_CLONE,         PPM_SC_CLONE3,
+        PPM_SC_CLOSE,          PPM_SC_CONNECT,      PPM_SC_CREAT,         PPM_SC_DUP,
+        PPM_SC_DUP2,           PPM_SC_DUP3,         PPM_SC_EVENTFD,       PPM_SC_EVENTFD2,
+        PPM_SC_EXECVE,         PPM_SC_EXECVEAT,     PPM_SC_FCHDIR,        PPM_SC_FCNTL,
+        PPM_SC_FCNTL64,        PPM_SC_FORK,         PPM_SC_INOTIFY_INIT,  PPM_SC_INOTIFY_INIT1,
+        PPM_SC_IO_URING_SETUP, PPM_SC_MOUNT,        PPM_SC_OPEN,          PPM_SC_OPEN_BY_HANDLE_AT,
+        PPM_SC_OPENAT,         PPM_SC_OPENAT2,      PPM_SC_PIPE,          PPM_SC_PIPE2,
+        PPM_SC_PRLIMIT64,      PPM_SC_RECVFROM,     PPM_SC_RECVMSG,       PPM_SC_RECVMMSG,
+        PPM_SC_GETSOCKOPT,     PPM_SC_SENDMSG,      PPM_SC_SENDMMSG,      PPM_SC_SENDTO,
+        PPM_SC_SETGID,         PPM_SC_SETGID32,     PPM_SC_SETPGID,       PPM_SC_SETRESGID,
+        PPM_SC_SETRESGID32,    PPM_SC_SETRESUID,    PPM_SC_SETRESUID32,   PPM_SC_SETRLIMIT,
+        PPM_SC_SETSID,         PPM_SC_SETUID,       PPM_SC_SETUID32,      PPM_SC_SHUTDOWN,
+        PPM_SC_SIGNALFD,       PPM_SC_SIGNALFD4,    PPM_SC_SOCKET,        PPM_SC_SOCKETPAIR,
+        PPM_SC_TIMERFD_CREATE, PPM_SC_UMOUNT,       PPM_SC_UMOUNT2,       PPM_SC_USERFAULTFD,
+        PPM_SC_VFORK,          PPM_SC_EPOLL_CREATE, PPM_SC_EPOLL_CREATE1, PPM_SC_SCHED_PROCESS_EXIT,
+        PPM_SC_PRCTL,          PPM_SC_MEMFD_CREATE, PPM_SC_PIDFD_OPEN,    PPM_SC_PIDFD_GETFD,
         PPM_SC_SETREUID,       PPM_SC_SETREGID,
 };
 
