@@ -17,27 +17,23 @@ limitations under the License.
 
 */
 
-#include <helpers/threads_helpers.h>
-#include <helpers/scap_file_helpers.h>
+#include <scap_files/scap_file_test.h>
+#include <sinsp_with_test_input.h>
 
-TEST(scap_file_kexec_arm64, tail_lineage) {
-	std::string path = LIBSINSP_TEST_SCAP_FILES_DIR + std::string("kexec_arm64.scap");
-	sinsp m_inspector;
-	m_inspector.open_savefile(path);
+TEST_F(scap_file_test, kexec_arm64_tail_lineage) {
+	open_filename("kexec_arm64.scap");
 
 	/* Check that containerd_shim main at the beginning is not a reaper since we cannot recover
 	 * that info from proc scan.
 	 */
-	auto containerd_shim1_tinfo = m_inspector.get_thread_ref(141207);
+	auto containerd_shim1_tinfo = m_inspector->get_thread_ref(141207);
 	ASSERT_TRUE(containerd_shim1_tinfo);
 	ASSERT_TRUE(containerd_shim1_tinfo->m_tginfo);
 	ASSERT_FALSE(containerd_shim1_tinfo->m_tginfo->is_reaper());
 
 	/* Search the tail execve event */
 	int64_t tid_tail = 141546;
-	auto evt = scap_file_test_helpers::capture_search_evt_by_type_and_tid(&m_inspector,
-	                                                                      PPME_SYSCALL_EXECVE_19_X,
-	                                                                      tid_tail);
+	auto evt = capture_search_evt_by_type_and_tid(PPME_SYSCALL_EXECVE_19_X, tid_tail);
 
 	std::vector<int64_t> traverse_parents;
 	sinsp_threadinfo::visitor_func_t visitor = [&traverse_parents](sinsp_threadinfo* pt) {
@@ -79,18 +75,15 @@ TEST(scap_file_kexec_arm64, tail_lineage) {
 	ASSERT_EQ(traverse_parents, expected_traverse_parents_after_execve);
 
 	/* At the beninning of the capture containerd_shim1 was not a reaper */
-	containerd_shim1_tinfo = m_inspector.get_thread_ref(tid_containerd_shim1);
+	containerd_shim1_tinfo = m_inspector->get_thread_ref(tid_containerd_shim1);
 	ASSERT_TRUE(containerd_shim1_tinfo);
 	ASSERT_TRUE(containerd_shim1_tinfo->m_tginfo);
 	ASSERT_TRUE(containerd_shim1_tinfo->m_tginfo->is_reaper());
 }
 
-TEST(scap_file_kexec_arm64, final_thread_table_dim) {
-	std::string path = LIBSINSP_TEST_SCAP_FILES_DIR + std::string("kexec_arm64.scap");
-	sinsp m_inspector;
-	m_inspector.open_savefile(path);
-
-	/* Get the final event of the capture and check the thread_table dim */
-	scap_file_test_helpers::capture_search_evt_by_num(&m_inspector, 907459);
-	ASSERT_EQ(m_inspector.m_thread_manager->get_thread_count(), 612);
+TEST_F(scap_file_test, kexec_arm64_final_thread_table_dim) {
+	open_filename("kexec_arm64.scap");
+	read_until_EOF();
+	/* Check the thread_table dim at the end of the capture */
+	ASSERT_EQ(m_inspector->m_thread_manager->get_thread_count(), 612);
 }
