@@ -110,7 +110,7 @@ scap_evt* sinsp_with_test_input::create_event_v(uint64_t ts,
 
 	if(ret != SCAP_INPUT_TOO_SMALL) {
 		va_end(args2);
-		return nullptr;
+		throw std::runtime_error(std::string("cannot compute the size of the event: ") + error);
 	}
 
 	event_buf.buf = malloc(event_size);
@@ -127,7 +127,7 @@ scap_evt* sinsp_with_test_input::create_event_v(uint64_t ts,
 		free(event_buf.buf);
 		event_buf.size = 0;
 		va_end(args2);
-		return nullptr;
+		throw std::runtime_error(std::string("cannot encode the event: ") + error);
 	}
 
 	scap_evt* event = static_cast<scap_evt*>(event_buf.buf);
@@ -150,6 +150,12 @@ scap_evt* sinsp_with_test_input::add_event_v(uint64_t ts,
 	}
 
 	scap_evt* event = create_event_v(ts, tid, event_type, n, args);
+	if(event == nullptr) {
+		std::stringstream ss;
+		ss << "cannot create event type: " << event_type << ", ts: " << ts << ", tid: " << tid
+		   << ", n: " << n;
+		throw std::runtime_error(ss.str());
+	}
 
 	uint64_t evtoffset = m_events.size() - m_test_data.event_count;
 	m_events.push_back(event);
@@ -260,7 +266,8 @@ sinsp_evt* sinsp_with_test_input::generate_execve_enter_and_exit_event(
         const std::string& pathname,
         const std::string& comm,
         const std::string& resolved_kernel_path,
-        const std::vector<std::string>& cgroup_vec) {
+        const std::vector<std::string>& cgroup_vec,
+        int64_t pgid) {
 	// Scaffolding needed to call the PPME_SYSCALL_EXECVE_19_X
 	uint64_t not_relevant_64 = 0;
 	uint32_t not_relevant_32 = 0;
@@ -279,7 +286,7 @@ sinsp_evt* sinsp_with_test_input::generate_execve_enter_and_exit_event(
 	return add_event_advance_ts(increasing_ts(),
 	                            new_tid,
 	                            PPME_SYSCALL_EXECVE_19_X,
-	                            28,
+	                            29,
 	                            retval,
 	                            pathname.c_str(),
 	                            empty_bytebuf,
@@ -307,7 +314,8 @@ sinsp_evt* sinsp_with_test_input::generate_execve_enter_and_exit_event(
 	                            not_relevant_64,
 	                            not_relevant_64,
 	                            not_relevant_32,
-	                            resolved_kernel_path.c_str());
+	                            resolved_kernel_path.c_str(),
+	                            pgid);
 }
 
 void sinsp_with_test_input::remove_thread(int64_t tid_to_remove, int64_t reaper_tid) {
@@ -351,6 +359,41 @@ sinsp_evt* sinsp_with_test_input::generate_getcwd_failed_entry_event(int64_t tid
 	                            path.c_str());
 }
 
+sinsp_evt* sinsp_with_test_input::generate_open_x_event(sinsp_test_input::open_params params,
+                                                        int64_t tid_caller) {
+	return add_event_advance_ts(increasing_ts(),
+	                            tid_caller,
+	                            PPME_SYSCALL_OPEN_X,
+	                            6,
+	                            params.fd,
+	                            params.path,
+	                            params.flags,
+	                            params.mode,
+	                            params.dev,
+	                            params.ino);
+}
+
+sinsp_evt* sinsp_with_test_input::generate_socket_events(sinsp_test_input::socket_params params,
+                                                         int64_t tid_caller) {
+	// todo!: remove it when we will disable enter events by default. At the moment we want to test
+	// the use case in which we generate both the enter event and the exit one.
+	add_event_advance_ts(increasing_ts(),
+	                     tid_caller,
+	                     PPME_SOCKET_SOCKET_E,
+	                     3,
+	                     params.domain,
+	                     params.type,
+	                     params.proto);
+	return add_event_advance_ts(increasing_ts(),
+	                            tid_caller,
+	                            PPME_SOCKET_SOCKET_X,
+	                            4,
+	                            params.fd,
+	                            params.domain,
+	                            params.type,
+	                            params.proto);
+}
+
 //=============================== PROCESS GENERATION ===========================
 
 void sinsp_with_test_input::add_thread(const scap_threadinfo& tinfo,
@@ -671,3 +714,115 @@ sinsp_evt* sinsp_with_test_input::next_event() {
 	auto result = m_inspector.next(&evt);
 	return result == SCAP_SUCCESS ? evt : nullptr;
 }
+
+void sinsp_with_test_input::assert_return_value(sinsp_evt* evt, int64_t expected_retval) {
+	// First the event we provide should have the return value
+	ASSERT_TRUE(evt->has_return_value());
+
+	// The raw value should be equal to what we expect
+	ASSERT_EQ(evt->get_syscall_return_value(), expected_retval);
+
+	// We need to create the filtercheck name for the first parameter, usually `res`/`fd` but not
+	// always, could be also `addr` for example...
+	std::string evt_rawarg_name = std::string("evt.rawarg.") + std::string(evt->get_param_name(0));
+
+	// SUCCESS CASE: we consider success when retval >= 0 (so != errno)
+	if(expected_retval >= 0) {
+		/////////////
+		// Res
+		/////////////
+		ASSERT_EQ(get_field_as_string(evt, "evt.res"), "SUCCESS");
+		ASSERT_EQ(get_field_as_string(evt, "evt.rawres"), std::to_string(expected_retval));
+		ASSERT_EQ(get_field_as_string(evt, "evt.failed"), "false");
+
+		/////////////
+		// First parameter (arg0)
+		/////////////
+		auto arg0_info = evt->get_param_info(0);
+		ASSERT_TRUE(arg0_info);
+		// Default values
+		std::string arg0 = std::to_string(expected_retval);
+		std::string raw_arg0 = std::to_string(expected_retval);
+
+		// Some cases in which we need to modify `arg0` or `raw_arg0`
+		if(arg0_info->type == PT_FD) {
+			// If the return value is a file descriptor the value of `evt.arg[0]` is the path
+			// prefixed by `<f>`
+			auto fdinfo = evt->get_fd_info();
+			ASSERT_TRUE(fdinfo);
+			arg0 = std::string("<f>") + fdinfo->m_name;
+
+			// raw_arg0 is ok!
+		}
+
+		if(arg0_info->fmt == PF_HEX && arg0_info->type == PT_UINT64) {
+			// both `evt.arg[0]` and `evt.rawarg` become hexadecimal
+			char buffer[100];
+			std::snprintf(buffer, sizeof(buffer), "%" PRIX64, expected_retval);
+			arg0 = buffer;
+			raw_arg0 = buffer;
+		}
+
+		ASSERT_EQ(get_field_as_string(evt, "evt.arg[0]"), arg0);
+		ASSERT_EQ(get_field_as_string(evt, evt_rawarg_name), raw_arg0);
+	} else {
+		/////////////
+		// Res
+		/////////////
+		ASSERT_EQ(get_field_as_string(evt, "evt.res"), sinsp_utils::errno_to_str(expected_retval));
+		ASSERT_EQ(get_field_as_string(evt, "evt.rawres"), std::to_string(expected_retval));
+		ASSERT_EQ(get_field_as_string(evt, "evt.failed"), "true");
+
+		/////////////
+		// First parameter (arg0)
+		/////////////
+		ASSERT_EQ(get_field_as_string(evt, "evt.arg[0]"), get_field_as_string(evt, "evt.res"));
+		ASSERT_EQ(get_field_as_string(evt, evt_rawarg_name),
+		          get_field_as_string(evt, "evt.rawres"));
+	}
+}
+
+void sinsp_with_test_input::assert_fd_fields(sinsp_evt* evt,
+                                             sinsp_test_input::fd_info_fields fields) {
+	auto fdinfo = evt->get_fd_info();
+
+	// Right now we only assert if the fdinfo is present, but we want to be sure that for some
+	// events the fdinfo should be here
+	if((evt->creates_fd() || evt->uses_fd()) && evt->get_syscall_return_value() >= 0) {
+		ASSERT_TRUE(fdinfo);
+	}
+
+	if(fdinfo) {
+		if(fields.fd_num.has_value()) {
+			ASSERT_EQ(fdinfo->m_fd, fields.fd_num.value());
+		}
+
+		if(fields.fd_name.has_value()) {
+			ASSERT_EQ(fdinfo->m_name, fields.fd_name.value());
+		}
+
+		if(fields.fd_name_raw.has_value()) {
+			ASSERT_EQ(fdinfo->m_name_raw, fields.fd_name_raw.value());
+		}
+	}
+
+	if(fields.fd_num.has_value()) {
+		ASSERT_EQ(get_field_as_string(evt, "fd.num"), std::to_string(fields.fd_num.value()));
+	}
+
+	if(fields.fd_name.has_value()) {
+		ASSERT_EQ(get_field_as_string(evt, "fd.name"), fields.fd_name.value());
+	}
+
+	if(fields.fd_name_raw.has_value()) {
+		ASSERT_EQ(get_field_as_string(evt, "fd.nameraw"), fields.fd_name_raw.value());
+	}
+
+	if(fields.fd_directory.has_value()) {
+		ASSERT_EQ(get_field_as_string(evt, "fd.directory"), fields.fd_directory.value());
+	}
+
+	if(fields.fd_filename.has_value()) {
+		ASSERT_EQ(get_field_as_string(evt, "fd.filename"), fields.fd_filename.value());
+	}
+}
