@@ -703,7 +703,7 @@ static inline bool concatenate_paths_(char* target,
                                       const char* path2,
                                       uint32_t len2) {
 	if(targetlen < (len1 + len2 + 1)) {
-		strlcpy(target, "/PATH_TOO_LONG", targetlen);
+		strlcpy(target, "/DIR_TOO_LONG/FILENAME_TOO_LONG", targetlen);
 		return false;
 	}
 
@@ -1264,13 +1264,13 @@ std::vector<std::string> sinsp_split(std::string_view sv, char delim) {
 	std::string_view::size_type start = 0;
 	for(std::string_view::size_type i = 0; i < sv.size(); i++) {
 		if(sv[i] == delim) {
-			res.push_back(std::string(sv.substr(start, i - start)));
+			res.emplace_back(sv.substr(start, i - start));
 			start = i + 1;
 		}
 	}
 
 	if(start <= sv.length()) {
-		res.push_back(std::string(sv.substr(start)));
+		res.emplace_back(sv.substr(start));
 	}
 
 	return res;
